import { FilterItem } from '@sowatech/shared/ds-datasource';
import { DialogDynamicList } from '@sowatech/shared/swt-generic';
import { FilterValues, IFilterConfiguration } from './compact-filter.types';
import { FilterLabel } from './labels/filter-label';
import * as i0 from "@angular/core";
export declare class CompactFilterComponent<DTO = unknown> {
    /**
     * Konfiguration des Filters. Ableitung der DialogConfiguration des GenericEditDialogs
     */
    readonly configuration: import("@angular/core").InputSignal<IFilterConfiguration<DTO>>;
    /**
     * Store-Key für die Speicherung der Filterwerte im UserPropertiesStorage
     */
    readonly partialStoreKey: import("@angular/core").InputSignal<string>;
    /**
     * Wenn im Filter noch keine Werte gesetzt sind, werden die Default-Werte gesetzt
     */
    readonly defaultValues: import("@angular/core").InputSignal<FilterValues>;
    /**
     * Dynamische Liste für Lookups/Datasource im Dialog
     */
    readonly dynamicList: import("@angular/core").InputSignal<DialogDynamicList[]>;
    /**
     * Versteckt die Anzeige der FilterItems
     */
    readonly hideFilterLabels: import("@angular/core").InputSignalWithTransform<boolean, unknown>;
    /**
     * Maximale Höhe des FilterButtons und FilterItems
     */
    readonly maxHeight: import("@angular/core").InputSignal<string>;
    /**
     * Minimale Höhe des FilterButtons und FilterItems
     * @default '68px' (entspricht FilterButton + eine Reihe FilterItems)
     */
    readonly minHeight: import("@angular/core").InputSignal<string>;
    /** bootstrap Farbe für den Filter Button, z.B. "primary" */
    readonly btnClass: import("@angular/core").InputSignal<string>;
    /**
     * Emitted wenn sich die FilterItems ändern
     * Wird initial mit Daten vom Storage/DefaultValues emitted
     */
    readonly change: import("@angular/core").OutputEmitterRef<FilterItem[]>;
    /**
     * Emitted wenn der Dialog geöffnet wird
     */
    readonly dialogOpened: import("@angular/core").OutputEmitterRef<FilterValues>;
    private readonly touchedFilterValues;
    private readonly filterValues;
    /**
     * Computed Signal mit den aktuellen FilterItems
    */
    readonly filterItems: import("@angular/core").Signal<FilterItem[]>;
    protected readonly labels: import("@angular/core").WritableSignal<FilterLabel<DTO>[]>;
    private readonly storeKey;
    private readonly storageValues;
    private readonly cleanedDefaultValues;
    private readonly dialog;
    private readonly userPropertiesStorage;
    private readonly destroyRef;
    constructor();
    /**
     * Anzeige der FilterItems wird neu kalkuliert.
     * Wird benötigt, wenn z.B. getLabelText neu berechnet werden soll.
     */
    refreshLabels(): void;
    private createLabels;
    protected openDialog(label?: FilterLabel<DTO>): void;
    private deepCopy;
    private deleteUnknownProperties;
    private getField;
    private createFilterItems;
    private createFilterItem;
    protected remove(label: FilterLabel<DTO>): void;
    protected reset(): void;
    private extractRequiredProperties;
    private isArrayWithMultipleItems;
    private loadFromStorage;
    static ɵfac: i0.ɵɵFactoryDeclaration<CompactFilterComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CompactFilterComponent<any>, "compact-filter", never, { "configuration": { "alias": "configuration"; "required": true; "isSignal": true; }; "partialStoreKey": { "alias": "store-key"; "required": false; "isSignal": true; }; "defaultValues": { "alias": "defaultValues"; "required": false; "isSignal": true; }; "dynamicList": { "alias": "dynamicList"; "required": false; "isSignal": true; }; "hideFilterLabels": { "alias": "hideFilterLabels"; "required": false; "isSignal": true; }; "maxHeight": { "alias": "maxHeight"; "required": false; "isSignal": true; }; "minHeight": { "alias": "minHeight"; "required": false; "isSignal": true; }; "btnClass": { "alias": "btnClass"; "required": false; "isSignal": true; }; }, { "change": "change"; "dialogOpened": "dialogOpened"; }, never, never, false, never>;
}
