import { LoggerService } from '@sowatech/shared/logger';
import { UserPropertiesStorageService } from '@sowatech/shared/user-properties-storage';
import { CsvMappingDialog } from './csv-mapping.dialog';
import * as i0 from "@angular/core";
/**
 * Service zum manuellen Konfigurieren eines CSV Mappings.
 * ```ts
 * const data = await this.csvService.parseCsv(file);
 * const targetFields
 * ```
 */
export declare class CsvMappingService {
    private csvMappingDialog;
    private logger;
    private storage;
    constructor(csvMappingDialog: CsvMappingDialog, logger: LoggerService, storage: UserPropertiesStorageService);
    /**
     * Zeigt einen Konfigurationsdialog an, in dem man ein Mapping von den gegebenen CSV Daten zum Zielformat einstellen kann
     * @param data Die aus dem CSV ausgelesenen Daten. Können über `csvMappingService.paseCsv(file)` besorgt werden.
     * @param configFields Konfiguration, welche Felder im Zielformat vorhanden sein sollen.
     */
    showDialog(data: Array<object>, configFields: TargetField[], storageKeyBase?: string, showDateFormatInput?: boolean): Promise<IMappingConfig>;
    /**
     * Liest eine CSV-Datei ein und gibt die Zeilen als Array zurück
     * @returns Liste aller Zeilen (`string[][]`)
     */
    parseCsv(file: File, config?: ParseConfig): Promise<Object[]>;
    private buildPapaParseConfig;
    /**
     * Nimmt die ausgelesenen Daten und das Mapping und baut daraus die Zielstruktur als JavaScript Objekte
     * @param data Die aus dem CSV ausgelesenen Daten. Können über `csvMappingService.paseCsv(file)` besorgt werden.
     * @param targetObjectDefinition Konfiguration, welche Felder im Zielformat vorhanden sein sollen.
     * Hier kann die gleiche Konfiguration wie in `csvMappingService.showDialog` verwendet werden: `{ fields: targetFields }`
     * @param mappingConfig Die Konfiguration fürs Mapping der Daten zum Zielformat. Hier kann das Ergebnis von `csvMappingService.showDialog` verwendet werden.
     */
    createTargetObjects<T>(data: Array<object>, targetObjectDefinition: TargetObjectDefinition, mappingConfig: IMappingConfig): T[];
    private createTargetObject;
    private createTargetObjectProperty;
    private createTargetObjectDictionary;
    private convertToType;
    /**im Mitgliederimport L2 kann man das Datum eines Zertifikats mit Ja beantworten, wenn kein Datum bekannt ist*/
    private convertJaDateStringToDate;
    static ɵfac: i0.ɵɵFactoryDeclaration<CsvMappingService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CsvMappingService>;
}
export declare class MappingConfigStorageHelper {
    private storage;
    private storageKey;
    constructor(storageKeyBase: string, storage: UserPropertiesStorageService);
    private storageIsActive;
    load(): IMappingConfig;
    save(mappingObject: IMappingConfig): void;
}
export interface ParseConfig {
    delimiter?: string;
    newline?: string;
    quoteChar?: string;
    header?: boolean;
    dynamicTyping?: boolean;
    preview?: number;
    encoding?: string;
    worker?: boolean;
    comments?: boolean | string;
    download?: boolean;
    skipEmptyLines?: boolean;
    fastMode?: boolean;
    withCredentials?: boolean;
}
export declare class TargetObjectDefinition {
    fields: TargetField[];
}
export declare class TargetField {
    type?: FieldType | 'dictionary';
    fieldname: string;
    displayname?: string;
    dictionaryValueType?: FieldType;
}
export declare class KeyValueObject {
    key: string;
    value: string | boolean | number | Date | Array<string>;
}
export declare type FieldType = 'string' | 'boolean' | 'number' | 'dateIso' | 'date' | 'string[]';
export interface IMappingConfig {
    fields: IMappingField;
    dateFormat: string;
    dataContainsHeaders: boolean;
}
export interface IMappingField {
    [fieldname: string]: number | null;
}
