import '@angular/localize/init';
import * as i0 from '@angular/core';
import { Injectable, Directive, Input, Component, NgModule } from '@angular/core';
import * as i1 from '@sowatech/shared/session';
import * as i2 from '@sowatech/shared/logger';
import * as i4 from '@angular/common';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

class RoleGroup {
    constructor(roles) {
        this.roles = [];
        this.roles = (typeof (roles) === 'string') ? roles.split(',') : roles;
    }
}

class AccessForRoleService {
    constructor(session, logger) {
        this.session = session;
        this.logger = logger;
    }
    sessionHasRole(roleGroups) {
        const sessionHasRoles = this.session && this.session.Data && this.session.Data.roles;
        if (!sessionHasRoles) {
            this.logger.warn('keine Rollen in der Session vorhanden');
            return false;
        }
        return roleGroups.every(roleGroup => this.session.Data.roles.some(item => roleGroup.roles.includes(item)));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: AccessForRoleService, deps: [{ token: i1.SharedSession }, { token: i2.LoggerService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: AccessForRoleService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: AccessForRoleService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i1.SharedSession }, { type: i2.LoggerService }] });

// _roles erwartet entweder einen ;-Separierten string mit ,-Separiert roleGroups, ein Array von Roles, oder ein Array von Role-Arrays
// in sessionHasRole wird in der aktuellen Session überprüft, ob mindestens eine Rolle aus jeder Gruppe vorhanden ist
class AccessForRoleComponent {
    set _roles(value) {
        const groups = [];
        if (value == null || value === undefined || !value[0])
            this.roleGroups = groups;
        else if (value && typeof (value) === 'string')
            value.split(';').forEach(group => groups.push(new RoleGroup(group)));
        else if (value[0] && typeof (value[0]) === 'string')
            groups.push(new RoleGroup(value));
        else if (value[0][0] && typeof (value[0][0]) === 'string')
            value.forEach(roles => groups.push(new RoleGroup(roles)));
        this.roleGroups = groups;
    }
    get sessionHasRole() {
        return this.accessForRoleService.sessionHasRole(this.roleGroups);
    }
    constructor(session, logger, accessForRoleService) {
        this.session = session;
        this.logger = logger;
        this.accessForRoleService = accessForRoleService;
        this.roleGroups = [];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: AccessForRoleComponent, deps: [{ token: i1.SharedSession }, { token: i2.LoggerService }, { token: AccessForRoleService }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.13", type: AccessForRoleComponent, isStandalone: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: AccessForRoleComponent, decorators: [{
            type: Directive
        }], ctorParameters: () => [{ type: i1.SharedSession }, { type: i2.LoggerService }, { type: AccessForRoleService }] });

//Bsp. <restrict-edit-to-roles [roles]="role1,role2;license1,license2"></restrict-edit-to-roles>
//Bsp. <restrict-edit-to-roles [roles]="['role1','role2']"></restrict-edit-to-roles>
//Bsp. <restrict-edit-to-roles [roles]="[['role1','role2'],['license1','license2']]"></restrict-edit-to-roles>
class RestrictEditToRolesComponent extends AccessForRoleComponent {
    set _editableRoles(value) {
        this._roles = value;
    }
    get canEdit() {
        return this.sessionHasRole;
    }
    constructor(session, logger, accessForRolesService) {
        super(session, logger, accessForRolesService);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: RestrictEditToRolesComponent, deps: [{ token: i1.SharedSession }, { token: i2.LoggerService }, { token: AccessForRoleService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: RestrictEditToRolesComponent, isStandalone: false, selector: "restrict-edit-to-roles", inputs: { _editableRoles: ["roles", "_editableRoles"] }, usesInheritance: true, ngImport: i0, template: `
        <div [ngClass]="sessionHasRole ? '': 'no-edit'">
            <ng-content></ng-content>
        </div>`, isInline: true, dependencies: [{ kind: "directive", type: i4.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: RestrictEditToRolesComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'restrict-edit-to-roles',
                    template: `
        <div [ngClass]="sessionHasRole ? '': 'no-edit'">
            <ng-content></ng-content>
        </div>`,
                    standalone: false
                }]
        }], ctorParameters: () => [{ type: i1.SharedSession }, { type: i2.LoggerService }, { type: AccessForRoleService }], propDecorators: { _editableRoles: [{
                type: Input,
                args: ['roles']
            }] } });

//Bsp. <visible-for-role [roles]="role1,role2;license1,license2"></visible-for-role>
//Bsp. <visible-for-role [roles]="['role1','role2']"></visible-for-role>
//Bsp. <visible-for-role [roles]="[['role1','role2'],['license1','license2']]"></visible-for-role>
class VisibleForRoleComponent extends AccessForRoleComponent {
    set _visibleRoles(value) {
        this._roles = value;
    }
    get isVisible() {
        return this.sessionHasRole;
    }
    constructor(session, logger, accessForRolesService) {
        super(session, logger, accessForRolesService);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: VisibleForRoleComponent, deps: [{ token: i1.SharedSession }, { token: i2.LoggerService }, { token: AccessForRoleService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: VisibleForRoleComponent, isStandalone: false, selector: "visible-for-role", inputs: { _visibleRoles: ["roles", "_visibleRoles"] }, usesInheritance: true, ngImport: i0, template: `
        <ng-container *ngIf="sessionHasRole">
            <ng-content></ng-content>
        </ng-container>`, isInline: true, dependencies: [{ kind: "directive", type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: VisibleForRoleComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'visible-for-role',
                    template: `
        <ng-container *ngIf="sessionHasRole">
            <ng-content></ng-content>
        </ng-container>`,
                    standalone: false
                }]
        }], ctorParameters: () => [{ type: i1.SharedSession }, { type: i2.LoggerService }, { type: AccessForRoleService }], propDecorators: { _visibleRoles: [{
                type: Input,
                args: ['roles']
            }] } });

class AccessForRoleDirective {
    set _roles(value) {
        const groups = [];
        if (value == null || value === undefined || !value[0])
            this.roleGroups = groups;
        else if (value && typeof (value) === 'string')
            value.split(';').forEach(group => groups.push(new RoleGroup(group)));
        else if (value[0] && typeof (value[0]) === 'string')
            groups.push(new RoleGroup(value));
        else if (value[0][0] && typeof (value[0][0]) === 'string')
            value.forEach(roles => groups.push(new RoleGroup(roles)));
        this.roleGroups = groups;
    }
    constructor(el, session, logger, accessForRoleService) {
        this.session = session;
        this.logger = logger;
        this.accessForRoleService = accessForRoleService;
        this.roleGroups = [];
        this.nativeElement = el.nativeElement;
    }
    ngOnInit() {
        if (this.sessionHasRole)
            this.removeClass(this.class);
        else
            this.addClass(this.class);
    }
    get sessionHasRole() {
        return this.accessForRoleService.sessionHasRole(this.roleGroups);
    }
    removeClass(className) {
        if (!this.nativeElement.classList)
            throw new Error('Die Variable nativeElement fehlt das Klassen Attribut. Kann die Klasse nicht entfernen: ' + className);
        this.nativeElement.classList.remove(className);
    }
    addClass(className) {
        if (!this.nativeElement.classList)
            throw new Error('Die Variable nativeElement fehlt das Klassen Attribut. Kann die Klasse nicht hinzufügen: ' + className);
        if (!this.nativeElement.classList.contains(className))
            this.nativeElement.classList.add(className);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: AccessForRoleDirective, deps: [{ token: i0.ElementRef }, { token: i1.SharedSession }, { token: i2.LoggerService }, { token: AccessForRoleService }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.13", type: AccessForRoleDirective, isStandalone: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: AccessForRoleDirective, decorators: [{
            type: Directive
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i1.SharedSession }, { type: i2.LoggerService }, { type: AccessForRoleService }] });

//Bsp. [restrict-edit-to-roles]="role1,role2;license1,license2"
//Bsp. [restrict-edit-to-roles]="['role1','role2']"
//Bsp. [restrict-edit-to-roles]="[['role1','role2'],['license1','license2']]"
class RestrictEditToRolesDirective extends AccessForRoleDirective {
    set _editableForRoles(value) {
        this._roles = value;
    }
    constructor(el, session, logger, accessForRoleService) {
        super(el, session, logger, accessForRoleService);
        this.class = 'no-edit';
    }
    ngOnInit() {
        super.ngOnInit();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: RestrictEditToRolesDirective, deps: [{ token: i0.ElementRef }, { token: i1.SharedSession }, { token: i2.LoggerService }, { token: AccessForRoleService }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.13", type: RestrictEditToRolesDirective, isStandalone: false, selector: "[restrict-edit-to-roles]", inputs: { _editableForRoles: ["restrict-edit-to-roles", "_editableForRoles"] }, usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: RestrictEditToRolesDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[restrict-edit-to-roles]',
                    standalone: false
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i1.SharedSession }, { type: i2.LoggerService }, { type: AccessForRoleService }], propDecorators: { _editableForRoles: [{
                type: Input,
                args: ['restrict-edit-to-roles']
            }] } });

//Bsp. [visible-for-role]="'role1,role2;license1,license2'"
//Bsp. [visible-for-role]="['role1','role2']"
//Bsp. [visible-for-role]="[['role1','role2'],['license1','license2']]"
class VisibleForRoleDirective extends AccessForRoleDirective {
    set _visibleForRoles(value) {
        this._roles = value;
    }
    constructor(el, session, logger, accessForRoleService) {
        super(el, session, logger, accessForRoleService);
        this.class = 'hidden';
    }
    ngOnInit() {
        super.ngOnInit();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: VisibleForRoleDirective, deps: [{ token: i0.ElementRef }, { token: i1.SharedSession }, { token: i2.LoggerService }, { token: AccessForRoleService }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.13", type: VisibleForRoleDirective, isStandalone: false, selector: "[visible-for-role]", inputs: { _visibleForRoles: ["visible-for-role", "_visibleForRoles"] }, usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: VisibleForRoleDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[visible-for-role]',
                    standalone: false
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i1.SharedSession }, { type: i2.LoggerService }, { type: AccessForRoleService }], propDecorators: { _visibleForRoles: [{
                type: Input,
                args: ['visible-for-role']
            }] } });

class AccessForRoleModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: AccessForRoleModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.13", ngImport: i0, type: AccessForRoleModule, declarations: [RestrictEditToRolesComponent,
            RestrictEditToRolesDirective,
            VisibleForRoleComponent,
            VisibleForRoleDirective], imports: [CommonModule,
            FormsModule], exports: [RestrictEditToRolesComponent,
            RestrictEditToRolesDirective,
            VisibleForRoleComponent,
            VisibleForRoleDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: AccessForRoleModule, imports: [CommonModule,
            FormsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: AccessForRoleModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        FormsModule,
                    ],
                    declarations: [
                        RestrictEditToRolesComponent,
                        RestrictEditToRolesDirective,
                        VisibleForRoleComponent,
                        VisibleForRoleDirective,
                    ],
                    exports: [
                        RestrictEditToRolesComponent,
                        RestrictEditToRolesDirective,
                        VisibleForRoleComponent,
                        VisibleForRoleDirective,
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { AccessForRoleModule, AccessForRoleService, RestrictEditToRolesComponent, RestrictEditToRolesDirective, RoleGroup, VisibleForRoleComponent, VisibleForRoleDirective };
//# sourceMappingURL=sowatech-shared-access-for-role.mjs.map
