import * as i0 from '@angular/core';
import { inject, input, booleanAttribute, signal, computed, Directive, Component, ElementRef, NgModule } from '@angular/core';
import { SharedConfigService } from '@sowatech/shared/shared-config';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import { MessageBoxService } from '@sowatech/shared/dialogs';
import { LoggerService } from '@sowatech/shared/logger';
import { I18nService } from '@sowatech/shared/utilities';

/* eslint-disable @angular-eslint/no-input-rename */
class ButtonBaseDirective {
    constructor() {
        this.config = inject(SharedConfigService);
        this.icon = input();
        this.btnClass = input(undefined, { alias: 'btn-class' });
        this.faType = input('fa', { alias: 'fa-type' });
        this.disableMargin = input(false, { transform: booleanAttribute });
        this.defaultIcon = signal('');
        this.defaultBtnClass = signal('');
        this.marginClass = computed(() => !this.disableMargin() ? this.config.decideByTemplate({ inspinia: 'm-r-xs', sneat: 'me-1' }) : '');
        this.computedClass = computed(() => `btn btn-${this.btnClass() ?? this.defaultBtnClass()} ${this.config.btnSize} ${this.marginClass()}`);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonBaseDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.13", type: ButtonBaseDirective, isStandalone: true, inputs: { icon: { classPropertyName: "icon", publicName: "icon", isSignal: true, isRequired: false, transformFunction: null }, btnClass: { classPropertyName: "btnClass", publicName: "btn-class", isSignal: true, isRequired: false, transformFunction: null }, faType: { classPropertyName: "faType", publicName: "fa-type", isSignal: true, isRequired: false, transformFunction: null }, disableMargin: { classPropertyName: "disableMargin", publicName: "disableMargin", isSignal: true, isRequired: false, transformFunction: null } }, host: { properties: { "class": "computedClass()" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonBaseDirective, decorators: [{
            type: Directive,
            args: [{
                    host: { '[class]': 'computedClass()' }, // host binding geht nur so mit signals
                }]
        }] });

class ButtonAddComponent extends ButtonBaseDirective {
    constructor() {
        super();
        this.defaultIcon.set('plus');
        this.defaultBtnClass.set('default');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonAddComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: ButtonAddComponent, isStandalone: false, selector: "button[button-add]", usesInheritance: true, ngImport: i0, template: "<i class=\"{{ faType() }} fa-{{ icon() ?? defaultIcon() }}\" *ngIf=\"icon() ?? defaultIcon()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonAddComponent, decorators: [{
            type: Component,
            args: [{ selector: 'button[button-add]', standalone: false, template: "<i class=\"{{ faType() }} fa-{{ icon() ?? defaultIcon() }}\" *ngIf=\"icon() ?? defaultIcon()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"] }]
        }], ctorParameters: () => [] });

const CLASS = 'ButtonConfirmDirective';
class ButtonConfirmDirective extends ButtonBaseDirective {
    constructor() {
        super(...arguments);
        this.i18nService = inject(I18nService);
        this.messageBoxService = inject(MessageBoxService);
        this.el = inject((ElementRef));
        this.logger = inject(LoggerService);
        this.designation = input(''); // z.B. Person
        this.name = input(''); // z.B. Chris König
        this.confirmationText = input(); // (mit i18n) z.B. Möchten Sie die Person wirklich löschen?
        this.confirmationTitle = input();
        this.confirmDialog = input(true);
        this.nativeClickListeners = [];
    }
    ngOnInit() {
        for (const listener of this.el.nativeElement.eventListeners()) {
            this.nativeClickListeners.push(listener);
            this.el.nativeElement.removeEventListener('click', listener);
        }
        this.el.nativeElement.addEventListener('click', event => this.doClick(event));
    }
    async doClick(e) {
        const confirmed = await this.showConfirmDialog();
        if (confirmed)
            this.nativeClickListeners.forEach(listener => listener(e));
    }
    async showConfirmDialog() {
        if (!this.confirmDialog())
            return true;
        const text = this.getText();
        if (text == null) {
            this.logger.error(CLASS + ' needs a confirmationText, a name or a designation');
            return false;
        }
        await this.messageBoxService.confirmDialog(text, this.confirmationTitle() ?? this.defaultText_title);
        return true;
    }
    getText() {
        if (this.confirmationText())
            return this.confirmationText();
        if (this.name() && this.designation())
            return this.i18nService.replace(this.defaultText_designationAndName, [this.designation(), this.name()]);
        else if (this.name())
            return this.i18nService.replace(this.defaultText_name, [this.name()]);
        else if (this.designation())
            return this.i18nService.replace(this.defaultText_designation, [this.designation()]);
        return null;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonConfirmDirective, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.2.13", type: ButtonConfirmDirective, isStandalone: true, inputs: { designation: { classPropertyName: "designation", publicName: "designation", isSignal: true, isRequired: false, transformFunction: null }, name: { classPropertyName: "name", publicName: "name", isSignal: true, isRequired: false, transformFunction: null }, confirmationText: { classPropertyName: "confirmationText", publicName: "confirmationText", isSignal: true, isRequired: false, transformFunction: null }, confirmationTitle: { classPropertyName: "confirmationTitle", publicName: "confirmationTitle", isSignal: true, isRequired: false, transformFunction: null }, confirmDialog: { classPropertyName: "confirmDialog", publicName: "confirmDialog", isSignal: true, isRequired: false, transformFunction: null } }, usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonConfirmDirective, decorators: [{
            type: Directive
        }] });

class ButtonCreateComponent extends ButtonBaseDirective {
    constructor() {
        super();
        this.defaultIcon.set('plus');
        this.defaultBtnClass.set('primary');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonCreateComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: ButtonCreateComponent, isStandalone: false, selector: "button[button-create]", usesInheritance: true, ngImport: i0, template: "<i class=\"{{ faType() }} fa-{{ icon() ?? defaultIcon() }}\" *ngIf=\"icon() ?? defaultIcon()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonCreateComponent, decorators: [{
            type: Component,
            args: [{ selector: 'button[button-create]', standalone: false, template: "<i class=\"{{ faType() }} fa-{{ icon() ?? defaultIcon() }}\" *ngIf=\"icon() ?? defaultIcon()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"] }]
        }], ctorParameters: () => [] });

class ButtonCustomComponent extends ButtonBaseDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonCustomComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: ButtonCustomComponent, isStandalone: false, selector: "button[button-custom]", usesInheritance: true, ngImport: i0, template: "<i class=\"{{ faType() }} fa-{{ icon() ?? defaultIcon() }}\" *ngIf=\"icon() ?? defaultIcon()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonCustomComponent, decorators: [{
            type: Component,
            args: [{ selector: 'button[button-custom]', standalone: false, template: "<i class=\"{{ faType() }} fa-{{ icon() ?? defaultIcon() }}\" *ngIf=\"icon() ?? defaultIcon()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"] }]
        }] });

class ButtonDeleteComponent extends ButtonConfirmDirective {
    constructor() {
        super();
        this.defaultIcon.set('trash');
        this.defaultBtnClass.set('danger');
        this.defaultText_title = $localize `:@@DeleteButton.act.Label:Löschen`;
        this.defaultText_designationAndName = $localize `:@@DeleteButton.confirmDialog.designationAndName.dsp.Text:$0 '$1' löschen?`;
        this.defaultText_designation = $localize `:@@DeleteButton.confirmDialog.designation.dsp.Text:$0 löschen?`;
        this.defaultText_name = $localize `:@@DeleteButton.confirmDialog.name.dsp.Text:'$0' löschen?`;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonDeleteComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: ButtonDeleteComponent, isStandalone: false, selector: "button[button-delete]", usesInheritance: true, ngImport: i0, template: "<i class=\"{{ faType() }} fa-{{ icon() ?? defaultIcon() }}\" *ngIf=\"icon() ?? defaultIcon()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonDeleteComponent, decorators: [{
            type: Component,
            args: [{ selector: 'button[button-delete]', standalone: false, template: "<i class=\"{{ faType() }} fa-{{ icon() ?? defaultIcon() }}\" *ngIf=\"icon() ?? defaultIcon()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"] }]
        }], ctorParameters: () => [] });

class ButtonEditComponent extends ButtonBaseDirective {
    constructor() {
        super();
        this.defaultIcon.set('edit');
        this.defaultBtnClass.set('default');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonEditComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: ButtonEditComponent, isStandalone: false, selector: "button[button-edit]", usesInheritance: true, ngImport: i0, template: "<i class=\"{{ faType() }} fa-{{ icon() ?? defaultIcon() }}\" *ngIf=\"icon() ?? defaultIcon()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonEditComponent, decorators: [{
            type: Component,
            args: [{ selector: 'button[button-edit]', standalone: false, template: "<i class=\"{{ faType() }} fa-{{ icon() ?? defaultIcon() }}\" *ngIf=\"icon() ?? defaultIcon()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"] }]
        }], ctorParameters: () => [] });

class ButtonRemoveComponent extends ButtonConfirmDirective {
    constructor() {
        super();
        this.defaultIcon.set('unlink');
        this.defaultBtnClass.set('danger');
        this.defaultText_title = $localize `:@@RemoveButton.act.Label:Entfernen`;
        this.defaultText_designationAndName = $localize `:@@RemoveButton.confirmDialog.designationAndName.dsp.Text:$0 '$1' entfernen?`;
        this.defaultText_designation = $localize `:@@RemoveButton.confirmDialog.designation.dsp.Text:$0 entfernen?`;
        this.defaultText_name = $localize `:@@RemoveButton.confirmDialog.name.dsp.Text:'$0' entfernen?`;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonRemoveComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: ButtonRemoveComponent, isStandalone: false, selector: "button[button-remove]", usesInheritance: true, ngImport: i0, template: "<i class=\"{{ faType() }} fa-{{ icon() ?? defaultIcon() }}\" *ngIf=\"icon() ?? defaultIcon()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonRemoveComponent, decorators: [{
            type: Component,
            args: [{ selector: 'button[button-remove]', standalone: false, template: "<i class=\"{{ faType() }} fa-{{ icon() ?? defaultIcon() }}\" *ngIf=\"icon() ?? defaultIcon()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"] }]
        }], ctorParameters: () => [] });

class ButtonsModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.13", ngImport: i0, type: ButtonsModule, declarations: [ButtonAddComponent,
            ButtonCreateComponent,
            ButtonCustomComponent,
            ButtonDeleteComponent,
            ButtonEditComponent,
            ButtonRemoveComponent], imports: [CommonModule], exports: [ButtonAddComponent,
            ButtonCreateComponent,
            ButtonCustomComponent,
            ButtonDeleteComponent,
            ButtonEditComponent,
            ButtonRemoveComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonsModule, imports: [CommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ButtonsModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                    ],
                    exports: [
                        ButtonAddComponent,
                        ButtonCreateComponent,
                        ButtonCustomComponent,
                        ButtonDeleteComponent,
                        ButtonEditComponent,
                        ButtonRemoveComponent,
                    ],
                    declarations: [
                        ButtonAddComponent,
                        ButtonCreateComponent,
                        ButtonCustomComponent,
                        ButtonDeleteComponent,
                        ButtonEditComponent,
                        ButtonRemoveComponent,
                    ],
                    providers: [],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ButtonAddComponent, ButtonBaseDirective, ButtonConfirmDirective, ButtonCreateComponent, ButtonCustomComponent, ButtonDeleteComponent, ButtonEditComponent, ButtonRemoveComponent, ButtonsModule };
//# sourceMappingURL=sowatech-shared-buttons.mjs.map
