import * as i0 from '@angular/core';
import { input, output, Component, booleanAttribute, inject, signal, computed, linkedSignal, DestroyRef, effect, untracked, NgModule } from '@angular/core';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import { FilterOperator, FilterItem } from '@sowatech/shared/ds-datasource';
import { SharedConfigService } from '@sowatech/shared/shared-config';
import { GenericEditDialogService, DialogField } from '@sowatech/shared/swt-generic';
import { UserPropertiesStorageService } from '@sowatech/shared/user-properties-storage';
import { first } from 'rxjs';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2$1 from '@sowatech/shared/no-double-click';
import { NoDblClickModule } from '@sowatech/shared/no-double-click';
import * as i3 from '@sowatech/shared/buttons';
import { ButtonsModule } from '@sowatech/shared/buttons';
import * as i2 from '@sowatech/shared/template';
import { SwitchTemplateModule } from '@sowatech/shared/template';

class FilterLabel {
    constructor(fieldname, value, field, fieldHasSingleValue, dynamicList = []) {
        this.fieldname = fieldname;
        this.value = value;
        this.text = FilterLabel.getText(fieldname, value, field, dynamicList);
        this.title = FilterLabel.getTitle(fieldname, value, field);
        this.class = FilterLabel.getClass(fieldname, value, field);
        this.iconClass = FilterLabel.getIconClass(fieldname, value, field);
        this.removable = !(field.required && fieldHasSingleValue);
    }
    static createLabels(key, filterValue, field, dynamicList) {
        if (!field)
            return [];
        let labels;
        if (Array.isArray(filterValue)) {
            const fieldHasSingleValue = filterValue.length === 1;
            labels = filterValue.map(value => new FilterLabel(key, value, field, fieldHasSingleValue, dynamicList));
        }
        else
            labels = [new FilterLabel(key, filterValue, field, true, dynamicList)];
        return labels.filter(fl => !!fl.text);
    }
    static getText(fieldname, value, field, dynamicList) {
        if (field.getLabelText)
            return field.getLabelText(value, fieldname);
        if (field.lookUps) {
            const lookups = Array.isArray(field.lookUps) ? field.lookUps : dynamicList.find(dl => dl.key === field.lookUps)?.lookupItems;
            if (!lookups)
                return value.toString();
            const isStringArrayLookUp = lookups.length > 0 && typeof lookups[0] === 'string';
            if (!isStringArrayLookUp) {
                const item = lookups.find(l => l.value === value);
                return item?.text ?? value.toString();
            }
        }
        return value.toString();
    }
    static getTitle(fieldname, value, field) {
        if (field.getLabelTitle)
            return field.getLabelTitle(value, fieldname);
        return field.text;
    }
    static getClass(fieldname, value, field) {
        if (field.getLabelClass)
            return field.getLabelClass(value, fieldname);
        return '';
    }
    static getIconClass(fieldname, value, field) {
        if (field.getLabelIconClass)
            return field.getLabelIconClass(value, fieldname);
        return '';
    }
}

class CompactFilterLabelsComponent {
    constructor() {
        this.labels = input.required();
        this.onLabelClick = output();
        this.onLabelRemove = output();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CompactFilterLabelsComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.13", type: CompactFilterLabelsComponent, isStandalone: false, selector: "compact-filter-labels", inputs: { labels: { classPropertyName: "labels", publicName: "labels", isSignal: true, isRequired: true, transformFunction: null } }, outputs: { onLabelClick: "onLabelClick", onLabelRemove: "onLabelRemove" }, ngImport: i0, template: "@for(label of labels(); track label) {\r\n    <code class=\"filter-label\" sneat-class=\"sneat\" [ngClass]=\"{'removable': label.removable}\" [class]=\"label.class\" [title]=\"label.title\"\r\n            (click)=\"onLabelClick.emit(label)\">\r\n        <i *ngIf=\"label.iconClass\" [ngClass]=\"label.iconClass\"></i>\r\n        {{label.text}}\r\n        <i *ngIf=\"label.removable\" class=\"fa fa-times remove-icon\" (click)=\"onLabelRemove.emit(label)\"></i>\r\n    </code>\r\n}\r\n", styles: [":host{display:block;margin-top:10px;margin-bottom:10px}.filter-label{padding:2px 4px;margin-right:10px;white-space:nowrap!important;overflow:hidden;text-overflow:ellipsis;display:inline-block;max-width:100%;position:relative}.filter-label.removable{padding-right:20px}.filter-label .remove-icon{position:absolute;right:5px;top:5px;cursor:pointer}code.sneat{background-color:#d5e0f4;color:#204077}code.sneat .remove-icon{top:7px}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.SneatCssClassDirective, selector: "[sneat-class]", inputs: ["sneat-class"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CompactFilterLabelsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'compact-filter-labels', standalone: false, template: "@for(label of labels(); track label) {\r\n    <code class=\"filter-label\" sneat-class=\"sneat\" [ngClass]=\"{'removable': label.removable}\" [class]=\"label.class\" [title]=\"label.title\"\r\n            (click)=\"onLabelClick.emit(label)\">\r\n        <i *ngIf=\"label.iconClass\" [ngClass]=\"label.iconClass\"></i>\r\n        {{label.text}}\r\n        <i *ngIf=\"label.removable\" class=\"fa fa-times remove-icon\" (click)=\"onLabelRemove.emit(label)\"></i>\r\n    </code>\r\n}\r\n", styles: [":host{display:block;margin-top:10px;margin-bottom:10px}.filter-label{padding:2px 4px;margin-right:10px;white-space:nowrap!important;overflow:hidden;text-overflow:ellipsis;display:inline-block;max-width:100%;position:relative}.filter-label.removable{padding-right:20px}.filter-label .remove-icon{position:absolute;right:5px;top:5px;cursor:pointer}code.sneat{background-color:#d5e0f4;color:#204077}code.sneat .remove-icon{top:7px}\n"] }]
        }] });

const STORE_KEY_PREFIX = 'CompactFilter.';
class CompactFilterComponent {
    constructor() {
        /**
         * Konfiguration des Filters. Ableitung der DialogConfiguration des GenericEditDialogs
         */
        this.configuration = input.required();
        /**
         * Store-Key für die Speicherung der Filterwerte im UserPropertiesStorage
         */
        this.partialStoreKey = input(null, { alias: 'store-key' });
        /**
         * Wenn im Filter noch keine Werte gesetzt sind, werden die Default-Werte gesetzt
         */
        this.defaultValues = input(null);
        /**
         * Dynamische Liste für Lookups/Datasource im Dialog
         */
        this.dynamicList = input(null);
        /**
         * Versteckt die Anzeige der FilterItems
         */
        this.hideFilterLabels = input(false, { transform: booleanAttribute });
        /**
         * Maximale Höhe des FilterButtons und FilterItems
         */
        this.maxHeight = input(null);
        /**
         * Minimale Höhe des FilterButtons und FilterItems
         * @default '68px' (entspricht FilterButton + eine Reihe FilterItems)
         */
        this.minHeight = input('68px');
        /** bootstrap Farbe für den Filter Button, z.B. "primary" */
        this.btnClass = input(inject(SharedConfigService).templateKey === 'inspinia' ? 'default' : 'secondary');
        /**
         * Emitted wenn sich die FilterItems ändern
         * Wird initial mit Daten vom Storage/DefaultValues emitted
         */
        this.change = output();
        /**
         * Emitted wenn der Dialog geöffnet wird
         */
        this.dialogOpened = output();
        this.touchedFilterValues = signal(null);
        this.filterValues = computed(() => this.touchedFilterValues() ?? this.deepCopy(this.cleanedDefaultValues()));
        /**
         * Computed Signal mit den aktuellen FilterItems
        */
        this.filterItems = computed(() => this.createFilterItems(this.filterValues()));
        this.labels = linkedSignal(() => this.createLabels(this.filterValues()));
        this.storeKey = computed(() => this.partialStoreKey() ? STORE_KEY_PREFIX + this.partialStoreKey() : null);
        this.storageValues = computed(() => this.storeKey() ? this.loadFromStorage(this.storeKey()) : null);
        this.cleanedDefaultValues = computed(() => this.defaultValues() ? this.deleteUnknownProperties(this.defaultValues()) : null);
        this.dialog = inject(GenericEditDialogService);
        this.userPropertiesStorage = inject(UserPropertiesStorageService);
        this.destroyRef = inject(DestroyRef);
        //Auslesen aus Storage
        effect(() => {
            if (this.storageValues() && untracked(this.touchedFilterValues) === null)
                this.touchedFilterValues.set(this.storageValues());
        });
        //Speichern des Storage
        effect(() => {
            if (this.storeKey() && this.filterValues())
                this.userPropertiesStorage.save(this.storeKey(), this.filterValues());
        });
        //Emit der FilterItems
        effect(() => {
            this.change.emit(this.filterItems());
        });
    }
    /**
     * Anzeige der FilterItems wird neu kalkuliert.
     * Wird benötigt, wenn z.B. getLabelText neu berechnet werden soll.
     */
    refreshLabels() {
        this.labels.set(this.createLabels(this.filterValues()));
    }
    createLabels(filterValues) {
        return filterValues !== null
            ? Object.keys(filterValues).flatMap(key => FilterLabel.createLabels(key, filterValues[key], this.getField(key), this.dynamicList()))
            : [];
    }
    openDialog(label) {
        const filterValues = this.filterValues() ? this.deleteUnknownProperties(this.filterValues()) : null;
        this.dialog.show(this.configuration(), filterValues, null, this.dynamicList())
            .pipe(takeUntilDestroyed(this.destroyRef), first()).subscribe(dialogResult => {
            const newFilterValues = this.deleteUnknownProperties(dialogResult.dto);
            this.touchedFilterValues.set(newFilterValues);
        });
        if (label)
            this.dialog.focus(label.fieldname);
        this.dialogOpened.emit(filterValues);
    }
    deepCopy(obj) {
        return JSON.parse(JSON.stringify(obj));
    }
    deleteUnknownProperties(filterValues) {
        const copy = this.deepCopy(filterValues);
        // eslint-disable-next-line guard-for-in
        for (const key in copy) {
            const value = copy[key];
            const valueIsNotSet = value === undefined || value === null || Number.isNaN(value)
                || (Array.isArray(value) && value.length === 0);
            const fieldIsNotInConfig = this.getField(key) === undefined;
            if (valueIsNotSet || fieldIsNotInConfig)
                delete copy[key];
        }
        return copy;
    }
    getField(fieldname) {
        const configuration = this.configuration();
        return configuration.fieldsOrCategoriesOfFields.find(f => f.fieldname === fieldname)
            ?? configuration.fieldsOrCategoriesOfFields.find(f => f.fieldname2 === fieldname);
    }
    createFilterItems(values) {
        if (!values)
            return [];
        return Object.keys(values).map(key => this.createFilterItem(key, values[key]));
    }
    createFilterItem(key, value) {
        const field = this.getField(key);
        const filterOperator = field.filterOperator ?? FilterOperator.IsEqual;
        if (Array.isArray(value)) {
            const stringValues = value.map(v => v.toString());
            return new FilterItem([key], stringValues, filterOperator);
        }
        else {
            const stringValue = value.toString();
            return new FilterItem([key], stringValue, filterOperator);
        }
    }
    remove(label) {
        if (this.filterValues() === null)
            return;
        const filterValues = { ...this.filterValues() };
        const filterValue = filterValues[label.fieldname];
        if (Array.isArray(filterValue)) {
            const index = filterValue.indexOf(label.value);
            if (index >= 0) {
                filterValue.splice(index, 1);
                filterValues[label.fieldname] = filterValue;
            }
        }
        else
            delete filterValues[label.fieldname];
        this.touchedFilterValues.set(filterValues);
    }
    reset() {
        if (this.touchedFilterValues() === null)
            return;
        this.touchedFilterValues.set(this.defaultValues()
            ? null
            : this.extractRequiredProperties(this.touchedFilterValues()));
    }
    extractRequiredProperties(filterValues) {
        const copy = { ...filterValues };
        // eslint-disable-next-line guard-for-in
        for (const key in copy) {
            const field = this.getField(key);
            if (!field || !field.required)
                delete copy[key];
            else if (this.isArrayWithMultipleItems(copy[key]))
                copy[key] = [copy[key][0]];
        }
        return copy;
    }
    isArrayWithMultipleItems(filterValue) {
        return Array.isArray(filterValue) && filterValue.length > 1;
    }
    loadFromStorage(storeKey) {
        const storageValues = this.userPropertiesStorage.load(storeKey);
        return storageValues ? this.deleteUnknownProperties(storageValues) : null;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CompactFilterComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.1.0", version: "19.2.13", type: CompactFilterComponent, isStandalone: false, selector: "compact-filter", inputs: { configuration: { classPropertyName: "configuration", publicName: "configuration", isSignal: true, isRequired: true, transformFunction: null }, partialStoreKey: { classPropertyName: "partialStoreKey", publicName: "store-key", isSignal: true, isRequired: false, transformFunction: null }, defaultValues: { classPropertyName: "defaultValues", publicName: "defaultValues", isSignal: true, isRequired: false, transformFunction: null }, dynamicList: { classPropertyName: "dynamicList", publicName: "dynamicList", isSignal: true, isRequired: false, transformFunction: null }, hideFilterLabels: { classPropertyName: "hideFilterLabels", publicName: "hideFilterLabels", isSignal: true, isRequired: false, transformFunction: null }, maxHeight: { classPropertyName: "maxHeight", publicName: "maxHeight", isSignal: true, isRequired: false, transformFunction: null }, minHeight: { classPropertyName: "minHeight", publicName: "minHeight", isSignal: true, isRequired: false, transformFunction: null }, btnClass: { classPropertyName: "btnClass", publicName: "btnClass", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { change: "change", dialogOpened: "dialogOpened" }, ngImport: i0, template: "<div class=\"compact-filter-container\" [style.maxHeight]=\"maxHeight()\" [style.minHeight]=\"minHeight()\">\r\n    <div class=\"btn-group\">\r\n        <button button-custom [btn-class]=\"btnClass()\" icon=\"filter\" (click)=\"openDialog()\" disableMargin\r\n            data-cy=\"compact-filter-button\" i18n=\"@@CompactFilter.Filter.act.Label\">Filter</button>\r\n        <button button-custom [btn-class]=\"btnClass()\" icon=\"undo\" data-cy=\"compact-filter-undo-button\"\r\n            (click)=\"reset()\"></button>\r\n    </div>\r\n    <compact-filter-labels *ngIf=\"!hideFilterLabels()\" [labels]=\"labels()\" (onLabelClick)=\"openDialog($event)\"\r\n        (onLabelRemove)=\"remove($event)\"></compact-filter-labels>\r\n</div>\r\n", styles: [".compact-filter-container{overflow-y:auto}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2$1.NoDblClickButtonDirective, selector: "button:not([disable-no-double-click])" }, { kind: "component", type: i3.ButtonCustomComponent, selector: "button[button-custom]" }, { kind: "component", type: CompactFilterLabelsComponent, selector: "compact-filter-labels", inputs: ["labels"], outputs: ["onLabelClick", "onLabelRemove"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CompactFilterComponent, decorators: [{
            type: Component,
            args: [{ selector: 'compact-filter', standalone: false, template: "<div class=\"compact-filter-container\" [style.maxHeight]=\"maxHeight()\" [style.minHeight]=\"minHeight()\">\r\n    <div class=\"btn-group\">\r\n        <button button-custom [btn-class]=\"btnClass()\" icon=\"filter\" (click)=\"openDialog()\" disableMargin\r\n            data-cy=\"compact-filter-button\" i18n=\"@@CompactFilter.Filter.act.Label\">Filter</button>\r\n        <button button-custom [btn-class]=\"btnClass()\" icon=\"undo\" data-cy=\"compact-filter-undo-button\"\r\n            (click)=\"reset()\"></button>\r\n    </div>\r\n    <compact-filter-labels *ngIf=\"!hideFilterLabels()\" [labels]=\"labels()\" (onLabelClick)=\"openDialog($event)\"\r\n        (onLabelRemove)=\"remove($event)\"></compact-filter-labels>\r\n</div>\r\n", styles: [".compact-filter-container{overflow-y:auto}\n"] }]
        }], ctorParameters: () => [] });

class CompactFilterModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CompactFilterModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.13", ngImport: i0, type: CompactFilterModule, declarations: [CompactFilterComponent,
            CompactFilterLabelsComponent], imports: [CommonModule,
            NoDblClickModule,
            ButtonsModule,
            SwitchTemplateModule], exports: [CompactFilterComponent,
            CompactFilterLabelsComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CompactFilterModule, imports: [CommonModule,
            NoDblClickModule,
            ButtonsModule,
            SwitchTemplateModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CompactFilterModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        NoDblClickModule,
                        ButtonsModule,
                        SwitchTemplateModule,
                    ],
                    declarations: [
                        CompactFilterComponent,
                        CompactFilterLabelsComponent
                    ],
                    exports: [
                        CompactFilterComponent,
                        CompactFilterLabelsComponent
                    ]
                }]
        }] });

class FilterDialogField extends DialogField {
}

/**
 * Generated bundle index. Do not edit.
 */

export { CompactFilterComponent, CompactFilterLabelsComponent, CompactFilterModule, FilterDialogField, FilterLabel };
//# sourceMappingURL=sowatech-shared-compact-filter.mjs.map
