import 'moment/locale/de';
import * as i0 from '@angular/core';
import { Injectable, NgModule } from '@angular/core';
import moment from 'moment';
import * as Papa from 'papaparse';
import { firstValueFrom } from 'rxjs';
import * as i1 from '@sowatech/shared/swt-generic';
import { SwtGenericModule } from '@sowatech/shared/swt-generic';
import * as i2 from '@sowatech/shared/logger';
import * as i3 from '@sowatech/shared/user-properties-storage';
import { CommonModule } from '@angular/common';

const CLASS$1 = 'CsvMappingDialog';
class CsvMappingDialog {
    constructor(genericEditDialog, logger) {
        this.genericEditDialog = genericEditDialog;
        this.logger = logger;
    }
    showMappingDialog(configFields, header, mappingConfig, showDateFormatInput = true) {
        this.logger.log(CLASS$1 + '.showMappingDialog');
        if (!header)
            throw new Error($localize `:@@CsvMapping.MissingDataRow.msg.Text:firstDataRow fehlt oder ist leer`);
        const lookupColNames = header.map((columnName, index) => ({ text: columnName.toString(), value: index }));
        // LEER Option für optionale Felder
        lookupColNames.unshift({ text: $localize `:@@CsvMapping.Empty.dsp.Label:(Leer)`, value: -1 });
        const lookupColNumbers = header.map((columnName, index) => ({ text: index.toString(), value: index }));
        // LEER Option für optionale Felder
        lookupColNumbers.unshift({ text: $localize `:@@CsvMapping.Empty.dsp.Label:(Leer)`, value: -1 });
        const lookups = [
            { key: 'COLUMNNUMMBERS', lookupItems: lookupColNumbers },
            { key: 'COLUMNNAMES', lookupItems: lookupColNames }
        ];
        const configDialog = this.getDialogConfiguration(configFields, showDateFormatInput);
        return this.genericEditDialog.show(configDialog, mappingConfig, null, lookups);
    }
    getDialogConfiguration(configFields, showDateFormatInput = true) {
        this.logger.log(CLASS$1 + '.getDialogConfiguration');
        const config = {
            title: $localize `:@@CsvMapping.AssignColumns.act.Title:Spalten zuordnen`,
            inputSize: 'small',
            fieldsOrCategoriesOfFields: this.getDialogFields(configFields, showDateFormatInput)
        };
        return config;
    }
    getDialogFields(configFields, showDateFormatInput) {
        this.logger.log(CLASS$1 + '.getDialogFields');
        const defaultDateFormat = 'DD.MM.YYYY';
        const dateformatChanged = (editItem) => {
            editItem.dateFormat = editItem.dateFormat != '' ? editItem.dateFormat : defaultDateFormat;
        };
        const dialogFields = [
            {
                fieldname: 'dataContainsHeaders',
                default: false,
                text: $localize `:@@CsvMapping.Header.dsp.Label:Kopfzeile mit Spaltennamen`,
                controlType: 'checkbox',
                type: 'boolean'
            }
        ];
        if (showDateFormatInput) {
            dialogFields.push({
                fieldname: 'dateFormat',
                text: $localize `:@@CsvMapping.Dateformat.dsp.Label:Datumsformat`,
                default: 'DD.MM.YYYY',
                type: 'text',
                placeholder: 'DD.MM.YYYY',
                onChange: dateformatChanged
            });
        }
        for (const val of configFields) {
            if (val.type == 'dictionary') {
                for (let field = 0; field < 2; field++) {
                    const dialogFieldsDictionaryWithNumbers = this.bulidDialogDictionaryFields(field, val, 'COLUMNNUMMBERS');
                    dialogFields.push(dialogFieldsDictionaryWithNumbers);
                    const dialogFieldsDictionaryWithNames = this.bulidDialogDictionaryFields(field, val, 'COLUMNNAMES');
                    dialogFields.push(dialogFieldsDictionaryWithNames);
                }
            }
            else {
                const dialogFieldWithNumbers = this.buildDialogField(val, 'COLUMNNUMMBERS');
                dialogFields.push(dialogFieldWithNumbers);
                const dialogFieldWithNames = this.buildDialogField(val, 'COLUMNNAMES');
                dialogFields.push(dialogFieldWithNames);
            }
        }
        return dialogFields;
    }
    bulidDialogDictionaryFields(fieldIndex, targetField, lookUpsKey) {
        return {
            fieldname: fieldIndex == 0 ? 'fields.' + targetField.fieldname : 'fields.' + targetField.fieldname + '_lastColumn',
            text: targetField.displayname ? targetField.displayname : targetField.fieldname,
            help: fieldIndex == 0 ? targetField.fieldname + ' Erste Spalte' : targetField.fieldname + ' Letzte Spalte',
            type: 'number',
            default: -1,
            lookUps: lookUpsKey,
            hideIf: lookUpsKey === 'COLUMNNUMMBERS' ?
                (editItem) => editItem.dataContainsHeaders :
                (editItem) => !editItem.dataContainsHeaders
        };
    }
    buildDialogField(targetField, lookUpsKey) {
        return {
            fieldname: 'fields.' + targetField.fieldname,
            text: targetField.displayname ? targetField.displayname : targetField.fieldname,
            type: 'number',
            default: -1,
            lookUps: lookUpsKey,
            hideIf: lookUpsKey === 'COLUMNNUMMBERS' ?
                (editItem) => editItem.dataContainsHeaders :
                (editItem) => !editItem.dataContainsHeaders
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CsvMappingDialog, deps: [{ token: i1.GenericEditDialogService }, { token: i2.LoggerService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CsvMappingDialog, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CsvMappingDialog, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: () => [{ type: i1.GenericEditDialogService }, { type: i2.LoggerService }] });

const CLASS = 'CsvMappingService';
const STORAGE_KEY_MAPPING_CONFIG = 'CsvMappingService.MappingConfig';
/**
 * Service zum manuellen Konfigurieren eines CSV Mappings.
 * ```ts
 * const data = await this.csvService.parseCsv(file);
 * const targetFields
 * ```
 */
class CsvMappingService {
    constructor(csvMappingDialog, logger, storage) {
        this.csvMappingDialog = csvMappingDialog;
        this.logger = logger;
        this.storage = storage;
    }
    /**
     * Zeigt einen Konfigurationsdialog an, in dem man ein Mapping von den gegebenen CSV Daten zum Zielformat einstellen kann
     * @param data Die aus dem CSV ausgelesenen Daten. Können über `csvMappingService.paseCsv(file)` besorgt werden.
     * @param configFields Konfiguration, welche Felder im Zielformat vorhanden sein sollen.
     */
    async showDialog(data, configFields, storageKeyBase, showDateFormatInput = true) {
        this.logger.log(CLASS + '.showDialog');
        const headerValues = Object.values(data[0]);
        const storageHelper = new MappingConfigStorageHelper(storageKeyBase, this.storage);
        const oldMappingConfig = storageHelper.load();
        const newMappingConfig = await firstValueFrom(this.csvMappingDialog.showMappingDialog(configFields, headerValues, oldMappingConfig, showDateFormatInput));
        storageHelper.save(newMappingConfig.dto);
        return newMappingConfig.dto;
    }
    /**
     * Liest eine CSV-Datei ein und gibt die Zeilen als Array zurück
     * @returns Liste aller Zeilen (`string[][]`)
     */
    parseCsv(file, config) {
        this.logger.log(CLASS + '.parseCsv');
        const promise = new Promise((resolve, reject) => {
            if (file && file.name.indexOf('.csv') < 0)
                reject(new Error($localize `:@@CsvMapping.NotCsvFileError.msg.Text:Die Datei ist nicht im csv-Format: ` + file));
            else {
                const papaParseConfig = this.buildPapaParseConfig(config, resolve, reject);
                Papa.parse(file, papaParseConfig);
            }
        });
        return promise;
    }
    //Erweitert das ParseConfig auf ein Papa.ParseConfig
    buildPapaParseConfig(config, resolve, reject) {
        this.logger.log(CLASS + '.buildPapaParseConfig');
        const papaParseConfig = config ? { ...config } : {};
        if (!papaParseConfig.encoding)
            papaParseConfig.encoding = 'iso-8859-1';
        if (!papaParseConfig.skipEmptyLines)
            papaParseConfig.skipEmptyLines = true;
        const doReject = (errors, file) => {
            const errorMessages = errors && errors.length > 0 ? errors.map(err => $localize `:@@CsvMapping.ParseError.msg.Text:Parse Error in Reihe: ` + err.row + ': ' + err.message) : [$localize `:@@CsvMapping.PapaparseError.msg.Text:Unbekannter error in Papaparse`]; //['unknown Error in papaparse'];
            reject(new Error(errorMessages.join(', ')));
        };
        papaParseConfig.error = (error, file) => {
            doReject([error], file);
        };
        papaParseConfig.complete = (csvResult) => {
            if (csvResult.errors && csvResult.errors.length > 0)
                doReject(csvResult.errors);
            else
                resolve(csvResult.data);
        };
        return papaParseConfig;
    }
    /**
     * Nimmt die ausgelesenen Daten und das Mapping und baut daraus die Zielstruktur als JavaScript Objekte
     * @param data Die aus dem CSV ausgelesenen Daten. Können über `csvMappingService.paseCsv(file)` besorgt werden.
     * @param targetObjectDefinition Konfiguration, welche Felder im Zielformat vorhanden sein sollen.
     * Hier kann die gleiche Konfiguration wie in `csvMappingService.showDialog` verwendet werden: `{ fields: targetFields }`
     * @param mappingConfig Die Konfiguration fürs Mapping der Daten zum Zielformat. Hier kann das Ergebnis von `csvMappingService.showDialog` verwendet werden.
     */
    createTargetObjects(data, targetObjectDefinition, mappingConfig) {
        this.logger.log(CLASS + '.createTargetObjects');
        const targetObjects = Array();
        const srcHeaderRow = mappingConfig.dataContainsHeaders ? data[0] : null;
        data.forEach((srcRow, index) => {
            const isDataRow = !mappingConfig.dataContainsHeaders || index > 0;
            if (isDataRow) {
                const targetObject = this.createTargetObject(srcRow, srcHeaderRow, targetObjectDefinition, mappingConfig);
                targetObjects.push(targetObject);
            }
        });
        return targetObjects;
    }
    createTargetObject(srcRow, srcHeaderRow, targetObjectDefiniton, mappingConfig) {
        this.logger.log(CLASS + '.createTargetObject');
        const targetObject = {};
        for (const targetField of targetObjectDefiniton.fields) {
            if (!targetField)
                continue;
            const srcFieldIndex = mappingConfig.fields[targetField.fieldname];
            if (srcFieldIndex != null && srcFieldIndex != -1)
                targetObject[targetField.fieldname] = this.createTargetObjectProperty(srcRow, srcHeaderRow, srcFieldIndex, targetField, mappingConfig);
        }
        return targetObject;
    }
    createTargetObjectProperty(srcRow, srcHeaderRow, srcFieldIndex, targetField, mappingConfig) {
        let resultProperty;
        switch (targetField.type) {
            case 'dictionary':
                let srcFieldLastIndex = mappingConfig.fields[targetField.fieldname + '_lastColumn'];
                if (srcFieldLastIndex == null)
                    srcFieldLastIndex = Object.values(srcRow).length - 1;
                resultProperty = this.createTargetObjectDictionary(srcRow, srcHeaderRow, srcFieldIndex, srcFieldLastIndex, targetField.dictionaryValueType, mappingConfig.dateFormat);
                break;
            default:
                resultProperty = this.convertToType(srcRow[srcFieldIndex], targetField.type, mappingConfig.dateFormat);
        }
        return resultProperty;
    }
    createTargetObjectDictionary(srcRow, srcHeaderRow, srcStartIndex, srcEndIndex, targetDictionaryValueType, targetDateFormat) {
        const result = [];
        for (let srcFieldIndex = srcStartIndex; srcFieldIndex <= srcEndIndex; srcFieldIndex++) {
            const item = new KeyValueObject();
            item.key = srcHeaderRow ? srcHeaderRow[srcFieldIndex] : (srcFieldIndex - srcStartIndex).toString();
            item.value = this.convertToType(srcRow[srcFieldIndex], targetDictionaryValueType, targetDateFormat);
            result.push(item);
        }
        return result;
    }
    convertToType(srcValue, valueType, srcDateFormat) {
        this.logger.log(CLASS + '.convertToTargetType');
        if (srcValue == null)
            return null;
        srcValue = this.convertJaDateStringToDate(srcValue, valueType);
        switch (valueType) {
            case 'number':
                return Number(srcValue.replace(',', '.'));
            case 'boolean':
                return srcValue != 'null' && srcValue != '0' && srcValue != '' && srcValue != 'false';
            case 'dateIso':
                return moment(srcValue, srcDateFormat).format('YYYY-MM-DD');
            case 'date':
                return moment(srcValue, srcDateFormat).toDate();
            case 'string[]':
                return srcValue.split(',');
            default:
                return srcValue;
        }
    }
    /**im Mitgliederimport L2 kann man das Datum eines Zertifikats mit Ja beantworten, wenn kein Datum bekannt ist*/
    convertJaDateStringToDate(srcValue, valueType) {
        if (srcValue === 'Ja' && (valueType === 'date' || valueType === 'dateIso'))
            srcValue = new Date().toLocaleDateString();
        return srcValue;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CsvMappingService, deps: [{ token: CsvMappingDialog }, { token: i2.LoggerService }, { token: i3.UserPropertiesStorageService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CsvMappingService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CsvMappingService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: () => [{ type: CsvMappingDialog }, { type: i2.LoggerService }, { type: i3.UserPropertiesStorageService }] });
class MappingConfigStorageHelper {
    constructor(storageKeyBase, storage) {
        this.storage = storage;
        this.storageKey = null;
        if (storageKeyBase && storageKeyBase.length > 0)
            this.storageKey = storageKeyBase + '.' + STORAGE_KEY_MAPPING_CONFIG;
    }
    storageIsActive() {
        return this.storageKey && this.storageKey.length > 0;
    }
    load() {
        if (!this.storageIsActive())
            return null;
        return this.storage.load(this.storageKey);
    }
    save(mappingObject) {
        if (!this.storageIsActive())
            return;
        this.storage.save(this.storageKey, mappingObject);
    }
}
class TargetObjectDefinition {
}
class TargetField {
    constructor() {
        this.type = 'string';
    }
}
class KeyValueObject {
}

class CsvMapping {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CsvMapping, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.13", ngImport: i0, type: CsvMapping, imports: [CommonModule,
            SwtGenericModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CsvMapping, imports: [CommonModule,
            SwtGenericModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CsvMapping, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        SwtGenericModule,
                    ],
                    providers: [],
                    declarations: []
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { CsvMapping, CsvMappingService, TargetObjectDefinition };
//# sourceMappingURL=sowatech-shared-csv-mapping.mjs.map
