import 'moment/locale/de';
import * as i0 from '@angular/core';
import { LOCALE_ID, Inject, Injectable } from '@angular/core';
import moment from 'moment';
import * as Papa from 'papaparse';
import { Observable } from 'rxjs';

class CsvCreateObjectConfig {
    constructor() {
        this.nullValue = 'NULL';
    }
    copy(config) {
        this.configFields = new Array();
        this.nullValue = config.nullValue;
        for (const field of config.configFields) {
            const configField = new CsvCreateObjectField();
            for (const prop in field)
                configField[prop] = field[prop];
            this.configFields.push(configField);
        }
    }
}
class CsvCreateObjectField {
    constructor() {
        this.dateFormat = 'DD-MM-YYYY';
    }
}

class CsvService {
    constructor(_locale) {
        this._locale = _locale;
    }
    unparse(arg, config) {
        if (!config) {
            config = {
                quotes: true,
                delimiter: ';',
                newline: '\r'
            };
        }
        let result = '';
        if (arg instanceof Array && arg.every(elem => elem instanceof Object)) {
            const unparsedObjects = this.cleanseObjectsForUnparse(arg);
            result = Papa.unparse(unparsedObjects, config);
        }
        else
            result = Papa.unparse(arg, config);
        return result;
    }
    cleanseObjectsForUnparse(inputObject) {
        const resultObjects = [];
        for (const item of inputObject) {
            const obj = new Object();
            for (const prop in item) {
                if (typeof item[prop] !== 'function' && !(item[prop] instanceof Array))
                    obj[prop] = item[prop];
                if (typeof item[prop] === 'number') {
                    if (this._locale != 'en-US')
                        obj[prop] = item[prop].toString().replace('.', ',');
                }
            }
            resultObjects.push(obj);
        }
        return resultObjects;
    }
    downloadCsv(data, fileName) {
        const blob = new Blob(['\ufeff', data]);
        const tempLink = document.createElement('a');
        tempLink.href = window.URL.createObjectURL(blob);
        tempLink.setAttribute('download', fileName + '.csv');
        document.body.appendChild(tempLink);
        tempLink.click();
        document.body.removeChild(tempLink);
    }
    parseCsv(arg1, config) {
        const observable = Observable.create(anyObserver => {
            const observer = anyObserver;
            const file = typeof arg1 === 'string' ? null : arg1;
            if (file && file.name.indexOf('.csv') < 0)
                observer.error({ error: { message: 'file is no csv-file' }, file });
            else {
                const parseConfig = config ? { ...config } : {};
                if (!parseConfig.encoding)
                    parseConfig.encoding = 'iso-8859-1';
                parseConfig.error = (error, file) => {
                    observer.error({ error, file });
                    observer.complete();
                };
                parseConfig.complete = (results, file) => {
                    observer.next(results);
                    observer.complete();
                };
                Papa.parse(arg1, parseConfig);
            }
        });
        return observable;
    }
    getCsvAsObjects(conf, csvResult) {
        console.log('getCsvAsObjects');
        const result = [];
        if (csvResult && csvResult.data && csvResult.data.length > 1) {
            const config = new CsvCreateObjectConfig();
            config.copy(conf);
            const header = csvResult.data[0];
            for (let rowIndex = 0; rowIndex < csvResult.data.length; rowIndex++) {
                const row = csvResult.data[rowIndex];
                const obj = {};
                for (const field of config.configFields) {
                    const index = header.findIndex(h => h.toLowerCase() == field.fieldname.toLowerCase());
                    switch (field.type) {
                        case 'string':
                            obj[field.fieldname] = row[index] === conf.nullValue ? null : row[index];
                            break;
                        case 'boolean':
                            obj[field.fieldname] = row[index] === conf.nullValue ? null : row[index];
                            break;
                        case 'number':
                            if (row[index])
                                obj[field.fieldname] = row[index] === conf.nullValue ? null : row[index].replace(',', '.');
                            break;
                        case 'Date':
                            obj[field.fieldname] = row[index] === conf.nullValue ? null : moment(row[index], field.dateFormat).format('YYYY-MM-DD');
                            break;
                        case 'DateTime':
                            obj[field.fieldname] = row[index] === conf.nullValue ? null : moment(row[index], field.dateFormat).toDate();
                            break;
                        case 'string[]':
                            if (row.length >= index)
                                obj[field.fieldname] = row[index] === conf.nullValue ? null : row[index].split(field.stringArraySeparator);
                            break;
                    }
                }
                result.push(obj);
            }
        }
        return result;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CsvService, deps: [{ token: LOCALE_ID }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CsvService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CsvService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [LOCALE_ID]
                }] }] });

/**
 * Generated bundle index. Do not edit.
 */

export { CsvCreateObjectConfig, CsvCreateObjectField, CsvService };
//# sourceMappingURL=sowatech-shared-csv.mjs.map
