import * as i0 from '@angular/core';
import { Injectable, signal, EventEmitter, ViewChild, Output, HostListener, Component, Input, inject, DestroyRef, Directive, NgModule } from '@angular/core';
import * as i1 from '@sowatech/shared/logger';
import * as i2 from '@sowatech/shared/shared-config';
import * as i3 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i4 from 'ngx-bootstrap/modal';
import { ModalModule } from 'ngx-bootstrap/modal';
import * as i5 from '@sowatech/shared/no-double-click';
import { NoDblClickModule } from '@sowatech/shared/no-double-click';
import * as i6 from '@sowatech/shared/template';
import { SwitchTemplateModule } from '@sowatech/shared/template';
import * as i1$1 from '@angular/forms';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';

class MessageBoxService {
    //service zum globalen aufruf des confirmation dialogs. nur einmal zentral providen für zugriff auf gleiche membervariablen
    constructor(logger) {
        this.logger = logger;
    }
    registerComponent(messageBoxComponent) {
        if (!messageBoxComponent)
            this.logger.error('MessageBoxService.registerDialog called with undefined dialog');
        this.registeredComponent = messageBoxComponent;
    }
    showDialog(text, title, messageType, messageButtons) {
        return this.registeredComponent.show(text, title, messageType, messageButtons);
    }
    confirmDialog(text, title) {
        return this.registeredComponent.showConfirm(text, title);
    }
    infoDialog(text, title) {
        return this.registeredComponent.showClose(text, title);
    }
    errorDialog(text, title) {
        return this.registeredComponent.showClose(text, title, MessageType.ERROR);
    }
    closeDialog() {
        this.registeredComponent.closeDialog();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: MessageBoxService, deps: [{ token: i1.LoggerService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: MessageBoxService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: MessageBoxService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: () => [{ type: i1.LoggerService }] });
var MessageButtons;
(function (MessageButtons) {
    MessageButtons[MessageButtons["OK_CANCEL"] = 0] = "OK_CANCEL";
    MessageButtons[MessageButtons["YES_NO"] = 1] = "YES_NO";
    MessageButtons[MessageButtons["YES_NO_CANCEL"] = 2] = "YES_NO_CANCEL";
    MessageButtons[MessageButtons["CLOSE"] = 3] = "CLOSE";
})(MessageButtons || (MessageButtons = {}));
var MessageType;
(function (MessageType) {
    MessageType[MessageType["PLAIN"] = 0] = "PLAIN";
    MessageType[MessageType["ERROR"] = 1] = "ERROR";
    MessageType[MessageType["INFORMATION"] = 2] = "INFORMATION";
    MessageType[MessageType["WARNING"] = 3] = "WARNING";
    MessageType[MessageType["QUESTION"] = 4] = "QUESTION";
})(MessageType || (MessageType = {}));
var DialogResult;
(function (DialogResult) {
    DialogResult[DialogResult["OK"] = 0] = "OK";
    DialogResult[DialogResult["CANCEL"] = 1] = "CANCEL";
    DialogResult[DialogResult["YES"] = 2] = "YES";
    DialogResult[DialogResult["NO"] = 3] = "NO";
    DialogResult[DialogResult["CLOSE"] = 4] = "CLOSE";
})(DialogResult || (DialogResult = {}));

class MessageBoxComponent {
    constructor(messageBoxService, sharedConfig) {
        this.messageBoxService = messageBoxService;
        this.timeStamp = signal(new Date());
        this.subscriptions = [];
        this.messageButtons = MessageButtons.OK_CANCEL;
        this.messageType = MessageType.PLAIN;
        this.cancel = new EventEmitter();
        this.submitWithOk = new EventEmitter();
        this.MessageType = MessageType;
        this.disableAnimation = sharedConfig.disableModalAnimation;
    }
    handleKeyboardEvent(event) {
        if (event.code && event.code.toUpperCase() == 'ENTER' && event.ctrlKey == true) {
            if (this.dialog.isShown && this.btnVisible(this.btnOk.nativeElement)) {
                this.btnClicked(this.btnOk.nativeElement);
                event.preventDefault();
            }
        }
    }
    ngOnInit() {
        this.subscriptions.push(this.dialog.onHidden.subscribe(() => this.closeModalFix()));
    }
    closeModalFix() {
        //fix weil modal-open nicht herausgenommen wird wenn ein 2ter Dialog geoeffnet wird
        document.body.classList.remove('modal-open');
        document.body.style.paddingRight = '0px';
        document.body.style.overflowY = '';
    }
    ngOnDestroy() {
        for (const s of this.subscriptions)
            s.unsubscribe();
    }
    ngAfterViewInit() {
        this.messageBoxService.registerComponent(this);
    }
    show(text, title, messageType, messageButtons) {
        this.timeStamp.set(new Date());
        return new Promise((resolve, reject) => {
            this.text = text;
            this.title = title;
            this.messageType = messageType || MessageType.PLAIN;
            this.messageButtons = messageButtons || MessageButtons.OK_CANCEL;
            switch (this.messageType) {
                case MessageType.ERROR:
                    this.iconClass = 'fas fa-exclamation-circle text-danger';
                    break;
                case MessageType.INFORMATION:
                    this.iconClass = 'fas fa-info-circle text-info';
                    break;
                case MessageType.WARNING:
                    this.iconClass = 'fas fa-exclamation-triangle text-warning';
                    break;
                case MessageType.QUESTION:
                    this.iconClass = 'fas fa-question-circle text-default';
                    break;
                default:
                    this.iconClass = 'hidden';
                    break;
            }
            if (this.dialog.backdrop)
                setTimeout(() => { this.dialog.show(); }, 500);
            else
                this.dialog.show();
            this.resolve = resolve;
            this.reject = reject;
        });
    }
    showConfirm(text, title) {
        return new Promise((resolve, reject) => {
            this.show(text, title, MessageType.QUESTION, MessageButtons.OK_CANCEL)
                .then((dialogResult) => {
                if (dialogResult == DialogResult.OK)
                    resolve();
            })
                .catch(() => {
                reject();
            });
        });
    }
    showClose(text, title, messageType = MessageType.INFORMATION) {
        return new Promise((resolve, reject) => {
            this.show(text, title, messageType, MessageButtons.CLOSE)
                .then((dialogResult) => {
                resolve();
            })
                .catch(() => {
                reject();
            });
        });
    }
    hideDialog() {
        this.dialog.hide();
    }
    closeDialog() {
        this.hideDialog();
        this.resolve(DialogResult.CLOSE);
    }
    btnClicked(btn) {
        this.hideDialog();
        this.resolve(DialogResult[btn.value]);
    }
    btnVisible(btn) {
        let result = false;
        const dialogResult = DialogResult[btn.value];
        switch (dialogResult) {
            case DialogResult.CANCEL:
                result = this.messageButtons == MessageButtons.OK_CANCEL || this.messageButtons == MessageButtons.YES_NO_CANCEL;
                break;
            case DialogResult.CLOSE:
                result = this.messageButtons == MessageButtons.CLOSE;
                break;
            case DialogResult.NO:
            case DialogResult.YES:
                result = this.messageButtons == MessageButtons.YES_NO || this.messageButtons == MessageButtons.YES_NO_CANCEL;
                break;
            case DialogResult.OK:
                result = this.messageButtons == MessageButtons.OK_CANCEL;
                break;
        }
        return result;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: MessageBoxComponent, deps: [{ token: MessageBoxService }, { token: i2.SharedConfigService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.13", type: MessageBoxComponent, isStandalone: false, selector: "message-box", outputs: { cancel: "cancel", submitWithOk: "submitWithOk" }, host: { listeners: { "document:keypress": "handleKeyboardEvent($event)" } }, viewQueries: [{ propertyName: "dialog", first: true, predicate: ["dialog"], descendants: true, static: true }, { propertyName: "btnOk", first: true, predicate: ["btnOk"], descendants: true, static: true }], ngImport: i0, template: "<div bsModal #dialog=\"bs-modal\" class=\"modal\" [ngClass]=\"disableAnimation ? '' : 'fade'\" tabindex=\"-1\" role=\"dialog\">\r\n    <div class=\"modal-dialog modal-md\">\r\n        <div class=\"modal-content\">\r\n            <div class=\"modal-header\" [hidden]=\"!title\">\r\n                <button *ifInspinia=\"true\" id=\"btn-close-dialog\" type=\"button\" class=\"close\" (click)=\"closeDialog()\"\r\n                        aria-label=\"Close\">\r\n                    <span aria-hidden=\"true\">&times;</span>\r\n                </button>\r\n                <h4 class=\"modal-title\">{{title}}</h4>\r\n                <button *ifSneat=\"true\" id=\"btn-close-dialog\" type=\"button\" class=\"btn-close\" (click)=\"closeDialog()\"\r\n                        aria-label=\"Close\">\r\n                </button>\r\n            </div>\r\n            <div class=\"modal-body\">\r\n                <i inspinia-class=\"pull-left m-r-md\" sneat-class=\"float-start me-3\" [ngClass]=\"iconClass\"\r\n                   style=\"font-size:35px\"></i>\r\n                <div [innerHTML]=\"text\"></div>\r\n            </div>\r\n            <div class=\"modal-footer\">\r\n                @if (messageType === MessageType.ERROR) {\r\n                    <!-- inspinia: line height, damit text mit buttons aligned ist -->\r\n                    <span inspinia-class=\"pull-left line-height-btn\" sneat-class=\"me-auto\" class=\"text-muted\">{{ timeStamp() | date:'medium' }}</span>\r\n                }\r\n                <span [hidden]=\"!btnVisible(btnCancel)\">\r\n                    <button id=\"btn-cancel\" #btnCancel value=\"CANCEL\" type=\"button\" class=\"btn btn-default\"\r\n                            (click)=\"btnClicked(btnCancel)\" i18n=\"@@Dialogs.Cancel.act.Label\">Abbrechen</button>\r\n                </span>\r\n                <span [hidden]=\"!btnVisible(btnOk)\">\r\n                    <button id=\"btn-ok\" #btnOk value=\"OK\" type=\"button\" class=\"btn btn-primary\"\r\n                            (click)=\"btnClicked(btnOk)\" i18n=\"@@Dialogs.Ok.act.Label\">OK</button>\r\n                </span>\r\n                <span [hidden]=\"!btnVisible(btnYes)\">\r\n                    <button id=\"btn-yes\" #btnYes value=\"YES\" type=\"button\" class=\"btn btn-success\"\r\n                            (click)=\"btnClicked(btnYes)\" i18n=\"@@Dialogs.Yes.act.Label\">Ja</button>\r\n                </span>\r\n                <span [hidden]=\"!btnVisible(btnNo)\">\r\n                    <button id=\"btn-no\" #btnNo value=\"NO\" [hidden]=\"!btnVisible(btnNo)\" type=\"button\"\r\n                            class=\"btn btn-danger\" (click)=\"btnClicked(btnNo)\" i18n=\"@@Dialogs.No.act.Label\">Nein</button>\r\n                </span>\r\n                <span [hidden]=\"!btnVisible(btnClose)\">\r\n                    <button id=\"btn-close\" #btnClose value=\"CLOSE\" [hidden]=\"!btnVisible(btnClose)\" type=\"button\"\r\n                            class=\"btn btn-default\" (click)=\"btnClicked(btnClose)\" i18n=\"@@Dialogs.Close.act.Label\">Schlie\u00DFen</button>\r\n                </span>\r\n            </div>\r\n        </div>\r\n    </div>\r\n</div>\r\n", styles: [".modal-footer button{margin-left:3px}\n", ".modal-footer .line-height-btn{line-height:34px}\n"], dependencies: [{ kind: "directive", type: i3.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i4.ModalDirective, selector: "[bsModal]", inputs: ["config", "closeInterceptor"], outputs: ["onShow", "onShown", "onHide", "onHidden"], exportAs: ["bs-modal"] }, { kind: "directive", type: i5.NoDblClickButtonDirective, selector: "button:not([disable-no-double-click])" }, { kind: "directive", type: i6.InspiniaCssClassDirective, selector: "[inspinia-class]", inputs: ["inspinia-class"] }, { kind: "directive", type: i6.SneatCssClassDirective, selector: "[sneat-class]", inputs: ["sneat-class"] }, { kind: "directive", type: i6.IfInspiniaDirective, selector: "[ifInspinia]", inputs: ["ifInspinia"] }, { kind: "directive", type: i6.IfSneatDirective, selector: "[ifSneat]", inputs: ["ifSneat"] }, { kind: "pipe", type: i3.DatePipe, name: "date" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: MessageBoxComponent, decorators: [{
            type: Component,
            args: [{ selector: 'message-box', standalone: false, template: "<div bsModal #dialog=\"bs-modal\" class=\"modal\" [ngClass]=\"disableAnimation ? '' : 'fade'\" tabindex=\"-1\" role=\"dialog\">\r\n    <div class=\"modal-dialog modal-md\">\r\n        <div class=\"modal-content\">\r\n            <div class=\"modal-header\" [hidden]=\"!title\">\r\n                <button *ifInspinia=\"true\" id=\"btn-close-dialog\" type=\"button\" class=\"close\" (click)=\"closeDialog()\"\r\n                        aria-label=\"Close\">\r\n                    <span aria-hidden=\"true\">&times;</span>\r\n                </button>\r\n                <h4 class=\"modal-title\">{{title}}</h4>\r\n                <button *ifSneat=\"true\" id=\"btn-close-dialog\" type=\"button\" class=\"btn-close\" (click)=\"closeDialog()\"\r\n                        aria-label=\"Close\">\r\n                </button>\r\n            </div>\r\n            <div class=\"modal-body\">\r\n                <i inspinia-class=\"pull-left m-r-md\" sneat-class=\"float-start me-3\" [ngClass]=\"iconClass\"\r\n                   style=\"font-size:35px\"></i>\r\n                <div [innerHTML]=\"text\"></div>\r\n            </div>\r\n            <div class=\"modal-footer\">\r\n                @if (messageType === MessageType.ERROR) {\r\n                    <!-- inspinia: line height, damit text mit buttons aligned ist -->\r\n                    <span inspinia-class=\"pull-left line-height-btn\" sneat-class=\"me-auto\" class=\"text-muted\">{{ timeStamp() | date:'medium' }}</span>\r\n                }\r\n                <span [hidden]=\"!btnVisible(btnCancel)\">\r\n                    <button id=\"btn-cancel\" #btnCancel value=\"CANCEL\" type=\"button\" class=\"btn btn-default\"\r\n                            (click)=\"btnClicked(btnCancel)\" i18n=\"@@Dialogs.Cancel.act.Label\">Abbrechen</button>\r\n                </span>\r\n                <span [hidden]=\"!btnVisible(btnOk)\">\r\n                    <button id=\"btn-ok\" #btnOk value=\"OK\" type=\"button\" class=\"btn btn-primary\"\r\n                            (click)=\"btnClicked(btnOk)\" i18n=\"@@Dialogs.Ok.act.Label\">OK</button>\r\n                </span>\r\n                <span [hidden]=\"!btnVisible(btnYes)\">\r\n                    <button id=\"btn-yes\" #btnYes value=\"YES\" type=\"button\" class=\"btn btn-success\"\r\n                            (click)=\"btnClicked(btnYes)\" i18n=\"@@Dialogs.Yes.act.Label\">Ja</button>\r\n                </span>\r\n                <span [hidden]=\"!btnVisible(btnNo)\">\r\n                    <button id=\"btn-no\" #btnNo value=\"NO\" [hidden]=\"!btnVisible(btnNo)\" type=\"button\"\r\n                            class=\"btn btn-danger\" (click)=\"btnClicked(btnNo)\" i18n=\"@@Dialogs.No.act.Label\">Nein</button>\r\n                </span>\r\n                <span [hidden]=\"!btnVisible(btnClose)\">\r\n                    <button id=\"btn-close\" #btnClose value=\"CLOSE\" [hidden]=\"!btnVisible(btnClose)\" type=\"button\"\r\n                            class=\"btn btn-default\" (click)=\"btnClicked(btnClose)\" i18n=\"@@Dialogs.Close.act.Label\">Schlie\u00DFen</button>\r\n                </span>\r\n            </div>\r\n        </div>\r\n    </div>\r\n</div>\r\n", styles: [".modal-footer button{margin-left:3px}\n", ".modal-footer .line-height-btn{line-height:34px}\n"] }]
        }], ctorParameters: () => [{ type: MessageBoxService }, { type: i2.SharedConfigService }], propDecorators: { handleKeyboardEvent: [{
                type: HostListener,
                args: ['document:keypress', ['$event']]
            }], cancel: [{
                type: Output
            }], submitWithOk: [{
                type: Output
            }], dialog: [{
                type: ViewChild,
                args: ['dialog', { static: true }]
            }], btnOk: [{
                type: ViewChild,
                args: ['btnOk', { static: true }]
            }] } });

class FileDialogComponent {
    constructor() {
        this.onOk = new EventEmitter();
    }
    show() {
        this.file.nativeElement.click();
    }
    ok(fileList) {
        this.onOk.emit(fileList);
        this.dialogForm.nativeElement.reset();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: FileDialogComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: FileDialogComponent, isStandalone: false, selector: "file-dialog", inputs: { extensions: "extensions", multiple: "multiple" }, outputs: { onOk: "onOk" }, viewQueries: [{ propertyName: "file", first: true, predicate: ["file"], descendants: true, static: true }, { propertyName: "dialogForm", first: true, predicate: ["dialogForm"], descendants: true, static: true }], ngImport: i0, template: '<form #dialogForm style="position:fixed;left:-9999px"><input type="file" #file (change)="ok(file.files)" style="display:none;" multiple="{{multiple}}" accept="{{extensions}}" /></form>', isInline: true, dependencies: [{ kind: "directive", type: i1$1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1$1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i1$1.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: FileDialogComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'file-dialog',
                    template: '<form #dialogForm style="position:fixed;left:-9999px"><input type="file" #file (change)="ok(file.files)" style="display:none;" multiple="{{multiple}}" accept="{{extensions}}" /></form>',
                    standalone: false
                }]
        }], ctorParameters: () => [], propDecorators: { extensions: [{
                type: Input
            }], multiple: [{
                type: Input
            }], onOk: [{
                type: Output
            }], file: [{
                type: ViewChild,
                args: ['file', { static: true }]
            }], dialogForm: [{
                type: ViewChild,
                args: ['dialogForm', { static: true }]
            }] } });

class BackdropPrintComponent {
    ngOnInit() {
        document.body.classList.add('no-scrollbar'); /* prevents double scroll bars*/
    }
    ngOnDestroy() {
        document.body.classList.remove('no-scrollbar');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: BackdropPrintComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: BackdropPrintComponent, isStandalone: false, selector: "backdrop-print", ngImport: i0, template: `
        <div class="print-backdrop backdrop-bg">
            <div class="print-content-wrapper">
              <div class="print-content">
                    <ng-content></ng-content>
              </div>
            </div>
        </div>`, isInline: true, styles: ["@media print{.print-backdrop{overflow-y:initial;position:initial;height:initial}.print-content{position:initial}}@media screen{.print-backdrop{overflow-y:scroll;position:fixed;width:100%;min-height:100%;inset:0;z-index:9001;background-color:silver!important}.print-content-wrapper{display:flex;justify-content:center}.print-content{position:absolute;width:21cm;padding:1.5cm;min-height:100%;background-color:#fff}}\n"] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: BackdropPrintComponent, decorators: [{
            type: Component,
            args: [{ selector: 'backdrop-print', template: `
        <div class="print-backdrop backdrop-bg">
            <div class="print-content-wrapper">
              <div class="print-content">
                    <ng-content></ng-content>
              </div>
            </div>
        </div>`, standalone: false, styles: ["@media print{.print-backdrop{overflow-y:initial;position:initial;height:initial}.print-content{position:initial}}@media screen{.print-backdrop{overflow-y:scroll;position:fixed;width:100%;min-height:100%;inset:0;z-index:9001;background-color:silver!important}.print-content-wrapper{display:flex;justify-content:center}.print-content{position:absolute;width:21cm;padding:1.5cm;min-height:100%;background-color:#fff}}\n"] }]
        }] });

class BackdropComponent {
    ngOnInit() {
        document.body.classList.add('no-scrollbar'); /* prevents double scroll bars*/
    }
    ngOnDestroy() {
        document.body.classList.remove('no-scrollbar');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: BackdropComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: BackdropComponent, isStandalone: false, selector: "backdrop", ngImport: i0, template: `
        <div style="position: fixed;width: 100%;height: 100%;overflow-y: scroll;left: 0;right: 0;top: 0;bottom: 0;z-index: 2001;" class="backdrop-bg">
            <div style="position: absolute;width: 100%;height: 100%;">
                <ng-content></ng-content>
            </div>
        </div>`, isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: BackdropComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'backdrop',
                    template: `
        <div style="position: fixed;width: 100%;height: 100%;overflow-y: scroll;left: 0;right: 0;top: 0;bottom: 0;z-index: 2001;" class="backdrop-bg">
            <div style="position: absolute;width: 100%;height: 100%;">
                <ng-content></ng-content>
            </div>
        </div>`,
                    standalone: false
                }]
        }] });

class CustomContentDialogComponent {
    constructor() {
        this.modalTitle = '';
        this.animate = true;
        this.size = 'md';
    }
    open() {
        this.modalDialog.show();
    }
    close() {
        this.modalDialog.hide();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CustomContentDialogComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: CustomContentDialogComponent, isStandalone: false, selector: "custom-content-dialog", inputs: { modalTitle: "modalTitle", animate: "animate", size: "size" }, viewQueries: [{ propertyName: "modalDialog", first: true, predicate: ["modalDialog"], descendants: true, static: true }], ngImport: i0, template: "<div bsModal #modalDialog=\"bs-modal\" class=\"modal\" tabindex=\"-1\" role=\"dialog\" [ngClass]=\"animate ? 'fade' : ''\">\r\n    <div class=\"modal-dialog\" [ngClass]=\"{'modal-sm': size === 'sm', 'modal-lg': size === 'lg'}\">\r\n        <div class=\"modal-content\">\r\n            <div class=\"modal-header\">\r\n                <button *ifInspinia=\"true\" type=\"button\" class=\"close\" (click)=\"close()\" aria-label=\"Close\">\r\n                    <i aria-hidden=\"true\" class=\"fa fa-times\"></i>\r\n                </button>\r\n                <h4 class=\"modal-title\">{{modalTitle}}</h4>\r\n                <button *ifSneat=\"true\" type=\"button\" class=\"btn-close\" (click)=\"close()\" aria-label=\"Close\">\r\n                </button>\r\n            </div>\r\n            <div class=\"modal-body\">\r\n                <ng-content></ng-content>\r\n            </div>\r\n            <div #contentHeadingWrapper [ngClass]=\"contentHeadingWrapper.children.length === 0 ? 'hidden' : 'modal-footer'\">\r\n                <ng-content select=\"[footer]\"></ng-content>\r\n            </div>\r\n        </div>\r\n    </div>\r\n</div>", dependencies: [{ kind: "directive", type: i3.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i4.ModalDirective, selector: "[bsModal]", inputs: ["config", "closeInterceptor"], outputs: ["onShow", "onShown", "onHide", "onHidden"], exportAs: ["bs-modal"] }, { kind: "directive", type: i5.NoDblClickButtonDirective, selector: "button:not([disable-no-double-click])" }, { kind: "directive", type: i6.IfInspiniaDirective, selector: "[ifInspinia]", inputs: ["ifInspinia"] }, { kind: "directive", type: i6.IfSneatDirective, selector: "[ifSneat]", inputs: ["ifSneat"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CustomContentDialogComponent, decorators: [{
            type: Component,
            args: [{ selector: 'custom-content-dialog', standalone: false, template: "<div bsModal #modalDialog=\"bs-modal\" class=\"modal\" tabindex=\"-1\" role=\"dialog\" [ngClass]=\"animate ? 'fade' : ''\">\r\n    <div class=\"modal-dialog\" [ngClass]=\"{'modal-sm': size === 'sm', 'modal-lg': size === 'lg'}\">\r\n        <div class=\"modal-content\">\r\n            <div class=\"modal-header\">\r\n                <button *ifInspinia=\"true\" type=\"button\" class=\"close\" (click)=\"close()\" aria-label=\"Close\">\r\n                    <i aria-hidden=\"true\" class=\"fa fa-times\"></i>\r\n                </button>\r\n                <h4 class=\"modal-title\">{{modalTitle}}</h4>\r\n                <button *ifSneat=\"true\" type=\"button\" class=\"btn-close\" (click)=\"close()\" aria-label=\"Close\">\r\n                </button>\r\n            </div>\r\n            <div class=\"modal-body\">\r\n                <ng-content></ng-content>\r\n            </div>\r\n            <div #contentHeadingWrapper [ngClass]=\"contentHeadingWrapper.children.length === 0 ? 'hidden' : 'modal-footer'\">\r\n                <ng-content select=\"[footer]\"></ng-content>\r\n            </div>\r\n        </div>\r\n    </div>\r\n</div>" }]
        }], propDecorators: { modalDialog: [{
                type: ViewChild,
                args: ['modalDialog', { static: true }]
            }], modalTitle: [{
                type: Input
            }], animate: [{
                type: Input
            }], size: [{
                type: Input
            }] } });

//import { Control } from '@angular/common';
class DialogInitDirective {
    constructor(el, logger) {
        this.logger = logger;
        this.destroyRef = inject(DestroyRef);
        /**
         * Selector für das Element, das beim Öffnen des Dialogs fokussiert werden soll.
         * Wird beim Schließen des Dialogs zurückgesetzt.
         * Ist nötig, da beim Aufruf der Fokus-Methode eventuell das Element noch nicht existiert.
         */
        this.focusedSelector = null;
        this.nativeElement = el.nativeElement;
    }
    ngAfterViewInit() {
        this.dialog.onShown
            .pipe(takeUntilDestroyed(this.destroyRef))
            .subscribe(() => this.onDialogShown());
        this.dialog.onHidden
            .pipe(takeUntilDestroyed(this.destroyRef))
            .subscribe(() => this.onDialogHidden());
    }
    focus(fieldname) {
        this.focusedSelector = `#${fieldname}`;
        const elements = this.nativeElement.querySelectorAll(this.focusedSelector);
        this.focusFirstElement(elements);
    }
    onDialogShown() {
        //select fist tab
        const tabsets = this.nativeElement.getElementsByClassName('nav-tabs');
        if (tabsets && tabsets.length > 0) {
            const tabset = tabsets[0];
            const tabpages = tabset.getElementsByClassName('nav-link');
            if (tabpages) {
                const tabpage = tabpages[0];
                if (tabpage)
                    tabpage.click();
            }
        }
        //1) select previous determined element
        let focusElements = this.nativeElement.querySelectorAll(this.focusedSelector);
        if (focusElements.length === 0) {
            //2) select element with attribute autofocus
            focusElements = this.nativeElement.querySelectorAll('[autofocus]');
        }
        if (focusElements.length === 0) {
            //3) select first input control
            focusElements = this.nativeElement.getElementsByTagName('input');
        }
        if (focusElements.length === 0) {
            //4) select first select control
            focusElements = this.nativeElement.getElementsByTagName('select');
        }
        this.focusFirstElement(focusElements);
    }
    onDialogHidden() {
        this.focusedSelector = null;
    }
    focusFirstElement(focusElements) {
        if (focusElements.length > 0) {
            const el = focusElements[0];
            el.focus();
            const inputEl = el;
            if (inputEl.select)
                inputEl.select();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: DialogInitDirective, deps: [{ token: i0.ElementRef }, { token: i1.LoggerService }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.13", type: DialogInitDirective, isStandalone: false, selector: "[dialog-init]", inputs: { dialog: ["dialog-init", "dialog"] }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: DialogInitDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[dialog-init]',
                    standalone: false
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i1.LoggerService }], propDecorators: { dialog: [{
                type: Input,
                args: ['dialog-init']
            }] } });

const ModalModuleForRoot = ModalModule.forRoot();
class DialogsModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: DialogsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.13", ngImport: i0, type: DialogsModule, declarations: [FileDialogComponent,
            MessageBoxComponent,
            DialogInitDirective,
            BackdropPrintComponent,
            BackdropComponent,
            CustomContentDialogComponent], imports: [CommonModule, i4.ModalModule, FormsModule,
            ReactiveFormsModule,
            NoDblClickModule,
            SwitchTemplateModule], exports: [FileDialogComponent,
            MessageBoxComponent,
            DialogInitDirective,
            BackdropComponent,
            BackdropPrintComponent,
            ModalModule,
            CustomContentDialogComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: DialogsModule, imports: [CommonModule,
            ModalModuleForRoot,
            FormsModule,
            ReactiveFormsModule,
            NoDblClickModule,
            SwitchTemplateModule, ModalModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: DialogsModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        ModalModuleForRoot,
                        FormsModule,
                        ReactiveFormsModule,
                        NoDblClickModule,
                        SwitchTemplateModule,
                    ],
                    declarations: [
                        FileDialogComponent,
                        MessageBoxComponent,
                        DialogInitDirective,
                        BackdropPrintComponent,
                        BackdropComponent,
                        CustomContentDialogComponent,
                    ],
                    exports: [
                        FileDialogComponent,
                        MessageBoxComponent,
                        DialogInitDirective,
                        BackdropComponent,
                        BackdropPrintComponent,
                        ModalModule,
                        CustomContentDialogComponent,
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { BackdropComponent, BackdropPrintComponent, CustomContentDialogComponent, DialogInitDirective, DialogResult, DialogsModule, FileDialogComponent, MessageBoxComponent, MessageBoxService, MessageButtons, MessageType };
//# sourceMappingURL=sowatech-shared-dialogs.mjs.map
