import * as i1 from '@angular/common';
import { WeekDay, getLocaleFirstDayOfWeek, CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { EventEmitter, Input, Output, ContentChild, Component, NgModule } from '@angular/core';
import { FormsModule } from '@angular/forms';
import * as i2 from '@fullcalendar/angular';
import { FullCalendarModule } from '@fullcalendar/angular';
import * as i3 from '@sowatech/shared/template';
import { SwitchTemplateModule } from '@sowatech/shared/template';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import dayGridPlugin from '@fullcalendar/daygrid';
import interactionPlugin from '@fullcalendar/interaction';
import listPlugin from '@fullcalendar/list';
import timeGridPlugin from '@fullcalendar/timegrid';
import { Subject, debounceTime } from 'rxjs';
import { createPlugin } from '@fullcalendar/core';
import { Theme } from '@fullcalendar/core/internal';

const defaultCalendarSettings = {
    startTime: 8,
    endTime: 18,
    visibleDays: [
        WeekDay.Monday,
        WeekDay.Tuesday,
        WeekDay.Wednesday,
        WeekDay.Thursday,
        WeekDay.Friday,
    ],
    slotDuration: '00:15:00'
};

class FontAwesomeTheme extends Theme {
}
FontAwesomeTheme.prototype.classes = {
    root: 'fc-theme-standard',
    tableCellShaded: 'fc-cell-shaded',
    buttonGroup: 'fc-button-group',
    button: 'fc-button fc-button-primary',
    buttonActive: 'fc-button-active',
    popover: 'popover',
    popoverHeader: 'popover-header',
    popoverContent: 'popover-body',
};
FontAwesomeTheme.prototype.baseIconClass = 'fa-icon fa';
FontAwesomeTheme.prototype.iconClasses = {
    close: 'fa-x',
    prev: 'fa-chevron-left',
    next: 'fa-chevron-right',
    prevYear: 'fa-chevrons-left',
    nextYear: 'fa-chevrons-right',
};
FontAwesomeTheme.prototype.rtlIconClasses = {
    prev: 'fa-chevron-right',
    next: 'fa-chevron-left',
    prevYear: 'fa-chevrons-right',
    nextYear: 'fa-chevrons-left',
};
FontAwesomeTheme.prototype.iconOverrideOption = 'buttonIcons';
FontAwesomeTheme.prototype.iconOverrideCustomButtonOption = 'icon';
FontAwesomeTheme.prototype.iconOverridePrefix = 'fa-';
const fontAwesomeThemePlugin = createPlugin({ name: 'font-awesome', themeClasses: { 'font-awesome': FontAwesomeTheme } });

class ToolbarConfigConverter {
    get getCustomButtons() {
        return this.customButtons;
    }
    get getToolbar() {
        return this.toolbar;
    }
    constructor(toolbarConfig) {
        this.customButtons = {};
        this.toolbar = {};
        this.toolbarConfig = toolbarConfig;
        this.init();
    }
    init() {
        if (!this.toolbarConfig)
            return;
        Object.keys(this.toolbarConfig).forEach(pos => {
            const key = pos;
            this.toolbar[key] = this.getToolbarLayout(this.toolbarConfig[key]);
        });
    }
    // Komma und Leerzeichen haben unterschiedlichen Effekt: https://fullcalendar.io/docs/headerToolbar
    getToolbarLayout(toolGroups) {
        if (toolGroups === null)
            return undefined;
        const groups = toolGroups.map(group => {
            const items = [];
            for (const tool of group)
                items.push(typeof tool === 'string' ? tool : this.registerCustomBtn(tool));
            return items.join(',');
        });
        return groups.join(' ');
    }
    registerCustomBtn(customButton) {
        const btnIdent = Object.keys(customButton)[0];
        const customBtn = customButton[btnIdent];
        this.customButtons[btnIdent] = customBtn;
        return btnIdent;
    }
}

class EnoFullcalendarComponent {
    get data() {
        return this._data;
    }
    set data(value) {
        this._data = value;
        this.updateEventSource();
    }
    set settings(value) {
        this.startTime = value.startTime;
        this.endTime = value.endTime;
        this.visibleDays = value.visibleDays;
        this.calendarOptions = this.configureFullCalendar();
    }
    get hiddenDays() {
        const allDays = [1, 2, 3, 4, 5, 6, 0];
        return allDays.filter(d => !this.visibleDays.includes(d));
    }
    set selectedDate(date) {
        this.calendarApi?.gotoDate(date);
    }
    constructor() {
        this.eventClick = new EventEmitter();
        this._data = [];
        this.requestData = new EventEmitter();
        this.initialViewMode = 'dayGridMonth';
        this.slotDuration = defaultCalendarSettings.slotDuration;
        this.startTime = defaultCalendarSettings.startTime;
        this.endTime = defaultCalendarSettings.endTime;
        this.visibleDays = defaultCalendarSettings.visibleDays;
        this.refreshDays$ = new Subject();
        this.refreshDays$.pipe(debounceTime(500), takeUntilDestroyed()).subscribe(interval => this.loadEvents(interval));
    }
    ngOnInit() {
        this.calendarOptions = this.configureFullCalendar();
    }
    refreshDays(start, end) {
        this.refreshDays$.next({ start, end });
    }
    loadEvents(interval) {
        if (!this.calendarApi)
            return;
        this.requestData.emit({
            start: interval.start ?? this.calendarApi.view.currentStart,
            end: interval.end ?? this.calendarApi.view.currentEnd,
        });
    }
    configureFullCalendar() {
        let headerToolbar;
        if (this.headerToolbarConfig !== undefined)
            headerToolbar = new ToolbarConfigConverter(this.headerToolbarConfig);
        const locale = $localize.locale ?? 'de-de';
        return {
            themeSystem: 'font-awesome',
            locale,
            firstDay: getLocaleFirstDayOfWeek(locale),
            plugins: EnoFullcalendarComponent.configurePlugins(),
            customButtons: headerToolbar?.getCustomButtons,
            headerToolbar: headerToolbar?.getToolbar,
            initialView: this.initialViewMode,
            events: this.data,
            buttonText: {
                month: $localize `:@@Fullcalendar.month.dsp.Label:Monat`,
                week: $localize `:@@Fullcalendar.week.dsp.Label:Woche`,
                day: $localize `:@@Fullcalendar.day.dsp.Label:Tag`,
                list: $localize `:@@Fullcalendar.list.dsp.Label:Liste`
            },
            datesSet: (arg) => this.refreshDays(arg.start, arg.end),
            eventClick: (arg) => this.eventClick.emit(EnoFullcalendarComponent.mapCalendarViewEvent(arg.event)),
            viewDidMount: (arg) => this.calendarApi = arg.view.calendar,
            slotMinTime: `${this.startTime}:00:00`,
            slotMaxTime: `${this.endTime}:00:00`,
            allDaySlot: false,
            slotDuration: this.slotDuration,
            hiddenDays: this.hiddenDays,
        };
    }
    updateEventSource() {
        if (!this.calendarOptions || !this.calendarApi)
            return;
        this.calendarOptions.events = this.data;
        // Bei mehreren EventSources sollte hier vllt. https://fullcalendar.io/docs/Calendar-getEventSourceById verwendet werden, um ungewollte Updates zu vermeiden
        this.calendarApi.refetchEvents();
    }
    static mapCalendarViewEvent(eventObject) {
        return {
            id: eventObject.id,
            title: eventObject.title,
            start: eventObject.start,
            end: eventObject.end,
            allDay: eventObject.allDay,
            url: eventObject.url,
            ...eventObject.extendedProps
        };
    }
    static configurePlugins() {
        return [
            interactionPlugin,
            timeGridPlugin,
            dayGridPlugin,
            listPlugin,
            fontAwesomeThemePlugin
        ];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: EnoFullcalendarComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: EnoFullcalendarComponent, isStandalone: false, selector: "eno-fullcalendar", inputs: { data: "data", initialViewMode: "initialViewMode", headerToolbarConfig: "headerToolbarConfig", settings: "settings" }, outputs: { eventClick: "eventClick", requestData: "requestData" }, queries: [{ propertyName: "_eventContent", first: true, predicate: ["eventContent"], descendants: true, static: true }], ngImport: i0, template: "<full-calendar [options]=\"calendarOptions\" inspinia-class=\"inspinia\" sneat-class=\"sneat\">\r\n    <ng-template #eventContent let-arg>\r\n        <ng-container *ngIf=\"_eventContent\">\r\n            <ng-container *ngTemplateOutlet=\"_eventContent; context: { $implicit: arg }\"></ng-container>\r\n        </ng-container>\r\n        <ng-container *ngIf=\"!_eventContent\">\r\n            <div [title]=\"arg.event.extendedProps.description\" class=\"event-item-wrapper\">\r\n                <small *ngIf=\"arg.view.type === 'dayGridMonth'\">{{ arg.event.start | date: 'shortTime' }}\r\n                </small>\r\n                <b [title]=\"arg.event.title\">{{ arg.event.title }}</b><br/>\r\n                <small [title]=\"arg.event.extendedProps.description\">{{ arg.event.extendedProps.description }}</small>\r\n            </div>\r\n        </ng-container>\r\n    </ng-template>\r\n</full-calendar>\r\n", styles: ["::ng-deep full-calendar :host ::ng-deep .fa-icon{color:#566a7f}::ng-deep full-calendar :host ::ng-deep .fc-event{overflow:hidden}::ng-deep full-calendar .calendar-view-event-inspinia-primary{color:#0043b8!important;background-color:#0043b833!important;border:none}::ng-deep full-calendar .calendar-view-event-inspinia-primary .fc-event-main{color:#0043b8}::ng-deep full-calendar .calendar-view-event-inspinia-primary .fc-list-event-dot{border-color:#0043b8!important}::ng-deep full-calendar .calendar-event-primary{color:#0043b8!important}::ng-deep full-calendar .calendar-event-primary .fc-event-main{color:#0043b8}::ng-deep full-calendar .calendar-view-event-inspinia-secondary{color:#209720!important;background-color:#20972033!important;border:none}::ng-deep full-calendar .calendar-view-event-inspinia-secondary .fc-event-main{color:#209720}::ng-deep full-calendar .calendar-view-event-inspinia-secondary .fc-list-event-dot{border-color:#209720!important}::ng-deep full-calendar .calendar-event-secondary{color:#209720!important}::ng-deep full-calendar .calendar-event-secondary .fc-event-main{color:#209720}::ng-deep full-calendar .calendar-view-event-inspinia-tertiary{color:#ca3457!important;background-color:#ca345733!important;border:none}::ng-deep full-calendar .calendar-view-event-inspinia-tertiary .fc-event-main{color:#ca3457}::ng-deep full-calendar .calendar-view-event-inspinia-tertiary .fc-list-event-dot{border-color:#ca3457!important}::ng-deep full-calendar .calendar-event-tertiary{color:#ca3457!important}::ng-deep full-calendar .calendar-event-tertiary .fc-event-main{color:#ca3457}::ng-deep full-calendar .calendar-view-event-inspinia-quaternary{color:#ff9800!important;background-color:#ff980033!important;border:none}::ng-deep full-calendar .calendar-view-event-inspinia-quaternary .fc-event-main{color:#ff9800}::ng-deep full-calendar .calendar-view-event-inspinia-quaternary .fc-list-event-dot{border-color:#ff9800!important}::ng-deep full-calendar .calendar-event-quaternary{color:#ff9800!important}::ng-deep full-calendar .calendar-event-quaternary .fc-event-main{color:#ff9800}::ng-deep full-calendar .calendar-view-event-inspinia-quinary{color:#2b86d1!important;background-color:#2b86d133!important;border:none}::ng-deep full-calendar .calendar-view-event-inspinia-quinary .fc-event-main{color:#2b86d1}::ng-deep full-calendar .calendar-view-event-inspinia-quinary .fc-list-event-dot{border-color:#2b86d1!important}::ng-deep full-calendar .calendar-event-quinary{color:#2b86d1!important}::ng-deep full-calendar .calendar-event-quinary .fc-event-main{color:#2b86d1}::ng-deep full-calendar .fc-day-today{background-color:#f5f5f5!important}::ng-deep full-calendar .fc-toolbar-chunk h2{display:inline-block;margin-top:7px}::ng-deep full-calendar .fc-toolbar-chunk .fc-next-button,::ng-deep full-calendar .fc-toolbar-chunk .fc-prev-button{padding-top:0;display:inline-block}::ng-deep full-calendar .fc-next-button,::ng-deep full-calendar .fc-prev-button{background-color:transparent!important;border-color:transparent!important;color:#566a7f!important}::ng-deep full-calendar.inspinia .fc-button{padding-top:0!important;padding-bottom:0!important;background-color:#8596b1;border-color:#7c8eab}::ng-deep full-calendar.inspinia .fc-button-active{background-color:#204077!important;border-color:#204077!important}::ng-deep full-calendar.inspinia h2{margin-left:0!important;margin-top:5px}::ng-deep full-calendar.inspinia .fc-next-button,::ng-deep full-calendar.inspinia .fc-prev-button{margin-bottom:8px}::ng-deep full-calendar.inspinia .event-item-wrapper{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}\n"], dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i2.FullCalendarComponent, selector: "full-calendar", inputs: ["options", "deepChangeDetection", "events", "eventSources", "resources"] }, { kind: "directive", type: i3.InspiniaCssClassDirective, selector: "[inspinia-class]", inputs: ["inspinia-class"] }, { kind: "directive", type: i3.SneatCssClassDirective, selector: "[sneat-class]", inputs: ["sneat-class"] }, { kind: "pipe", type: i1.DatePipe, name: "date" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: EnoFullcalendarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eno-fullcalendar', standalone: false, template: "<full-calendar [options]=\"calendarOptions\" inspinia-class=\"inspinia\" sneat-class=\"sneat\">\r\n    <ng-template #eventContent let-arg>\r\n        <ng-container *ngIf=\"_eventContent\">\r\n            <ng-container *ngTemplateOutlet=\"_eventContent; context: { $implicit: arg }\"></ng-container>\r\n        </ng-container>\r\n        <ng-container *ngIf=\"!_eventContent\">\r\n            <div [title]=\"arg.event.extendedProps.description\" class=\"event-item-wrapper\">\r\n                <small *ngIf=\"arg.view.type === 'dayGridMonth'\">{{ arg.event.start | date: 'shortTime' }}\r\n                </small>\r\n                <b [title]=\"arg.event.title\">{{ arg.event.title }}</b><br/>\r\n                <small [title]=\"arg.event.extendedProps.description\">{{ arg.event.extendedProps.description }}</small>\r\n            </div>\r\n        </ng-container>\r\n    </ng-template>\r\n</full-calendar>\r\n", styles: ["::ng-deep full-calendar :host ::ng-deep .fa-icon{color:#566a7f}::ng-deep full-calendar :host ::ng-deep .fc-event{overflow:hidden}::ng-deep full-calendar .calendar-view-event-inspinia-primary{color:#0043b8!important;background-color:#0043b833!important;border:none}::ng-deep full-calendar .calendar-view-event-inspinia-primary .fc-event-main{color:#0043b8}::ng-deep full-calendar .calendar-view-event-inspinia-primary .fc-list-event-dot{border-color:#0043b8!important}::ng-deep full-calendar .calendar-event-primary{color:#0043b8!important}::ng-deep full-calendar .calendar-event-primary .fc-event-main{color:#0043b8}::ng-deep full-calendar .calendar-view-event-inspinia-secondary{color:#209720!important;background-color:#20972033!important;border:none}::ng-deep full-calendar .calendar-view-event-inspinia-secondary .fc-event-main{color:#209720}::ng-deep full-calendar .calendar-view-event-inspinia-secondary .fc-list-event-dot{border-color:#209720!important}::ng-deep full-calendar .calendar-event-secondary{color:#209720!important}::ng-deep full-calendar .calendar-event-secondary .fc-event-main{color:#209720}::ng-deep full-calendar .calendar-view-event-inspinia-tertiary{color:#ca3457!important;background-color:#ca345733!important;border:none}::ng-deep full-calendar .calendar-view-event-inspinia-tertiary .fc-event-main{color:#ca3457}::ng-deep full-calendar .calendar-view-event-inspinia-tertiary .fc-list-event-dot{border-color:#ca3457!important}::ng-deep full-calendar .calendar-event-tertiary{color:#ca3457!important}::ng-deep full-calendar .calendar-event-tertiary .fc-event-main{color:#ca3457}::ng-deep full-calendar .calendar-view-event-inspinia-quaternary{color:#ff9800!important;background-color:#ff980033!important;border:none}::ng-deep full-calendar .calendar-view-event-inspinia-quaternary .fc-event-main{color:#ff9800}::ng-deep full-calendar .calendar-view-event-inspinia-quaternary .fc-list-event-dot{border-color:#ff9800!important}::ng-deep full-calendar .calendar-event-quaternary{color:#ff9800!important}::ng-deep full-calendar .calendar-event-quaternary .fc-event-main{color:#ff9800}::ng-deep full-calendar .calendar-view-event-inspinia-quinary{color:#2b86d1!important;background-color:#2b86d133!important;border:none}::ng-deep full-calendar .calendar-view-event-inspinia-quinary .fc-event-main{color:#2b86d1}::ng-deep full-calendar .calendar-view-event-inspinia-quinary .fc-list-event-dot{border-color:#2b86d1!important}::ng-deep full-calendar .calendar-event-quinary{color:#2b86d1!important}::ng-deep full-calendar .calendar-event-quinary .fc-event-main{color:#2b86d1}::ng-deep full-calendar .fc-day-today{background-color:#f5f5f5!important}::ng-deep full-calendar .fc-toolbar-chunk h2{display:inline-block;margin-top:7px}::ng-deep full-calendar .fc-toolbar-chunk .fc-next-button,::ng-deep full-calendar .fc-toolbar-chunk .fc-prev-button{padding-top:0;display:inline-block}::ng-deep full-calendar .fc-next-button,::ng-deep full-calendar .fc-prev-button{background-color:transparent!important;border-color:transparent!important;color:#566a7f!important}::ng-deep full-calendar.inspinia .fc-button{padding-top:0!important;padding-bottom:0!important;background-color:#8596b1;border-color:#7c8eab}::ng-deep full-calendar.inspinia .fc-button-active{background-color:#204077!important;border-color:#204077!important}::ng-deep full-calendar.inspinia h2{margin-left:0!important;margin-top:5px}::ng-deep full-calendar.inspinia .fc-next-button,::ng-deep full-calendar.inspinia .fc-prev-button{margin-bottom:8px}::ng-deep full-calendar.inspinia .event-item-wrapper{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}\n"] }]
        }], ctorParameters: () => [], propDecorators: { _eventContent: [{
                type: ContentChild,
                args: ['eventContent', { static: true }]
            }], eventClick: [{
                type: Output
            }], data: [{
                type: Input
            }], requestData: [{
                type: Output
            }], initialViewMode: [{
                type: Input
            }], headerToolbarConfig: [{
                type: Input
            }], settings: [{
                type: Input
            }] } });

class FullcalendarModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: FullcalendarModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.13", ngImport: i0, type: FullcalendarModule, declarations: [EnoFullcalendarComponent], imports: [CommonModule,
            FormsModule,
            FullCalendarModule,
            SwitchTemplateModule], exports: [EnoFullcalendarComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: FullcalendarModule, imports: [CommonModule,
            FormsModule,
            FullCalendarModule,
            SwitchTemplateModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: FullcalendarModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        FormsModule,
                        FullCalendarModule,
                        SwitchTemplateModule
                    ],
                    declarations: [
                        EnoFullcalendarComponent
                    ],
                    exports: [
                        EnoFullcalendarComponent
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { EnoFullcalendarComponent, FullcalendarModule };
//# sourceMappingURL=sowatech-shared-fullcalendar.mjs.map
