import * as i0 from '@angular/core';
import { Injectable, Input, Directive, ViewChild, Component, NgModule } from '@angular/core';
import * as i2 from 'ng-keyboard-shortcuts';
import { AllowIn, KeyboardShortcutsComponent, KeyboardShortcutsModule } from 'ng-keyboard-shortcuts';
import { Subject } from 'rxjs';

class GlobalKeyboardShortcutService {
    constructor() {
        this.onAddShortcut = new Subject();
        this.onRemoveShortcut = new Subject();
    }
    addShortcut(shortcut) {
        this.onAddShortcut.next(shortcut);
    }
    removeShortcut(shortcut) {
        this.onRemoveShortcut.next(shortcut);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: GlobalKeyboardShortcutService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: GlobalKeyboardShortcutService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: GlobalKeyboardShortcutService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }] });

/**
 * Shortcut Keys müssen immer mit Leerzeichen getrennt werden z.B. 'Ctrl + G'.
 * Des Weiteren muss irgendwo global die GlobalKeyboardShortcutsComponent im HTML plaziert werden, am einfachsten wäre es in der AppComponent HTML
 */
class ShortcutDirective {
    constructor(el, shortcutService) {
        this.el = el;
        this.shortcutService = shortcutService;
    }
    ngOnInit() {
        this.createShortcut();
    }
    createShortcut() {
        this.el.nativeElement.title = `${this.el.nativeElement.title ? this.el.nativeElement.title : this.el.nativeElement.textContent} (${this.getShortcutFriendlyName(this.shortcut)})`;
        this.btnShortcut = {
            key: this.shortcut,
            preventDefault: true,
            command: () => {
                this.shortcutExecuted();
            },
            description: this.el.nativeElement.textContent,
            label: this.shortcut,
            allowIn: [AllowIn.Input, AllowIn.Select, AllowIn.Textarea]
        };
        this.shortcutService.addShortcut(this.btnShortcut);
    }
    getShortcutFriendlyName(shortcut) {
        if (Array.isArray(shortcut))
            return this.replaceCtrlInFriendlyName(shortcut.length > 0 ? shortcut[0] : '');
        else
            return this.replaceCtrlInFriendlyName(shortcut);
    }
    replaceCtrlInFriendlyName(shortcut) {
        return shortcut.toLocaleLowerCase().replace('ctrl', 'strg').toLocaleUpperCase();
    }
    shortcutExecuted() {
        this.el.nativeElement.click();
    }
    ngOnDestroy() {
        this.shortcutService.removeShortcut(this.btnShortcut);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ShortcutDirective, deps: [{ token: i0.ElementRef }, { token: GlobalKeyboardShortcutService }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.13", type: ShortcutDirective, isStandalone: false, selector: "[shortcut]", inputs: { shortcut: "shortcut" }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: ShortcutDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[shortcut]',
                    standalone: false
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: GlobalKeyboardShortcutService }], propDecorators: { shortcut: [{
                type: Input
            }] } });

class GlobalKeyboardShortcutsComponent {
    constructor(shortcutService) {
        this.shortcutService = shortcutService;
        this.shortcuts = [];
        this.defaultShortcuts = [];
        this.subscriptions = new Array();
    }
    ngOnInit() {
        this.subscriptions.push(this.shortcutService.onAddShortcut.subscribe((shortcut) => this.addShortcut(shortcut)), this.shortcutService.onRemoveShortcut.subscribe((shortcut) => this.removeShortcut(shortcut)));
    }
    ngAfterViewInit() {
        this.shortcuts = this.defaultShortcuts;
    }
    removeShortcut(shortcut) {
        this.keyboard.disabled = true;
        const index = this.shortcuts.findIndex(s => s.key === shortcut.key);
        this.shortcuts.splice(index, 1);
        this.keyboard.disabled = false;
    }
    addShortcut(shortcut) {
        this.keyboard.disabled = true;
        this.shortcuts.push(shortcut);
        this.keyboard.disabled = false;
    }
    ngOnDestroy() {
        for (const s of this.subscriptions)
            s.unsubscribe();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: GlobalKeyboardShortcutsComponent, deps: [{ token: GlobalKeyboardShortcutService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: GlobalKeyboardShortcutsComponent, isStandalone: false, selector: "global-keyboard-shortcuts", inputs: { defaultShortcuts: "defaultShortcuts" }, viewQueries: [{ propertyName: "keyboard", first: true, predicate: KeyboardShortcutsComponent, descendants: true, static: true }], ngImport: i0, template: `
    <ng-keyboard-shortcuts [shortcuts]="shortcuts"></ng-keyboard-shortcuts>
    `, isInline: true, dependencies: [{ kind: "component", type: i2.KeyboardShortcutsComponent, selector: "ng-keyboard-shortcuts", inputs: ["shortcuts", "disabled"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: GlobalKeyboardShortcutsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'global-keyboard-shortcuts', template: `
    <ng-keyboard-shortcuts [shortcuts]="shortcuts"></ng-keyboard-shortcuts>
    `, standalone: false }]
        }], ctorParameters: () => [{ type: GlobalKeyboardShortcutService }], propDecorators: { keyboard: [{
                type: ViewChild,
                args: [KeyboardShortcutsComponent, { static: true }]
            }], defaultShortcuts: [{
                type: Input
            }] } });

const KeyboardShortcutsModuleForRoot = KeyboardShortcutsModule.forRoot();
class GlobalKeyboardShortcutsModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: GlobalKeyboardShortcutsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.13", ngImport: i0, type: GlobalKeyboardShortcutsModule, declarations: [GlobalKeyboardShortcutsComponent,
            ShortcutDirective], imports: [i2.KeyboardShortcutsModule], exports: [ShortcutDirective,
            GlobalKeyboardShortcutsComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: GlobalKeyboardShortcutsModule, imports: [KeyboardShortcutsModuleForRoot] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: GlobalKeyboardShortcutsModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        KeyboardShortcutsModuleForRoot
                    ],
                    declarations: [
                        GlobalKeyboardShortcutsComponent,
                        ShortcutDirective
                    ],
                    exports: [
                        ShortcutDirective,
                        GlobalKeyboardShortcutsComponent
                    ],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { GlobalKeyboardShortcutService, GlobalKeyboardShortcutsComponent, GlobalKeyboardShortcutsModule, ShortcutDirective };
//# sourceMappingURL=sowatech-shared-global-keyboard-shortcuts.mjs.map
