import * as i0 from '@angular/core';
import { EventEmitter, Output, Input, Component, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';

/* eslint-disable @angular-eslint/no-output-on-prefix */
class LightboxComponent {
    constructor() {
        this.thumbSize = '50px';
        this.imageClosed = new EventEmitter();
        this.onButtonClicked = new EventEmitter();
        this.onImageClicked = new EventEmitter();
        this.opened = false;
    }
    get currentImageIndex() {
        return this.currentImage ? this.images.indexOf(this.currentImage) : -1;
    }
    set scrollingDisabled(value) {
        document.body.style.overflowY = value ? 'hidden' : 'unset';
    }
    closeImage() {
        this.opened = false;
        this.scrollingDisabled = false;
        this.imageClosed.emit(null);
    }
    prevImage() {
        let imageIndex = this.images.indexOf(this.currentImage);
        imageIndex = imageIndex > 0 ? imageIndex - 1 : this.images.length - 1;
        this.currentImage = this.images[imageIndex];
        this.openImage();
    }
    nextImage() {
        let imageIndex = this.images.indexOf(this.currentImage);
        imageIndex = imageIndex === this.images.length - 1 ? 0 : imageIndex + 1;
        this.currentImage = this.images[imageIndex];
        this.openImage();
    }
    openImage(imageName) {
        if (imageName)
            this.currentImage = this.images.find(img => img.imageName === imageName);
        this.opened = true;
        this.scrollingDisabled = true;
        this.onImageClicked.emit(this.currentImage);
        this.setCurrentImageUrl(this.currentImage);
    }
    openImageWithIndex(index) {
        this.currentImage = this.images[index];
        this.openImage();
    }
    buttonClicked(ident, image) {
        const btnEvent = { ident, imageName: image.imageName };
        this.onButtonClicked.emit(btnEvent);
    }
    async setCurrentImageUrl(image) {
        if (image.imageUrl)
            return;
        image.imageUrl = await image.getImage();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: LightboxComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: LightboxComponent, isStandalone: false, selector: "lightbox", inputs: { images: "images", thumbSize: "thumbSize", actions: "actions", hideGallery: "hideGallery", showImageName: "showImageName" }, outputs: { imageClosed: "imageClosed", onButtonClicked: "onButtonClicked", onImageClicked: "onImageClicked" }, ngImport: i0, template: "<div class=\"ng-gallery\" *ngIf=\"!hideGallery\">\r\n    <div *ngFor=\"let image of images; let index = index\" class=\"img-wrap\">\r\n        <span class=\"lightboxBtn\">\r\n            <span>\r\n                <button *ngFor=\"let btn of actions?.imageButtons\" type=\"button\" class=\"btn m-r-xs {{btn.buttonClass}}\"\r\n                    [title]=\"btn.tooltip\" (click)=\"buttonClicked(btn.ident, image)\">\r\n                    <i *ngIf=\"btn.iconClass\" class=\"fa {{btn.iconClass}}\"></i>\r\n                    {{btn.text}}\r\n                </button>\r\n            </span>\r\n        </span>\r\n        <div [style.width]=\"thumbSize\" [style.height]=\"thumbSize\" class=\"ng-thumb\">\r\n            <img [src]=\"image.thumbUrl\" [style.max-width]=\"thumbSize\" (click)=\"openImage(image.imageName)\"\r\n                alt=\"Bild {{ index + 1 }}\" />\r\n        </div>\r\n    </div>\r\n</div>\r\n<div class=\"ng-overlay\" *ngIf=\"opened\">\r\n    <div class=\"ng-gallery-content\">\r\n        <div class=\"uil-ring-css\" *ngIf=\"!currentImage || !currentImage.imageUrl\">\r\n            <div></div>\r\n        </div>\r\n        <a class=\"close-popup\" (click)=\"closeImage()\"><i class=\"fa fa-times\"></i></a>\r\n        <a class=\"nav-left\" *ngIf=\"images.length >1\" (click)=\"prevImage()\"><i class=\"fa fa-angle-left\"></i></a>\r\n        <img *ngIf=\"currentImage && currentImage.imageUrl\" [src]=\"currentImage.imageUrl\" (click)=\"nextImage()\"\r\n            class=\"effect\" />\r\n        <a class=\"nav-right\" *ngIf=\"images.length >1\" (click)=\"nextImage()\"><i class=\"fa fa-angle-right\"></i></a>\r\n        <span *ngIf=\"showImageName\" class=\"info-text image-name\">{{currentImage?.imageName}}</span>\r\n        <span class=\"info-text\">{{ currentImageIndex + 1 }}/{{ images.length }} - Bild {{currentImageIndex+1}}</span>\r\n        <span class=\"overlay-buttons-container\">\r\n            <button *ngFor=\"let btn of actions?.overlayButtons\" type=\"button\" class=\"btn m-r-xs {{btn.buttonClass}}\"\r\n                [title]=\"btn.tooltip\" (click)=\"buttonClicked(btn.ident, currentImage)\">\r\n                <i *ngIf=\"btn.iconClass\" class=\"fa {{btn.iconClass}}\"></i>\r\n                {{btn.text}}\r\n            </button>\r\n        </span>\r\n    </div>\r\n</div>\r\n", styles: [".ng-gallery{width:100%;display:inline-block}div.ng-thumb{text-align:center;float:left;padding:5px;margin:5px;overflow:hidden}div.ng-thumb img{cursor:pointer}.ng-overlay{position:fixed;top:0;left:0;width:100%;height:100%;background:#000c;z-index:9999;-webkit-user-select:none;-khtml-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;-webkit-user-drag:none}.ng-gallery-content{position:fixed;top:0;left:0;width:100%;height:100%;z-index:10000;text-align:center}.ng-gallery-content>a.close-popup{font-size:42px;float:right;color:#fff;text-decoration:none;margin:0 30px 0 0;cursor:pointer;position:absolute;top:20px;right:0}.ng-gallery-content>a.download-image{font-size:42px;float:right;color:#fff;text-decoration:none;margin:0 30px 0 0;cursor:pointer;position:absolute;top:20px;right:63px}.ng-gallery-content>a.nav-left,.ng-gallery-content>a.nav-right{color:#fff;text-decoration:none;font-size:60px;cursor:pointer;outline:none}.ng-gallery-content>a.nav-left{position:fixed;left:30px;top:50%;transform:translateY(-50%)}.ng-gallery-content>a.nav-right{position:fixed;right:30px;top:50%;transform:translateY(-50%)}.ng-gallery-content>img{height:auto;max-height:calc(100% - 150px);max-width:calc(100% - 100px);position:relative;display:block;margin:0 auto;top:50%;transform:translateY(-50%);-webkit-transform:translateY(-50%);cursor:pointer;-webkit-user-select:none;-khtml-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;-webkit-user-drag:none}.ng-gallery-content>img.effect{animation:fadeIn .5s}@keyframes fadeIn{0%{opacity:.3}to{opacity:1}}.ng-gallery-content>span.info-text{color:#fff;display:inline-block;width:100%;height:20px;font-weight:700;text-align:center;position:fixed;left:0;right:0;bottom:100px}.ng-gallery-content>span.info-text.image-name{bottom:80px;font-size:16px}.ng-gallery-content>.ng-thumbnails-wrapper{width:400px;height:70px;text-align:center;position:fixed;bottom:20px;left:0;right:0;margin-left:auto;margin-right:auto;overflow-x:hidden}.ng-gallery-content>.ng-thumbnails-wrapper>.ng-thumbnails{width:4000px;height:70px}.ng-gallery-content>.ng-thumbnails-wrapper>.ng-thumbnails>div>img{width:auto;height:70px;float:left;margin-right:10px;cursor:pointer;opacity:.6}.ng-gallery-content>.ng-thumbnails-wrapper>.ng-thumbnails>div>img:hover,.ng-gallery-content>.ng-thumbnails-wrapper>.ng-thumbnails>div>img.active{transition:opacity .25s ease;opacity:1}uiload{display:inline-block;position:relative}uiload>div{position:relative}@-webkit-keyframes uil-ring-anim{0%{-ms-transform:rotate(0deg);-moz-transform:rotate(0deg);-webkit-transform:rotate(0deg);-o-transform:rotate(0deg);transform:rotate(0)}to{-ms-transform:rotate(360deg);-moz-transform:rotate(360deg);-webkit-transform:rotate(360deg);-o-transform:rotate(360deg);transform:rotate(360deg)}}@-moz-keyframes uil-ring-anim{0%{-ms-transform:rotate(0deg);-moz-transform:rotate(0deg);-webkit-transform:rotate(0deg);-o-transform:rotate(0deg);transform:rotate(0)}to{-ms-transform:rotate(360deg);-moz-transform:rotate(360deg);-webkit-transform:rotate(360deg);-o-transform:rotate(360deg);transform:rotate(360deg)}}@-ms-keyframes uil-ring-anim{0%{-ms-transform:rotate(0deg);-moz-transform:rotate(0deg);-webkit-transform:rotate(0deg);-o-transform:rotate(0deg);transform:rotate(0)}to{-ms-transform:rotate(360deg);-moz-transform:rotate(360deg);-webkit-transform:rotate(360deg);-o-transform:rotate(360deg);transform:rotate(360deg)}}@keyframes uil-ring-anim{0%{-ms-transform:rotate(0deg);-moz-transform:rotate(0deg);-webkit-transform:rotate(0deg);-o-transform:rotate(0deg);transform:rotate(0)}to{-ms-transform:rotate(360deg);-moz-transform:rotate(360deg);-webkit-transform:rotate(360deg);-o-transform:rotate(360deg);transform:rotate(360deg)}}.uil-ring-css{background:none;position:relative;top:0;margin:180px auto 0;width:100px;height:100px}.uil-ring-css>div{position:absolute;display:block;width:80px;height:80px;top:20px;left:20px;border-radius:40px;box-shadow:0 6px #fff;-ms-animation:uil-ring-anim 1s linear infinite;-moz-animation:uil-ring-anim 1s linear infinite;-webkit-animation:uil-ring-anim 1s linear infinite;-o-animation:uil-ring-anim 1s linear infinite;animation:uil-ring-anim 1s linear infinite}.img-wrap{position:relative;display:inline-block;font-size:0}.img-wrap .lightboxBtn{position:absolute;top:2px;right:2px;z-index:100;cursor:pointer;opacity:0}.img-wrap:hover .lightboxBtn{opacity:1}.overlay-buttons-container{position:fixed;bottom:15px;width:100%;text-align:center;display:inline-block;left:0;right:0}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: LightboxComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lightbox', standalone: false, template: "<div class=\"ng-gallery\" *ngIf=\"!hideGallery\">\r\n    <div *ngFor=\"let image of images; let index = index\" class=\"img-wrap\">\r\n        <span class=\"lightboxBtn\">\r\n            <span>\r\n                <button *ngFor=\"let btn of actions?.imageButtons\" type=\"button\" class=\"btn m-r-xs {{btn.buttonClass}}\"\r\n                    [title]=\"btn.tooltip\" (click)=\"buttonClicked(btn.ident, image)\">\r\n                    <i *ngIf=\"btn.iconClass\" class=\"fa {{btn.iconClass}}\"></i>\r\n                    {{btn.text}}\r\n                </button>\r\n            </span>\r\n        </span>\r\n        <div [style.width]=\"thumbSize\" [style.height]=\"thumbSize\" class=\"ng-thumb\">\r\n            <img [src]=\"image.thumbUrl\" [style.max-width]=\"thumbSize\" (click)=\"openImage(image.imageName)\"\r\n                alt=\"Bild {{ index + 1 }}\" />\r\n        </div>\r\n    </div>\r\n</div>\r\n<div class=\"ng-overlay\" *ngIf=\"opened\">\r\n    <div class=\"ng-gallery-content\">\r\n        <div class=\"uil-ring-css\" *ngIf=\"!currentImage || !currentImage.imageUrl\">\r\n            <div></div>\r\n        </div>\r\n        <a class=\"close-popup\" (click)=\"closeImage()\"><i class=\"fa fa-times\"></i></a>\r\n        <a class=\"nav-left\" *ngIf=\"images.length >1\" (click)=\"prevImage()\"><i class=\"fa fa-angle-left\"></i></a>\r\n        <img *ngIf=\"currentImage && currentImage.imageUrl\" [src]=\"currentImage.imageUrl\" (click)=\"nextImage()\"\r\n            class=\"effect\" />\r\n        <a class=\"nav-right\" *ngIf=\"images.length >1\" (click)=\"nextImage()\"><i class=\"fa fa-angle-right\"></i></a>\r\n        <span *ngIf=\"showImageName\" class=\"info-text image-name\">{{currentImage?.imageName}}</span>\r\n        <span class=\"info-text\">{{ currentImageIndex + 1 }}/{{ images.length }} - Bild {{currentImageIndex+1}}</span>\r\n        <span class=\"overlay-buttons-container\">\r\n            <button *ngFor=\"let btn of actions?.overlayButtons\" type=\"button\" class=\"btn m-r-xs {{btn.buttonClass}}\"\r\n                [title]=\"btn.tooltip\" (click)=\"buttonClicked(btn.ident, currentImage)\">\r\n                <i *ngIf=\"btn.iconClass\" class=\"fa {{btn.iconClass}}\"></i>\r\n                {{btn.text}}\r\n            </button>\r\n        </span>\r\n    </div>\r\n</div>\r\n", styles: [".ng-gallery{width:100%;display:inline-block}div.ng-thumb{text-align:center;float:left;padding:5px;margin:5px;overflow:hidden}div.ng-thumb img{cursor:pointer}.ng-overlay{position:fixed;top:0;left:0;width:100%;height:100%;background:#000c;z-index:9999;-webkit-user-select:none;-khtml-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;-webkit-user-drag:none}.ng-gallery-content{position:fixed;top:0;left:0;width:100%;height:100%;z-index:10000;text-align:center}.ng-gallery-content>a.close-popup{font-size:42px;float:right;color:#fff;text-decoration:none;margin:0 30px 0 0;cursor:pointer;position:absolute;top:20px;right:0}.ng-gallery-content>a.download-image{font-size:42px;float:right;color:#fff;text-decoration:none;margin:0 30px 0 0;cursor:pointer;position:absolute;top:20px;right:63px}.ng-gallery-content>a.nav-left,.ng-gallery-content>a.nav-right{color:#fff;text-decoration:none;font-size:60px;cursor:pointer;outline:none}.ng-gallery-content>a.nav-left{position:fixed;left:30px;top:50%;transform:translateY(-50%)}.ng-gallery-content>a.nav-right{position:fixed;right:30px;top:50%;transform:translateY(-50%)}.ng-gallery-content>img{height:auto;max-height:calc(100% - 150px);max-width:calc(100% - 100px);position:relative;display:block;margin:0 auto;top:50%;transform:translateY(-50%);-webkit-transform:translateY(-50%);cursor:pointer;-webkit-user-select:none;-khtml-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;-webkit-user-drag:none}.ng-gallery-content>img.effect{animation:fadeIn .5s}@keyframes fadeIn{0%{opacity:.3}to{opacity:1}}.ng-gallery-content>span.info-text{color:#fff;display:inline-block;width:100%;height:20px;font-weight:700;text-align:center;position:fixed;left:0;right:0;bottom:100px}.ng-gallery-content>span.info-text.image-name{bottom:80px;font-size:16px}.ng-gallery-content>.ng-thumbnails-wrapper{width:400px;height:70px;text-align:center;position:fixed;bottom:20px;left:0;right:0;margin-left:auto;margin-right:auto;overflow-x:hidden}.ng-gallery-content>.ng-thumbnails-wrapper>.ng-thumbnails{width:4000px;height:70px}.ng-gallery-content>.ng-thumbnails-wrapper>.ng-thumbnails>div>img{width:auto;height:70px;float:left;margin-right:10px;cursor:pointer;opacity:.6}.ng-gallery-content>.ng-thumbnails-wrapper>.ng-thumbnails>div>img:hover,.ng-gallery-content>.ng-thumbnails-wrapper>.ng-thumbnails>div>img.active{transition:opacity .25s ease;opacity:1}uiload{display:inline-block;position:relative}uiload>div{position:relative}@-webkit-keyframes uil-ring-anim{0%{-ms-transform:rotate(0deg);-moz-transform:rotate(0deg);-webkit-transform:rotate(0deg);-o-transform:rotate(0deg);transform:rotate(0)}to{-ms-transform:rotate(360deg);-moz-transform:rotate(360deg);-webkit-transform:rotate(360deg);-o-transform:rotate(360deg);transform:rotate(360deg)}}@-moz-keyframes uil-ring-anim{0%{-ms-transform:rotate(0deg);-moz-transform:rotate(0deg);-webkit-transform:rotate(0deg);-o-transform:rotate(0deg);transform:rotate(0)}to{-ms-transform:rotate(360deg);-moz-transform:rotate(360deg);-webkit-transform:rotate(360deg);-o-transform:rotate(360deg);transform:rotate(360deg)}}@-ms-keyframes uil-ring-anim{0%{-ms-transform:rotate(0deg);-moz-transform:rotate(0deg);-webkit-transform:rotate(0deg);-o-transform:rotate(0deg);transform:rotate(0)}to{-ms-transform:rotate(360deg);-moz-transform:rotate(360deg);-webkit-transform:rotate(360deg);-o-transform:rotate(360deg);transform:rotate(360deg)}}@keyframes uil-ring-anim{0%{-ms-transform:rotate(0deg);-moz-transform:rotate(0deg);-webkit-transform:rotate(0deg);-o-transform:rotate(0deg);transform:rotate(0)}to{-ms-transform:rotate(360deg);-moz-transform:rotate(360deg);-webkit-transform:rotate(360deg);-o-transform:rotate(360deg);transform:rotate(360deg)}}.uil-ring-css{background:none;position:relative;top:0;margin:180px auto 0;width:100px;height:100px}.uil-ring-css>div{position:absolute;display:block;width:80px;height:80px;top:20px;left:20px;border-radius:40px;box-shadow:0 6px #fff;-ms-animation:uil-ring-anim 1s linear infinite;-moz-animation:uil-ring-anim 1s linear infinite;-webkit-animation:uil-ring-anim 1s linear infinite;-o-animation:uil-ring-anim 1s linear infinite;animation:uil-ring-anim 1s linear infinite}.img-wrap{position:relative;display:inline-block;font-size:0}.img-wrap .lightboxBtn{position:absolute;top:2px;right:2px;z-index:100;cursor:pointer;opacity:0}.img-wrap:hover .lightboxBtn{opacity:1}.overlay-buttons-container{position:fixed;bottom:15px;width:100%;text-align:center;display:inline-block;left:0;right:0}\n"] }]
        }], propDecorators: { images: [{
                type: Input
            }], thumbSize: [{
                type: Input
            }], actions: [{
                type: Input
            }], hideGallery: [{
                type: Input
            }], showImageName: [{
                type: Input
            }], imageClosed: [{
                type: Output
            }], onButtonClicked: [{
                type: Output
            }], onImageClicked: [{
                type: Output
            }] } });
class LightboxActions {
}
class LightboxButtonEvent {
}
class LightboxImageButton {
}

class LightboxModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: LightboxModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.13", ngImport: i0, type: LightboxModule, declarations: [LightboxComponent], imports: [CommonModule], exports: [LightboxComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: LightboxModule, imports: [CommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: LightboxModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule
                    ],
                    declarations: [
                        LightboxComponent
                    ],
                    exports: [
                        LightboxComponent
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { LightboxActions, LightboxButtonEvent, LightboxComponent, LightboxImageButton, LightboxModule };
//# sourceMappingURL=sowatech-shared-lightbox.mjs.map
