import * as i0 from '@angular/core';
import { Injectable } from '@angular/core';
import { UserPropertiesStorageService } from '@sowatech/shared/user-properties-storage';
import * as i1 from '@sowatech/shared/shared-config';

class LocalStorageService extends UserPropertiesStorageService {
    constructor(config) {
        super();
        this.prefix = '';
        this.userPrefix = '';
        this.getPrefixedKey = (key) => this.prefix + this.userPrefix + key;
        this.prefix = config.storagePrefix;
    }
    setUserName(username) {
        this.userPrefix = username ? username + '.' : '';
    }
    clearUserName() {
        this.userPrefix = '';
    }
    save(key, value) {
        this.setItem(key, value);
    }
    load(key) {
        return this.getItem(key);
    }
    delete(key) {
        this.removeItem(key);
    }
    /**
     * Liest den Wert aus und gibt ihn geparsed zurück.
     * Der Key wird mit dem Prefix versehen.
     */
    getItem(key) {
        const stored = localStorage.getItem(this.getPrefixedKey(key));
        try {
            return JSON.parse(stored);
        }
        catch { // L2-4547: früher string hidden gespeichert ohne "" -> JSON.parse failt
            return stored;
        }
    }
    /**
     * Stringified den value und schreibt ihn in den Localstorage.
     * Der Key wird mit dem Prefix versehen.
     */
    setItem(key, value) {
        localStorage.setItem(this.getPrefixedKey(key), JSON.stringify(value));
    }
    removeItem(key) {
        localStorage.removeItem(this.getPrefixedKey(key));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: LocalStorageService, deps: [{ token: i1.SharedConfigService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: LocalStorageService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: LocalStorageService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: () => [{ type: i1.SharedConfigService }] });

/**
 * Generated bundle index. Do not edit.
 */

export { LocalStorageService };
//# sourceMappingURL=sowatech-shared-local-storage.mjs.map
