import * as i0 from '@angular/core';
import { Directive, Component, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

const NoEditClass = 'no-edit';
const IgnoreSingleELementClass = 'ignore-no-edit';
const IgnoreParentSelector = '.ignore-no-edit';
const IgnoreSelectors = [
    IgnoreParentSelector,
    //hier können weitere Selectors eingefügt werden, die das no-edit im Innern büberschreiben
];
//no-edit-hidden Comment...
class NoEditButtonDirective {
    constructor(renderer, el) {
        this.renderer = renderer;
        this.el = el;
    }
    ngDoCheck() {
        if (this.isNoEdit())
            this.renderer.setStyle(this.el.nativeElement, 'display', 'none');
        else
            this.renderer.removeStyle(this.el.nativeElement, 'display');
    }
    isNoEdit() {
        return NoEditButtonDirective.isNoEdit(this.el.nativeElement);
    }
    static isNoEdit(nativeElement) {
        if (nativeElement.classList.contains(IgnoreSingleELementClass))
            return false;
        const parent = nativeElement.closest(`.${NoEditClass}, ${IgnoreSelectors.join(', ')}`);
        if (parent && parent.classList.contains(NoEditClass))
            return true;
        return false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: NoEditButtonDirective, deps: [{ token: i0.Renderer2 }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.13", type: NoEditButtonDirective, isStandalone: false, selector: "button:not(ignore-no-edit),\n                [no-edit-hidden]:not(ignore-no-edit)", ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: NoEditButtonDirective, decorators: [{
            type: Directive,
            args: [{
                    //no-edit-hidden für Elemente die ausgeblendet werden sollen, aber keine Buttons sind (z.B. Dropdowns mit Links)
                    selector: `button:not(${IgnoreSingleELementClass}),
                [no-edit-hidden]:not(${IgnoreSingleELementClass})`,
                    standalone: false
                }]
        }], ctorParameters: () => [{ type: i0.Renderer2 }, { type: i0.ElementRef }] });

class NoEditCheckerComponent {
    constructor(element) {
        this.element = element;
    }
    ngOnInit() {
    }
    ngOnDestroy() {
    }
    get canEdit() {
        return !NoEditButtonDirective.isNoEdit(this.element.nativeElement);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: NoEditCheckerComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: NoEditCheckerComponent, isStandalone: false, selector: "hidden-no-edit", ngImport: i0, template: `<ng-container *ngIf="canEdit">
                    <ng-content></ng-content>
                </ng-container>
`, isInline: true, dependencies: [{ kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: NoEditCheckerComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'hidden-no-edit',
                    template: `<ng-container *ngIf="canEdit">
                    <ng-content></ng-content>
                </ng-container>
`,
                    standalone: false
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }] });

class NoEditButtonModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: NoEditButtonModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.13", ngImport: i0, type: NoEditButtonModule, declarations: [NoEditButtonDirective, NoEditCheckerComponent], imports: [CommonModule,
            FormsModule], exports: [NoEditButtonDirective, NoEditCheckerComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: NoEditButtonModule, imports: [CommonModule,
            FormsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: NoEditButtonModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        FormsModule,
                    ],
                    declarations: [NoEditButtonDirective, NoEditCheckerComponent],
                    exports: [NoEditButtonDirective, NoEditCheckerComponent]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { NoEditButtonDirective, NoEditButtonModule, NoEditCheckerComponent };
//# sourceMappingURL=sowatech-shared-no-edit-button.mjs.map
