import 'moment/locale/de';
import * as i1 from '@angular/common';
import { DatePipe, CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { EventEmitter, Output, Input, ViewChild, ViewEncapsulation, Component, NgModule } from '@angular/core';
import moment from 'moment';
import * as i2 from '@sowatech/shared/logger';
import * as i3 from '@sowatech/shared/swt-controls';
import { SwtControlsModule } from '@sowatech/shared/swt-controls';
import { FormsModule } from '@angular/forms';
import * as i1$1 from 'ngx-bootstrap/popover';
import { PopoverModule } from 'ngx-bootstrap/popover';
import { NgScrollbarModule } from 'ngx-scrollbar';

const CLASS = 'SchedulerYearCalendarComponent';
class SchedulerYearCalendarComponent {
    constructor(datePipe, logger) {
        this.datePipe = datePipe;
        this.logger = logger;
        this.months = [];
        this.CELLHEIGHTPX = 34;
        this.CELLHEIGHTPERCENT = 100;
        this._slotDataItems = new Array();
        this.cellClick = new EventEmitter();
    }
    ngOnInit() {
        this.initTable();
    }
    set _slotItems(values) {
        this._slotDataItems = values;
    }
    initTable() {
        this.months = [];
        if (!this.year)
            this.year = moment().year();
        const yearMoment = this.year ? moment().year(this.year) : moment();
        this.logger.log(CLASS + '.initTable');
        for (let tMonth = 0; tMonth < 12; tMonth++) {
            const month = new Month();
            month.index = tMonth;
            month.name = this.datePipe.transform(yearMoment.month(tMonth).toDate(), 'MMMM');
            const days = [];
            for (let day = 1; day <= 31; day++) {
                const thisDay = this.createDay(day, tMonth);
                days.push(thisDay);
            }
            month.days = days;
            this.months.push(month);
        }
    }
    createDay(day, tMonth) {
        const monthMoment = this.year ? moment().year(this.year).month(tMonth) : moment();
        const thisDay = new Day();
        if (day <= monthMoment.daysInMonth()) {
            thisDay.exists = true;
            thisDay.number = day;
            thisDay.date = moment().year(this.year).month(tMonth).date(day).toDate();
            thisDay.dataItems = this.getDateDataItems(day, tMonth);
            thisDay.cssClass = 'day-of-week-' + monthMoment.date(day).toDate().getDay();
        }
        else {
            thisDay.exists = false;
            thisDay.number = null;
        }
        return thisDay;
    }
    getDateDataItems(day, month) {
        const arrayOfDataItems = new Array();
        this._slotDataItems.forEach(item => {
            const yearOfItem = moment(item.date).year();
            const dayOfItem = moment(item.date).date();
            const monthOfItem = moment(item.date).month();
            if (month == monthOfItem && day == dayOfItem && this.year == yearOfItem)
                arrayOfDataItems.push(item);
        });
        return arrayOfDataItems;
    }
    getTitle(arr) {
        let title = '';
        if (arr)
            title = arr.map(d => d.title).join('; ');
        return title;
    }
    setCssClasses(day) {
        let cssClasses = '';
        if (!day.exists)
            cssClasses = 'not-existing-day';
        else
            cssClasses += 'clickable ' + day.cssClass;
        return cssClasses;
    }
    onCellClick(event, month, day) {
        this.logger.log(month, day);
        if (day.exists) {
            event.stopPropagation();
            const e = new DateCellClickEvent();
            e.date = day.date;
            e.dataItems = day.dataItems;
            this.logger.log(CLASS + 'onCellClick' + e.date + ' ' + e.dataItems);
            this.cellClick.emit(e);
        }
    }
    increaseYear() {
        this.year++;
        this.initTable();
    }
    decreaseYear() {
        this.year--;
        this.initTable();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: SchedulerYearCalendarComponent, deps: [{ token: i1.DatePipe }, { token: i2.LoggerService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: SchedulerYearCalendarComponent, isStandalone: false, selector: "scheduler-year-calendar", inputs: { year: "year", occupationLegend: "occupationLegend", _slotItems: ["slotItems", "_slotItems"] }, outputs: { cellClick: "cellClick" }, providers: [DatePipe], viewQueries: [{ propertyName: "loadingIndicator", first: true, predicate: ["loadingIndicator"], descendants: true, static: true }], ngImport: i0, template: "<div>\r\n    <div style=\"width:5%; float:left;\">\r\n        <div class=\"btn-group\">\r\n            <button class=\"btn btn-default btn-xs\" (click)=\"decreaseYear()\" data-toggle=\"tooltip\" title=\"{{year-1}}\"><i\r\n                    class=\"fas fa-angle-left\"></i></button>\r\n        </div>\r\n    </div>\r\n    <div [style.width.%]=\"90\" style=\"float:left;\" class=\"text-center\"><h4>{{year}}</h4></div>\r\n    <div style=\"float:right; width:5%;\">\r\n        <div class=\"btn-group pull-right\">\r\n            <button class=\"btn btn-default btn-xs\" (click)=\"increaseYear()\" data-toggle=\"tooltip\" title=\"{{year+1}}\"><i\r\n                    class=\"fas fa-angle-right\"></i></button>\r\n        </div>\r\n    </div>\r\n</div>\r\n<div>\r\n    <loading-indicator #loadingIndicator>\r\n        <table class=\"scheduler-year table table-bordered table-hover dataTable\">\r\n            <thead>\r\n                <tr>\r\n                    <th class=\"row-month\"></th>\r\n                    <th *ngFor=\"let day of months[0].days\" class=\"row-day text-center\">{{day.number}}</th>\r\n                </tr>\r\n            </thead>\r\n            <tbody>\r\n                <tr *ngFor=\"let month of months\">\r\n                    <td class=\"row-month\">{{month.name}}</td>\r\n                    <td *ngFor=\"let day of month.days\" (click)=\"onCellClick($event, month, day)\"\r\n                        class=\"text-center row-day\" [ngClass]=\"setCssClasses(day)\"\r\n                        [attr.title]=\"getTitle(day.dataItems)\" style=\"position:relative\">\r\n                            <div *ngFor=\"let dayItem of day.dataItems\" [ngClass]=\"dayItem.cssClass\"\r\n                                [style.height.px]=\"(CELLHEIGHTPX/CELLHEIGHTPERCENT)*dayItem.proportion\"></div>\r\n                        <div style=\"position:absolute; top:-2px; right:3px;\">\r\n                            <small class=\"day\" *ngIf=\"day.exists\">{{day.number}}</small>\r\n                        </div>\r\n                    </td>\r\n                </tr>\r\n            </tbody>\r\n        </table>\r\n        <div class=\"pull-right\">\r\n            <small *ngFor=\"let occupation of occupationLegend\" style=\"padding-right:3px;\">\r\n                <span  [ngClass]=\"occupation?.cssClass\">&nbsp;&nbsp;</span>\r\n                {{occupation.name}}\r\n            </small>\r\n        </div>\r\n    </loading-indicator>\r\n</div>\r\n", styles: ["table.scheduler-year.table-fixed{table-layout:fixed;width:100%}table.scheduler-year td.row-month,table.scheduler-year th.row-month{width:7%;max-height:34px}table.scheduler-year td.row-day,table.scheduler-year th.row-day{width:3%;padding:0;max-height:34px}table.scheduler-year td.day{opacity:1;text-shadow:0px 0px 1px #9E93C1}table.scheduler-year td.not-existing-day{background-color:#a1b2ce}table.scheduler-year td.clickable{cursor:pointer}table.scheduler-year td.day-of-week-0:not(.custom-cell),table.scheduler-year td.day-of-week-6:not(.custom-cell){background-color:#c1d7ff}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i3.LoadingIndicatorComponent, selector: "loading-indicator", inputs: ["text", "spinnerSize", "minHeight"] }], encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: SchedulerYearCalendarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'scheduler-year-calendar', encapsulation: ViewEncapsulation.None, providers: [DatePipe], standalone: false, template: "<div>\r\n    <div style=\"width:5%; float:left;\">\r\n        <div class=\"btn-group\">\r\n            <button class=\"btn btn-default btn-xs\" (click)=\"decreaseYear()\" data-toggle=\"tooltip\" title=\"{{year-1}}\"><i\r\n                    class=\"fas fa-angle-left\"></i></button>\r\n        </div>\r\n    </div>\r\n    <div [style.width.%]=\"90\" style=\"float:left;\" class=\"text-center\"><h4>{{year}}</h4></div>\r\n    <div style=\"float:right; width:5%;\">\r\n        <div class=\"btn-group pull-right\">\r\n            <button class=\"btn btn-default btn-xs\" (click)=\"increaseYear()\" data-toggle=\"tooltip\" title=\"{{year+1}}\"><i\r\n                    class=\"fas fa-angle-right\"></i></button>\r\n        </div>\r\n    </div>\r\n</div>\r\n<div>\r\n    <loading-indicator #loadingIndicator>\r\n        <table class=\"scheduler-year table table-bordered table-hover dataTable\">\r\n            <thead>\r\n                <tr>\r\n                    <th class=\"row-month\"></th>\r\n                    <th *ngFor=\"let day of months[0].days\" class=\"row-day text-center\">{{day.number}}</th>\r\n                </tr>\r\n            </thead>\r\n            <tbody>\r\n                <tr *ngFor=\"let month of months\">\r\n                    <td class=\"row-month\">{{month.name}}</td>\r\n                    <td *ngFor=\"let day of month.days\" (click)=\"onCellClick($event, month, day)\"\r\n                        class=\"text-center row-day\" [ngClass]=\"setCssClasses(day)\"\r\n                        [attr.title]=\"getTitle(day.dataItems)\" style=\"position:relative\">\r\n                            <div *ngFor=\"let dayItem of day.dataItems\" [ngClass]=\"dayItem.cssClass\"\r\n                                [style.height.px]=\"(CELLHEIGHTPX/CELLHEIGHTPERCENT)*dayItem.proportion\"></div>\r\n                        <div style=\"position:absolute; top:-2px; right:3px;\">\r\n                            <small class=\"day\" *ngIf=\"day.exists\">{{day.number}}</small>\r\n                        </div>\r\n                    </td>\r\n                </tr>\r\n            </tbody>\r\n        </table>\r\n        <div class=\"pull-right\">\r\n            <small *ngFor=\"let occupation of occupationLegend\" style=\"padding-right:3px;\">\r\n                <span  [ngClass]=\"occupation?.cssClass\">&nbsp;&nbsp;</span>\r\n                {{occupation.name}}\r\n            </small>\r\n        </div>\r\n    </loading-indicator>\r\n</div>\r\n", styles: ["table.scheduler-year.table-fixed{table-layout:fixed;width:100%}table.scheduler-year td.row-month,table.scheduler-year th.row-month{width:7%;max-height:34px}table.scheduler-year td.row-day,table.scheduler-year th.row-day{width:3%;padding:0;max-height:34px}table.scheduler-year td.day{opacity:1;text-shadow:0px 0px 1px #9E93C1}table.scheduler-year td.not-existing-day{background-color:#a1b2ce}table.scheduler-year td.clickable{cursor:pointer}table.scheduler-year td.day-of-week-0:not(.custom-cell),table.scheduler-year td.day-of-week-6:not(.custom-cell){background-color:#c1d7ff}\n"] }]
        }], ctorParameters: () => [{ type: i1.DatePipe }, { type: i2.LoggerService }], propDecorators: { loadingIndicator: [{
                type: ViewChild,
                args: ['loadingIndicator', { static: true }]
            }], year: [{
                type: Input
            }], occupationLegend: [{
                type: Input
            }], _slotItems: [{
                type: Input,
                args: ['slotItems']
            }], cellClick: [{
                type: Output
            }] } });
// eslint-disable-next-line @typescript-eslint/naming-convention
var TMonth;
(function (TMonth) {
    TMonth[TMonth["Jan"] = 0] = "Jan";
    TMonth[TMonth["Feb"] = 1] = "Feb";
    TMonth[TMonth["Mar"] = 2] = "Mar";
    TMonth[TMonth["Apr"] = 3] = "Apr";
    TMonth[TMonth["May"] = 4] = "May";
    TMonth[TMonth["Jun"] = 5] = "Jun";
    TMonth[TMonth["Jul"] = 6] = "Jul";
    TMonth[TMonth["Aug"] = 7] = "Aug";
    TMonth[TMonth["Sep"] = 8] = "Sep";
    TMonth[TMonth["Oct"] = 9] = "Oct";
    TMonth[TMonth["Nov"] = 10] = "Nov";
    TMonth[TMonth["Dec"] = 11] = "Dec";
})(TMonth || (TMonth = {}));
class DateCellClickEvent {
    constructor() {
        this.dataItems = [];
    }
}
class Month {
}
class Day {
    constructor() {
        this.dataItems = [];
    }
}
class DateDataItem {
}
class OccupationLegend {
}

const PopoverModuleForRoot = PopoverModule.forRoot();
class SchedulerYearModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: SchedulerYearModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.13", ngImport: i0, type: SchedulerYearModule, declarations: [SchedulerYearCalendarComponent], imports: [CommonModule,
            FormsModule,
            NgScrollbarModule,
            SwtControlsModule, i1$1.PopoverModule], exports: [SchedulerYearCalendarComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: SchedulerYearModule, imports: [CommonModule,
            FormsModule,
            NgScrollbarModule,
            SwtControlsModule, //loadingIndicator
            PopoverModuleForRoot] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: SchedulerYearModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        FormsModule,
                        NgScrollbarModule,
                        SwtControlsModule, //loadingIndicator
                        PopoverModuleForRoot,
                    ],
                    declarations: [
                        SchedulerYearCalendarComponent
                    ],
                    exports: [
                        SchedulerYearCalendarComponent
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { DateCellClickEvent, DateDataItem, Day, Month, OccupationLegend, SchedulerYearCalendarComponent, SchedulerYearModule };
//# sourceMappingURL=sowatech-shared-scheduler-year.mjs.map
