import * as i0 from '@angular/core';
import { Injectable, Input, ViewChild, Component, NgModule } from '@angular/core';
import { Subject } from 'rxjs';
import * as i3 from '@angular/router';
import { ActivationStart, RouterOutlet, RouterModule } from '@angular/router';
import * as i1 from '@sowatech/shared/logger';
import * as i4 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i5 from 'ngx-scrollbar';
import { NgScrollbarModule } from 'ngx-scrollbar';

class SideContentService {
    constructor() {
        this.onInit = new Subject();
        this.onRemove = new Subject();
        this.onShow = new Subject();
        this.onHide = new Subject();
        /**Der sideContent wurde geöffnet*/
        this.opened = new Subject();
        /**Der sideContent wurde geschlossen*/
        this.closed = new Subject();
        this.isOpen = false;
    }
    init(config) {
        this.lastConfig = config;
        this.onInit.next(config);
    }
    show() {
        this.onShow.next();
    }
    hide() {
        this.onHide.next();
    }
    remove() {
        this.onRemove.next();
    }
    /**Nur aufzurufen vom sideContent selbst*/
    setOpened(value) {
        if (this.isOpen == value)
            return;
        this.isOpen = value;
        if (this.isOpen)
            this.opened.next();
        else
            this.closed.next();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: SideContentService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: SideContentService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: SideContentService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: () => [] });

const CLASS$1 = 'SideContentComponent';
class SideContentComponent {
    constructor(logger, sideContentService, router) {
        this.logger = logger;
        this.sideContentService = sideContentService;
        this.router = router;
        this.subscriptions = [];
        this.isOpen = false;
    }
    ngOnInit() {
        this.subscriptions.push(this.sideContentService.onRemove.subscribe(() => {
            this.remove();
        }), this.sideContentService.onInit.subscribe((config) => {
            this.init(config);
        }), this.sideContentService.onHide.subscribe(() => {
            this.hide();
        }), this.sideContentService.onShow.subscribe(() => {
            this.show();
        }));
        //FIX: https://stackoverflow.com/questions/55617772/angular-7-multiple-outlets-error-cannot-activate-an-already-activated-outle
        if (this.hackDeactivateOutletOnActivationStart) {
            this.subscriptions.push(this.router.events.subscribe(e => {
                if (e instanceof ActivationStart && e.snapshot.outlet === 'sideContent')
                    this.outlet.deactivate();
            }));
        }
        //--notwendig da reihenfolge ggf so dass sideContentService bereist ein init ausgelöst hat bevor die sideContentComponent selbst initialisiert war
        if (this.sideContentService.lastConfig != null)
            this.init(this.sideContentService.lastConfig);
    }
    async init(config) {
        this.logger.log(CLASS$1 + '.onInit');
        this.config = config;
        this.setSideContentOpenerVisible();
        this.open(false);
        const navSuccess = await this.router.navigate([{ outlets: { sideContent: null } }], { skipLocationChange: true });
        if (!navSuccess)
            this.logger.warn(CLASS$1 + 'onInit navigate to sideContent=null not successfull');
        this.logger.log(CLASS$1 + '.onInit done');
    }
    async remove() {
        this.logger.log(CLASS$1 + '.onRemove');
        this.setSideContentOpenerInvisible();
        this.open(false);
        const navSuccess = await this.router.navigate([{ outlets: { sideContent: null } }], { skipLocationChange: true });
        if (!navSuccess)
            this.logger.warn(CLASS$1 + '.onRemove navigate to sideContent=null not successfull');
    }
    toggle() {
        this.open(!this.isOpen);
    }
    hide() {
        this.open(false);
    }
    show() {
        this.open(true);
    }
    setSideContentOpenerVisible() {
        this.sideContent.nativeElement.classList.add('show');
    }
    setSideContentOpenerInvisible() {
        this.sideContent.nativeElement.classList.remove('show');
    }
    open(value) {
        if (this.isOpen == value)
            return;
        this.isOpen = value;
        if (this.isOpen) {
            this.setSideContentOpenerVisible(); //soll eigtl durch init schon gesetzt sein; um irritation (falls kein init aufgerufen) zu vermeiden hier noch einmal
            this.contentBox.nativeElement.classList.add('show');
            this.content.nativeElement.classList.add('show');
        }
        else {
            this.contentBox.nativeElement.classList.remove('show');
            this.content.nativeElement.classList.remove('show');
        }
        this.sideContentService.setOpened(this.isOpen);
    }
    ngOnDestroy() {
        this.subscriptions.forEach(s => s.unsubscribe());
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: SideContentComponent, deps: [{ token: i1.LoggerService }, { token: SideContentService }, { token: i3.Router }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: SideContentComponent, isStandalone: false, selector: "side-content", inputs: { hackDeactivateOutletOnActivationStart: "hackDeactivateOutletOnActivationStart" }, viewQueries: [{ propertyName: "outlet", first: true, predicate: RouterOutlet, descendants: true }, { propertyName: "sideContent", first: true, predicate: ["sideContent"], descendants: true, static: true }, { propertyName: "contentBox", first: true, predicate: ["contentBox"], descendants: true, static: true }, { propertyName: "icon", first: true, predicate: ["icon"], descendants: true, static: true }, { propertyName: "content", first: true, predicate: ["content"], descendants: true, static: true }], ngImport: i0, template: "<div #sideContent class=\"side-content-wrapper\">\r\n    <div #contentBox class=\"side-content-box\"\r\n        [style.margin-right.px]=\"config?.contentWidth ? -config?.contentWidth:-800\">\r\n        <div class=\"spin-icon\" [title]=\"config?.iconTooltip\" (click)=\"toggle()\">\r\n            <i #icon class=\"fa\" [ngClass]=\"config?.icon\"></i>\r\n        </div>\r\n        <div #content class=\"side-content\" [style.width.px]=\"config?.contentWidth ? config?.contentWidth:800\">\r\n            <div #contentCore>\r\n                <ng-scrollbar [ngStyle]=\"{'max-height.px':config?.contentMaxHeight}\">\r\n                    <router-outlet #outlet name=\"sideContent\"></router-outlet>\r\n                </ng-scrollbar>\r\n            </div>\r\n        </div>\r\n    </div>\r\n</div>\r\n", styles: [".side-content-wrapper{position:fixed;z-index:2045;top:90px;right:0;display:none}.side-content-wrapper.show{display:block}.side-content-box{margin-right:-800px;position:relative;z-index:2000;-webkit-transition-duration:.8s;transition-duration:.8s}.side-content-box.show{margin-right:0!important}.side-content{width:800px;margin-left:40px;background:#f3f3f4;min-height:36px}.side-content.show{box-shadow:-1px 1px 17px gray}\n"], dependencies: [{ kind: "directive", type: i3.RouterOutlet, selector: "router-outlet", inputs: ["name", "routerOutletData"], outputs: ["activate", "deactivate", "attach", "detach"], exportAs: ["outlet"] }, { kind: "directive", type: i4.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i4.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "component", type: i5.NgScrollbar, selector: "ng-scrollbar:not([externalViewport])", exportAs: ["ngScrollbar"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: SideContentComponent, decorators: [{
            type: Component,
            args: [{ selector: 'side-content', standalone: false, template: "<div #sideContent class=\"side-content-wrapper\">\r\n    <div #contentBox class=\"side-content-box\"\r\n        [style.margin-right.px]=\"config?.contentWidth ? -config?.contentWidth:-800\">\r\n        <div class=\"spin-icon\" [title]=\"config?.iconTooltip\" (click)=\"toggle()\">\r\n            <i #icon class=\"fa\" [ngClass]=\"config?.icon\"></i>\r\n        </div>\r\n        <div #content class=\"side-content\" [style.width.px]=\"config?.contentWidth ? config?.contentWidth:800\">\r\n            <div #contentCore>\r\n                <ng-scrollbar [ngStyle]=\"{'max-height.px':config?.contentMaxHeight}\">\r\n                    <router-outlet #outlet name=\"sideContent\"></router-outlet>\r\n                </ng-scrollbar>\r\n            </div>\r\n        </div>\r\n    </div>\r\n</div>\r\n", styles: [".side-content-wrapper{position:fixed;z-index:2045;top:90px;right:0;display:none}.side-content-wrapper.show{display:block}.side-content-box{margin-right:-800px;position:relative;z-index:2000;-webkit-transition-duration:.8s;transition-duration:.8s}.side-content-box.show{margin-right:0!important}.side-content{width:800px;margin-left:40px;background:#f3f3f4;min-height:36px}.side-content.show{box-shadow:-1px 1px 17px gray}\n"] }]
        }], ctorParameters: () => [{ type: i1.LoggerService }, { type: SideContentService }, { type: i3.Router }], propDecorators: { outlet: [{
                type: ViewChild,
                args: [RouterOutlet]
            }], sideContent: [{
                type: ViewChild,
                args: ['sideContent', { static: true }]
            }], contentBox: [{
                type: ViewChild,
                args: ['contentBox', { static: true }]
            }], icon: [{
                type: ViewChild,
                args: ['icon', { static: true }]
            }], content: [{
                type: ViewChild,
                args: ['content', { static: true }]
            }], hackDeactivateOutletOnActivationStart: [{
                type: Input
            }] } });
class SideContentConfig {
    constructor(icon, iconTooltip, contentWidth = 800, contentMaxHeight = 800) {
        this.icon = icon;
        this.iconTooltip = iconTooltip;
        this.contentWidth = contentWidth;
        this.contentMaxHeight = contentMaxHeight;
    }
}

const CLASS = 'SideContentComponent';
class EmptySideContentComponent {
    constructor(logger, router) {
        this.logger = logger;
        this.router = router;
    }
    ngOnInit() {
    }
    ngOnDestroy() {
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: EmptySideContentComponent, deps: [{ token: i1.LoggerService }, { token: i3.Router }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.13", type: EmptySideContentComponent, isStandalone: false, selector: "empty-side-content", ngImport: i0, template: "<div style=\"text-align: center;\">\r\n    <b i18n=\"@@EmptySideContent.NoContentChosen.msg.Text\">Kein Inhalt ausgew\u00E4hlt!</b>\r\n</div>\r\n" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: EmptySideContentComponent, decorators: [{
            type: Component,
            args: [{ selector: 'empty-side-content', standalone: false, template: "<div style=\"text-align: center;\">\r\n    <b i18n=\"@@EmptySideContent.NoContentChosen.msg.Text\">Kein Inhalt ausgew\u00E4hlt!</b>\r\n</div>\r\n" }]
        }], ctorParameters: () => [{ type: i1.LoggerService }, { type: i3.Router }] });

const sideContentRoutes = [
    { path: 'empty-side-content', component: EmptySideContentComponent, outlet: 'sideContent' },
];
const sideRouting = RouterModule.forChild(sideContentRoutes);

class SideContentModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: SideContentModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.13", ngImport: i0, type: SideContentModule, declarations: [EmptySideContentComponent,
            SideContentComponent], imports: [i3.RouterModule, RouterModule,
            CommonModule,
            NgScrollbarModule], exports: [SideContentComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: SideContentModule, imports: [sideRouting,
            RouterModule,
            CommonModule,
            NgScrollbarModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: SideContentModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        sideRouting,
                        RouterModule,
                        CommonModule,
                        NgScrollbarModule
                    ],
                    declarations: [
                        EmptySideContentComponent,
                        SideContentComponent
                    ],
                    exports: [
                        SideContentComponent
                    ],
                    providers: []
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { EmptySideContentComponent, SideContentComponent, SideContentConfig, SideContentModule, SideContentService };
//# sourceMappingURL=sowatech-shared-side-content.mjs.map
