import * as i0 from '@angular/core';
import { Injectable, Pipe, NgModule } from '@angular/core';
import { BehaviorSubject, Subject } from 'rxjs';
import * as i1 from '@sowatech/shared/logger';
import * as i1$1 from '@sowatech/shared/shared-config';
import * as i1$2 from '@angular/platform-browser';
import { CommonModule } from '@angular/common';
import '@angular/localize/init';

class BankAccountValidationService {
    validateBankAccount(iban, bic) {
        let resultFlags = BankAccountValidationFlags.valid;
        if (!this.validateIBAN(iban))
            resultFlags |= BankAccountValidationFlags.invalidIBAN;
        if (!this.validateBIC(bic))
            resultFlags |= BankAccountValidationFlags.invalidBIC;
        return resultFlags;
    }
    validateBIC(bic) {
        try {
            if (bic == null)
                return true;
            let valid = true;
            //if (bic.length != 0 && bic.length != 8 && bic.length != 11)
            //    valid = false;
            if (bic.length != 0 && !/^[a-zA-Z]+$/.test(bic.substring(0, 5)))
                valid = false;
            if (bic[6] == '0' || bic[6] == '1')
                valid = false;
            if (bic.length > 7 && bic[7].toUpperCase() == 'O')
                valid = false;
            if (bic.length == 11 && bic[8].toUpperCase() == 'X' && !(bic[9].toUpperCase() == 'X' && bic[10].toUpperCase() == 'X'))
                valid = false;
            return valid;
        }
        catch {
            return false;
        }
    }
    validateIBAN(iban) {
        try {
            if (iban == null || iban.length == 0)
                return true;
            const CODE_LENGTHS = {
                AD: 24, AE: 23, AT: 20, AZ: 28, BA: 20, BE: 16, BG: 22, BH: 22, BR: 29,
                CH: 21, CR: 21, CY: 28, CZ: 24, DE: 22, DK: 18, DO: 28, EE: 20, ES: 24,
                FI: 18, FO: 18, FR: 27, GB: 22, GI: 23, GL: 18, GR: 27, GT: 28, HR: 21,
                HU: 28, IE: 22, IL: 23, IS: 26, IT: 27, JO: 30, KW: 30, KZ: 20, LB: 28,
                LI: 21, LT: 20, LU: 20, LV: 21, MC: 27, MD: 24, ME: 22, MK: 19, MR: 27,
                MT: 31, MU: 30, NL: 18, NO: 15, PK: 24, PL: 28, PS: 29, PT: 25, QA: 29,
                RO: 24, RS: 22, SA: 24, SE: 24, SI: 19, SK: 24, SM: 27, TN: 24, TR: 26
            };
            const replacedIban = iban.toUpperCase().replace(/[^A-Z0-9]/g, '');
            const code = replacedIban.match(/^([A-Z]{2})(\d{2})([A-Z\d]+)$/);
            if (!code || replacedIban.length !== CODE_LENGTHS[code[1]])
                return false;
            const digits = (code[3] + code[1] + code[2]).replace(/[A-Z]/g, (letter) => (letter.charCodeAt(0) - 55).toString());
            return this.mod97(digits) === 1;
        }
        catch {
            return false;
        }
    }
    mod97(string) {
        let checksum = string.slice(0, 2);
        let fragment;
        for (let offset = 2; offset < string.length; offset += 7) {
            fragment = String(checksum) + string.substring(offset, offset + 7);
            checksum = parseInt(fragment, 10) % 97;
        }
        return checksum;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: BankAccountValidationService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: BankAccountValidationService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: BankAccountValidationService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });
var BankAccountValidationFlags;
(function (BankAccountValidationFlags) {
    BankAccountValidationFlags[BankAccountValidationFlags["valid"] = 0] = "valid";
    BankAccountValidationFlags[BankAccountValidationFlags["invalidIBAN"] = 2] = "invalidIBAN";
    BankAccountValidationFlags[BankAccountValidationFlags["invalidBIC"] = 4] = "invalidBIC";
})(BankAccountValidationFlags || (BankAccountValidationFlags = {}));
class BankAccountValidationFlagsHelper {
    static getErrorTexts(flags) {
        const result = [];
        if ((flags & BankAccountValidationFlags.invalidBIC) == BankAccountValidationFlags.invalidBIC)
            result.push($localize `:@@BankAccount.InvalidBic.dsp.Label:Ungültige BIC`);
        if ((flags & BankAccountValidationFlags.invalidIBAN) == BankAccountValidationFlags.invalidIBAN)
            result.push($localize `:@@BankAccount.InvalidIban.dsp.Label:Ungültige IBAN`);
        return result;
    }
}

class CommunicationService {
    constructor(logger) {
        this.logger = logger;
        this.channels = {};
    }
    static { this.currentHandleCreatorNumber = 0; }
    createChannel() {
        CommunicationService.currentHandleCreatorNumber++;
        const handle = CommunicationService.currentHandleCreatorNumber.toString();
        if (!this.channels[handle])
            this.channels[handle] = new BehaviorSubject(null);
        else
            throw (new Error('generated channel handle already exists'));
        return handle;
    }
    sendMessage(handle, data, messageType) {
        this.getChannel(handle).next(new Message(data, messageType));
    }
    subscribeToChannel(handle, next, error, complete) {
        return this.getChannel(handle).subscribe(next, error, complete);
    }
    getChannel(handle) {
        if (!this.channels[handle])
            throw (new Error('channel not exists ' + handle));
        return this.channels[handle];
    }
    deleteChannel(handle) {
        const subject = this.getChannel(handle);
        subject.complete();
        this.channels[handle] = undefined;
        this.logger.log('channel deleted ' + handle);
    }
    deleteChannels(handles) {
        for (const handle of handles)
            this.deleteChannel(handle);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CommunicationService, deps: [{ token: i1.LoggerService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CommunicationService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: CommunicationService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }], ctorParameters: () => [{ type: i1.LoggerService }] });
class Message {
    constructor(data, messageType //optional type to help distinguish between different messagedata
    ) {
        this.data = data;
        this.messageType = messageType;
    }
}

class I18nService {
    constructor(config) {
        this.config = config;
        this.messages = {};
        this.regex = {
            key: new RegExp('@@(.*?):'),
            fallback: new RegExp('@@.*?:(.*)$'),
            message: new RegExp('@@.*:.*')
        };
    }
    /**
     * z.B. i18nService.translate("@@Person.UpdateAddress.error.msg.Text:Fehler beim Bearbeiten der Adressdaten");
     */
    translate(message, values = []) {
        const key = this.regex.key.exec(message)[1];
        const fallback = this.regex.fallback.exec(message)[1];
        let translated = this.localize(key, fallback);
        if (values.length > 0)
            translated = this.replace(translated, values);
        return translated;
    }
    /**
     * z.B. i18nService.replace($localize`:@@Person.streetNameIs.msg.Text:Der Straßenname ist $0`, [this.model.streetName]);
     */
    replace(msg, values) {
        values.forEach((value, index) => {
            if (this.regex.message.test(value)) {
                const subtranslation = this.translate(value, []);
                msg = msg.replace(new RegExp(`\\$${index}`, 'g'), subtranslation);
            }
            else
                msg = msg.replace(new RegExp(`\\$${index}`, 'g'), value);
        });
        return msg;
    }
    localize(key, fallback = '') {
        if ($localize.locale === undefined || (fallback && $localize.locale === this.config.sourceLanguage))
            return fallback;
        return this.messages[key];
    }
    // i18nService.concat(messages);
    concat(dict) {
        // eslint-disable-next-line guard-for-in
        for (const key in dict)
            this.messages[key] = this.messages[key] ?? dict[key];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: I18nService, deps: [{ token: i1$1.SharedConfigService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: I18nService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: I18nService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [{ type: i1$1.SharedConfigService }] });

class PrintService {
    constructor() {
        this.emptyTitle = $localize `:@@PrintService.EmptyTitle.dsp.Title:Dokument`;
        this.stylesToBeLoaded = 0;
    }
    printNodeById(id, title = this.emptyTitle) {
        const node = document.getElementById(id);
        this.print(node, title);
    }
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    printNode(node, cloneNode = true, title = this.emptyTitle) {
        this.print(node.cloneNode(true), title);
    }
    /**
     * Hack für SHANG-406.
     * Kann bei Update von `ngx-scrollbar` kaputtgehen.
     */
    sanitizeNgScrollbarForPrint(rootElement) {
        const elementKeepChildrenSelectors = [
            'ng-scrollbar',
            '.ng-scrollbar-wrapper',
            '.ng-scroll-viewport-wrapper',
            '.ng-scroll-viewport',
            '.ng-scroll-content',
        ];
        const elementRemoveChildrenSelectors = [
            'scrollbar-x',
            'scrollbar-y',
        ];
        for (const selector of elementKeepChildrenSelectors) {
            let element = rootElement.querySelector(selector);
            while (element) {
                this.removeElementKeepChildren(element);
                element = rootElement.querySelector(selector);
            }
        }
        for (const selector of elementRemoveChildrenSelectors) {
            let element = rootElement.querySelector(selector);
            while (element) {
                this.removeElementWithChildren(element);
                element = rootElement.querySelector(selector);
            }
        }
    }
    removeElementWithChildren(element) {
        const parent = element.parentNode;
        parent.removeChild(element);
    }
    removeElementKeepChildren(element) {
        const parent = element.parentNode;
        while (element.firstChild)
            parent.insertBefore(element.firstChild, element);
        parent.removeChild(element);
    }
    print(node, title) {
        this.window = window.open('', 'PRINT', 'height=800,width=1000');
        const styles = this.getStylesFromParentWindow(this.window.document);
        this.addStylesThenPrint(styles);
        this.window.document.head.appendChild(this.getTitleEl(title));
        this.window.document.body.appendChild(node);
        this.sanitizeNgScrollbarForPrint(this.window.document.body);
        this.window.focus();
    }
    getTitleEl(title) {
        const titleEl = document.createElement('title');
        titleEl.innerText = title;
        return titleEl;
    }
    getStylesFromParentWindow(doc) {
        const styles = [];
        document.querySelectorAll('link').forEach(htmlElement => {
            if (htmlElement.rel === 'stylesheet') {
                const styleSheetElement = doc.createElement('link');
                const absoluteUrl = new URL(htmlElement.href).href;
                styleSheetElement.rel = 'stylesheet';
                styleSheetElement.type = 'text/css';
                styleSheetElement.href = absoluteUrl;
                styles.push(styleSheetElement);
            }
        });
        document.querySelectorAll('style').forEach(htmlElement => {
            styles.push(htmlElement.cloneNode(true));
        });
        return styles;
    }
    addStylesThenPrint(styles) {
        this.stylesToBeLoaded = styles.length;
        styles.forEach((css) => {
            css.onload = () => this.onStyleLoaded();
            this.window.document.head.appendChild(css);
        });
    }
    onStyleLoaded() {
        this.stylesToBeLoaded--;
        if (this.stylesToBeLoaded === 0) {
            setTimeout(() => {
                this.window.print();
                this.window.close();
            }, 100);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: PrintService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: PrintService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: PrintService, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }] });

class SafeHtmlPipe {
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
    }
    transform(html) {
        return this.sanitizer.bypassSecurityTrustHtml(html);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: SafeHtmlPipe, deps: [{ token: i1$2.DomSanitizer }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.13", ngImport: i0, type: SafeHtmlPipe, isStandalone: false, name: "safeHTML" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: SafeHtmlPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'safeHTML',
                    standalone: false
                }]
        }], ctorParameters: () => [{ type: i1$2.DomSanitizer }] });

class StateMachineService {
    createStateMachine(initialState, transitions, finalStates) {
        const sm = new StateMachine(initialState, transitions, finalStates);
        return sm;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: StateMachineService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: StateMachineService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: StateMachineService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });
class StateMachine {
    constructor(initialState, transitions, finalStates) {
        this.initialState = initialState;
        this.transitions = transitions;
        this.finalStates = finalStates;
        this.onStateChanged = new Subject();
        this.onFinalState = new Subject();
        this._state = initialState;
    }
    set currentState(value) {
        if (value != this._state) {
            this._state = value;
            this.onStateChanged.next(this._state);
        }
        if (this.finalStates && this.finalStates.indexOf(value) > 0)
            this.onFinalState.next(this._state);
    }
    get currentState() {
        return this._state;
    }
    resetState() {
        this._state = this.initialState;
    }
    sendInput(input) {
        const relevantTransitions = this.transitions.filter((trans) => trans.fromState == this.currentState && trans.input == input);
        if (relevantTransitions.length == 0) {
            //no state change
        }
        if (relevantTransitions.length == 1)
            this.currentState = relevantTransitions[0].toState;
        if (relevantTransitions.length > 1) {
            //error
            console.error('more than 1 transition');
        }
    }
}

class UtilitiesModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: UtilitiesModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.13", ngImport: i0, type: UtilitiesModule, declarations: [SafeHtmlPipe], imports: [CommonModule], exports: [SafeHtmlPipe] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: UtilitiesModule, imports: [CommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.13", ngImport: i0, type: UtilitiesModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule],
                    declarations: [
                        SafeHtmlPipe
                    ],
                    exports: [
                        SafeHtmlPipe
                    ],
                    providers: []
                }]
        }] });

const ensureArray = (arg) => Array.isArray(arg) ? arg : [arg];

/**
 * Generated bundle index. Do not edit.
 */

export { BankAccountValidationFlags, BankAccountValidationFlagsHelper, BankAccountValidationService, CommunicationService, I18nService, Message, PrintService, SafeHtmlPipe, StateMachine, StateMachineService, UtilitiesModule, ensureArray };
//# sourceMappingURL=sowatech-shared-utilities.mjs.map
