import { HttpErrorResponse } from '@angular/common/http';
import { Actions } from '@ngrx/effects';
import { Action, ActionCreator, Creator } from '@ngrx/store';
import { Observable } from 'rxjs';
import { ErrorParams } from './error-handling';
/**
 * Abkürzung von `createEffect` für den Standardfall, wenn man auf Actions reagiert
 * ```ts
 * loadList$ = createActionEffect(
 *     [listActions.init, apiActions.createSuccess],
 *     switchMap(() => this.webApi.getList()),
 * );
 * create$ = createActionEffect(
 *     listActions.create,
 *     pipe(
 *         showDialog(new CreateDialog()),
 *         switchMap(({ dto }) => this.webApi.create(dto)),
 *     ),
 * );
 * ```
 */
export declare function createActionEffect<T extends string, P extends Creator<any[], object>>(actions: ActionCreator<T, P> | ActionCreator<T, P>[], fn: (obs$: Observable<ReturnType<P>>) => Observable<Action>, actions$?: Actions<any>): Observable<Action<string>> & import("@ngrx/effects").CreateEffectMetadata;
export declare abstract class EffectBase {
    protected readonly actions$: Actions<any>;
    protected on<T extends string, P extends Creator<any[], object>>(actions: ActionCreator<T, P> | ActionCreator<T, P>[], fn: (obs$: Observable<ReturnType<P>>) => Observable<Action>): Observable<Action<string>> & import("@ngrx/effects").CreateEffectMetadata;
    protected onError(action: ActionCreator<string, Creator<[HttpErrorResponse], {
        error: ErrorParams;
    }>>, actionText: string): Observable<{
        error: ErrorParams;
        actionText: string;
        handling: "messageBox" | "dialog";
    } & Action<"[App] Error">> & import("@ngrx/effects").CreateEffectMetadata;
    protected onDialogError(action: ActionCreator<string, Creator<[HttpErrorResponse], {
        error: ErrorParams;
    }>>): Observable<{
        error: ErrorParams;
        actionText: string;
        handling: "messageBox" | "dialog";
    } & Action<"[App] Error">> & import("@ngrx/effects").CreateEffectMetadata;
}
