import 'moment/locale/de';
import { ChangeDetectorRef, EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { LoggerService } from '@sowatech/shared/logger';
import moment from 'moment';
import { Subscription } from 'rxjs';
import { DayItem, IScheduledItem, MonthItem, ScheduledItemClickEvent, ScheduledItemDragDropEvent, ScheduledItemModel, TimeLineSlot, TimeLineSlotCell, TimelineSlotDataItem, TimeLineSlotHeader, TimeSlotCellClickEvent } from './scheduler-shared';
import { TScheduledItemsDateFormat } from './types/scheduled-items-date-format.type';
import { TSchedulerVariantType } from './types/scheduler-variant.type';
import * as i0 from "@angular/core";
export declare const CELL_PADDING = 4;
export declare const TABLE_MARGIN_VERTICAL = 0;
export declare const TABLE_BORDER = 1;
export type THeaderSlotSpan = 1 | 2 | 3 | 4 | 6 | 8 | 12 | 24;
export declare abstract class SchedulerTimelineBase implements OnInit, OnDestroy {
    protected logger: LoggerService;
    protected changeDetectorRef: ChangeDetectorRef;
    constructor(logger: LoggerService, changeDetectorRef: ChangeDetectorRef);
    protected subscriptions: Subscription[];
    protected onInitCompleted: boolean;
    ngOnInit(): void;
    ngOnDestroy(): void;
    refresh(): void;
    tableWidth: number;
    protected tableCustomColumnsWidth: number;
    headerHeight: number;
    private numOfHeaderRows;
    headerRowHeight: number;
    headerSlotSpan: number;
    showNameOfMonth: boolean;
    showNameOfDay: boolean;
    cellPadding: number;
    small: boolean;
    rowHeight: number;
    protected setVariant(value: TSchedulerVariantType): void;
    protected variant: TSchedulerVariantType;
    protected setSlotUnitOfTime(unit: moment.unitOfTime.Diff, visibleRangeFrom?: string, visibleRangeTo?: string): void;
    protected timelineSlotUnitOfTime: moment.unitOfTime.Diff;
    protected visibleHoursFrom: number;
    visibleHoursUntil: number;
    private timeLineDate;
    setTimeLineDate(value: Date | string): void;
    protected timeLineStartMoment: moment.Moment;
    protected timeLineEndMoment: moment.Moment;
    get timeLineStart(): Date;
    get timeLineEnd(): Date;
    monthItems: MonthItem[];
    dayItems: DayItem[];
    protected setSlotWidth(value: number): void;
    timeLineSlotWidth: number;
    get timeLineSlotOuterWidth(): number;
    timeLineSlotNumber: number;
    timeLineSlotHeaders: Array<TimeLineSlotHeader>;
    timeLineSlots: Array<TimeLineSlot>;
    private recalcTimeLine;
    protected recalcWidthsAndHeights(): void;
    setSlotDataItems(values: Array<TimelineSlotDataItem>): void;
    private _slotDataItems;
    timelineSlotsRefreshed: EventEmitter<void>;
    refreshTimelineSlots(): void;
    private buildDayItems;
    private buildMonthItems;
    private buildTimelineSlotMoments;
    protected isVisibleSlotMoment(slotMoment: moment.Moment): boolean;
    cellClick: EventEmitter<TimeSlotCellClickEvent>;
    onCellClick(event: MouseEvent, lineId: any, slot: TimeLineSlot): void;
    protected findTimeLineSlot(arg: Date | string): TimeLineSlot;
    protected findTimeLineSlots(argFrom: Date | string, argTo: Date | string): TimeLineSlot[];
    protected findTimeLineSlotCell(date: Date | string, lineId: string | number): TimeLineSlotCell;
    protected getDateOfCell(slot: TimeLineSlot, lineId: string | number): Date;
    cellClass(slot: TimeLineSlot, lineId: string | number): string;
    protected abstract getSlotCellLineId(timelineSlotDataItem: TimelineSlotDataItem): string | number;
    protected abstract getSlotCellLineId(scheduledItem: IScheduledItem): string | number;
    scheduledItemsDateFormat: TScheduledItemsDateFormat;
    protected formatScheduledItemsDate(src: Date | string): Date | string;
    scheduledItemsAsAppointments: boolean;
    setScheduledItems(values: Array<IScheduledItem>): void;
    protected scheduledDataItems: Array<IScheduledItem>;
    items: Array<ScheduledItemModel>;
    private assertFixedSlotWidth;
    refreshItems(): void;
    protected refreshScheduledItems(): void;
    protected abstract createScheduledItemModel(value: IScheduledItem): ScheduledItemModel;
    itemClick: EventEmitter<ScheduledItemClickEvent>;
    onItemClick(event: Event, item: ScheduledItemModel): void;
    setItemActive(itemIdent: any): any;
    setItemActive(item: ScheduledItemModel): any;
    removeItemActive(item: ScheduledItemModel): void;
    clearItemActive(): void;
    itemDrop: EventEmitter<ScheduledItemDragDropEvent>;
    itemDragStart: EventEmitter<ScheduledItemDragDropEvent>;
    itemDragOver: EventEmitter<ScheduledItemDragDropEvent>;
    allowDragItems: boolean;
    onItemDragStart(event: DragEvent, item: ScheduledItemModel): void;
    private dataTransferDragItemDummy;
    onItemDragOver(event: DragEvent): void;
    onItemDrop(event: DragEvent): void;
    private createScheduledItemDragDropEventData;
    private getDropTargetAttr;
    protected refreshCellAppointments(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SchedulerTimelineBase, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<SchedulerTimelineBase, never, never, {}, {}, never, never, true, never>;
}
