import moment, { Moment, unitOfTime } from 'moment';
import 'moment/locale/de';
import { TDestRowType } from './types/dest-row.type';
import { TSchedulerVariantType } from './types/scheduler-variant.type';
export declare class MonthItem {
    constructor(monthMoment: moment.Moment, numOfSlots?: number);
    dateIso: string;
    name: string;
    class: string;
    numOfSlots: number;
}
export declare class DayItem {
    constructor(dayMoment: moment.Moment, numOfSlots?: number, dayNameFormat?: string);
    dateOfDay: Date;
    dateIso: string;
    name: string;
    class: string;
    numOfSlots: number;
}
export declare class TimeLineSlotHeader {
    timelineSlotUnitOfTime: unitOfTime.Diff;
    timeStart: Moment;
    timeEnd: Moment;
    slotSpan: number;
    text: string;
    timeInfoTitle: string;
    cssClass: string;
    cellInfoTitle: string;
    constructor(timeStart: Moment, timelineSlotUnitOfTime: unitOfTime.Diff, colspan?: number);
    appendCellData(cssClass: string, cellTitle: string): void;
    setNewEndTime(timeEnd: Moment): void;
    isEndOfDay(visibleHoursUntil: number): boolean;
    get title(): string;
}
export declare class TimeLineSlot {
    private timelineSlotUnitOfTime;
    constructor(slotMoment: moment.Moment, timelineSlotUnitOfTime: moment.unitOfTime.Diff);
    private slotMoment;
    private get slotEndMoment();
    get date(): Date;
    isEndOfDay(visibleHoursUntil: number): boolean;
    isLastSlotCell(span: number): boolean;
    headerText: string;
    headerTitle: string;
    nameOfDay: string;
    class: string;
    slotDateTimeIso: string;
    slotDateIso: string;
    isFirstSlotCell: boolean;
    cells: object;
    getCell(lineId: any | 'HEADER' | 'ALL'): TimeLineSlotCell;
    getOrCreateCell(lineId: any | 'HEADER' | 'ALL'): TimeLineSlotCell;
    isSlotForDate(date: Date | string, timeLineVariant: TSchedulerVariantType): boolean;
    isSlotIntersectingDateInterval(dateFrom: Date | string, dateTo: Date | string): boolean;
    tryFillCellData(dataItems: Array<TimelineSlotDataItem>, timeLineVariant: TSchedulerVariantType, getSlotCellLineId: (timelineSlotDataItem: TimelineSlotDataItem) => any): void;
    headerCellTitle(): string;
    cellTitle(lineId?: any): string;
    headerCellClass(): string;
    cellClass(lineId?: any): string;
}
export declare class TimeLineSlotCell {
    constructor(lineId: any, dataItem?: TimelineSlotDataItem);
    title: string;
    text: string;
    class: string;
    lineId: any;
    add(dataItem: TimelineSlotDataItem): void;
    dataItems: Array<TimelineSlotDataItem>;
    appointments?: Array<AppointmentModel>;
    addAppointment(scheduledItem: IScheduledItem): void;
}
export declare class TimeSlotCellClickEvent {
    lineId: any;
    date: Date;
    dataItems: Array<TimelineSlotDataItem>;
}
export declare class TimelineSlotDataItem {
    resourceId?: any;
    date: Date;
    class?: string;
    title?: string;
    text?: string;
}
export interface IScheduledItem {
    start: Date | string;
    end: Date | string;
    resourceId?: string;
    text?: string;
    title?: string;
    class?: string;
    styles?: {
        [klass: string]: string;
    };
    ident?: string | number;
    bgColor?: string;
    bgStriped?: boolean;
    borderWidth?: string;
    borderColor?: string;
}
export declare class ScheduledItemModel implements IScheduledItem {
    resourceId: string;
    left: number;
    width: number;
    height: number;
    top: number;
    start: Date | string;
    end: Date | string;
    text: string;
    title: string;
    class: string;
    styles: {
        [klasse: string]: string;
    };
    ident: string | number;
    cellRowIndex: number;
    bgColor?: string;
    bgStriped?: boolean;
    borderWidth?: string;
    borderColor?: string;
    get diffSeconds(): number;
    get diffDays(): number;
}
export declare class ScheduledItemClickEvent {
    resourceId?: any;
    start: Date | string;
    end: Date | string;
    ident: any;
    text: string;
}
export declare class ScheduledItemDragDropEvent {
    original: DragEvent;
    destRowType: TDestRowType;
    destResourceId?: any;
    destStart?: Date | string;
    destEnd?: Date | string;
    constructor(original: DragEvent, item: IScheduledItem, destRowType?: TDestRowType, destResourceId?: any, destStart?: Date | string, destEnd?: Date | string);
    ident: any;
    text: string;
    srcResourceId?: any;
    srcStart: Date | string;
    srcEnd: Date | string;
}
export declare class SchedulerDataTransferItem {
    item: ScheduledItemModel;
    offsetX: number;
    offsetY: number;
    slotOffset: number;
    toJson(): string;
    static toJson(item: SchedulerDataTransferItem): string;
    static fromJson(json: string): SchedulerDataTransferItem;
}
export declare class AppointmentModel {
    constructor(scheduledItem: IScheduledItem, lineId: any);
    lineId: any;
    start: Date;
    end: Date;
    text: string;
    class: string;
    title: string;
    ident: string | number;
    resourceId?: string;
}
