import 'moment/locale/de';
import { AfterViewInit, ChangeDetectorRef, EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { DatasourceComponent } from '@sowatech/shared/ds-datasource';
import { LoggerService } from '@sowatech/shared/logger';
import moment from 'moment';
import { NgScrollbar } from 'ngx-scrollbar';
import { SchedulerTimelineBase, THeaderSlotSpan } from './scheduler-base';
import { IScheduledItem, ScheduledItemClickEvent, ScheduledItemDragDropEvent, ScheduledItemModel, TimelineSlotDataItem, TimeSlotCellClickEvent } from './scheduler-shared';
import { TScheduledItemsDateFormat } from './types/scheduled-items-date-format.type';
import { TSchedulerVariantType } from './types/scheduler-variant.type';
import * as i0 from "@angular/core";
export type UnitOfTimeWithRange = `${moment.unitOfTime.Diff}:${number}-${number}`;
export declare class SchedulerTimelineComponent extends SchedulerTimelineBase implements OnInit, OnDestroy, AfterViewInit {
    constructor(logger: LoggerService, changeDetectorRef: ChangeDetectorRef);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    headerHeight: number;
    headerSlotSpan: THeaderSlotSpan;
    small: boolean;
    rowHeight: number;
    showNameOfMonth: boolean;
    showNameOfDay: boolean;
    maxHeight: string;
    stickyHeader: boolean;
    set _variant(value: TSchedulerVariantType);
    set _timeLineDate(value: Date | string);
    /**standard="days"; alternative: "hours", "hours:9-18" */
    set _slotUnitOfTime(value: moment.unitOfTime.Diff | UnitOfTimeWithRange);
    scheduledItemRoundFraction: number;
    protected get timelineSecondsPerSlot(): number;
    set _slotWidth(value: number);
    set _slotItems(values: Array<TimelineSlotDataItem>);
    cellClick: EventEmitter<TimeSlotCellClickEvent>;
    itemClick: EventEmitter<ScheduledItemClickEvent>;
    itemDrop: EventEmitter<ScheduledItemDragDropEvent>;
    itemDragStart: EventEmitter<ScheduledItemDragDropEvent>;
    itemDragOver: EventEmitter<ScheduledItemDragDropEvent>;
    set _scheduledItems(values: Array<IScheduledItem>);
    scheduledItemsDateFormat: TScheduledItemsDateFormat;
    scheduledItemMarginHorizontal: number;
    scheduledItemMarginLeft: number;
    allowDragItems: boolean;
    showResourceColumn: boolean;
    resourceHeaderText: string;
    set setResourceColWidthTotal(value: number);
    private resourceColOuterWidth;
    resourceColWidth: number;
    protected recalcWidthsAndHeights(): void;
    scrolledToPosition: EventEmitter<ScrollEvent>;
    scroll(event: any): void;
    scrollbar: NgScrollbar;
    private scrollEventBlocked;
    scrollToPosition(posX: number, posY: number): void;
    resourceIdField: string;
    resourceNameField: string;
    set setListDatasource(value: DatasourceComponent);
    resourceDatasource: DatasourceComponent;
    protected refreshScheduledItems(): void;
    private cellRowInfos;
    private getScheduledItemCellRowInfos;
    protected createScheduledItemModel(scheduledItem: IScheduledItem): ScheduledItemModel;
    private calculateScheduledItemLeftEnd;
    private calculateScheduledItemRightEnd;
    private buildScheduledItemCssClassOpen;
    private date2Px;
    private seconds2Px;
    private roundPxToSlotWidth;
    private get timeLineSecondPerPx();
    private calculateHiddenSeconds;
    protected getSlotCellLineId(scheduledItem: IScheduledItem): any;
    protected getSlotCellLineId(timelineSlotDataItem: TimelineSlotDataItem): any;
    static ɵfac: i0.ɵɵFactoryDeclaration<SchedulerTimelineComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SchedulerTimelineComponent, "scheduler-timeline", never, { "headerHeight": { "alias": "headerHeight"; "required": false; }; "headerSlotSpan": { "alias": "headerSlotSpan"; "required": false; }; "small": { "alias": "small"; "required": false; }; "rowHeight": { "alias": "rowHeight"; "required": false; }; "showNameOfMonth": { "alias": "showNameOfMonth"; "required": false; }; "showNameOfDay": { "alias": "showNameOfDay"; "required": false; }; "maxHeight": { "alias": "maxHeight"; "required": false; }; "stickyHeader": { "alias": "stickyHeader"; "required": false; }; "_variant": { "alias": "variant"; "required": false; }; "_timeLineDate": { "alias": "date"; "required": false; }; "_slotUnitOfTime": { "alias": "slotUnitOfTime"; "required": false; }; "scheduledItemRoundFraction": { "alias": "scheduledItemRoundFraction"; "required": false; }; "_slotWidth": { "alias": "slotWidth"; "required": false; }; "_slotItems": { "alias": "slotItems"; "required": false; }; "_scheduledItems": { "alias": "scheduledItems"; "required": false; }; "scheduledItemsDateFormat": { "alias": "scheduledItemsDateFormat"; "required": false; }; "scheduledItemMarginHorizontal": { "alias": "scheduledItemMarginHorizontal"; "required": false; }; "scheduledItemMarginLeft": { "alias": "scheduledItemMarginLeft"; "required": false; }; "allowDragItems": { "alias": "allowDragItems"; "required": false; }; "showResourceColumn": { "alias": "showResourceColumn"; "required": false; }; "resourceHeaderText": { "alias": "resourceHeaderText"; "required": false; }; "setResourceColWidthTotal": { "alias": "resourceColWidth"; "required": false; }; "resourceIdField": { "alias": "idfield"; "required": false; }; "resourceNameField": { "alias": "resourceNameField"; "required": false; }; "setListDatasource": { "alias": "datasource"; "required": false; }; }, { "cellClick": "cellClick"; "itemClick": "itemClick"; "itemDrop": "itemDrop"; "itemDragStart": "itemDragStart"; "itemDragOver": "itemDragOver"; "scrolledToPosition": "scrolledToPosition"; }, never, never, false, never>;
}
export declare class ScrollEvent {
    posX: number;
    posY: number;
}
