"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ngUpdate = ngUpdate;
/* eslint-disable guard-for-in */
const schematics_1 = require("@angular-devkit/schematics");
const child_process_1 = require("child_process");
const angularVersion = 19;
const staticDependencies = {
    '@angular/cli': angularVersion,
    '@angular/core': angularVersion,
    '@angular/cdk': angularVersion,
    '@angular-eslint/schematics': angularVersion,
    'ngrx-store-localstorage': angularVersion,
    '@sowatech/cypress': '3',
};
function updateAllDependencies(libPackageJsonPath) {
    return (tree) => {
        if (!tree.exists(libPackageJsonPath))
            throw new Error(`Could not find ${libPackageJsonPath}`);
        if (!tree.exists('package.json'))
            throw new Error('Could not find project package.json');
        const libPackageJson = JSON.parse(tree.read(libPackageJsonPath).toString('utf-8'));
        const projectPackageJson = JSON.parse(tree.read('package.json').toString('utf-8'));
        const peerDependencies = {};
        for (const peerDep in libPackageJson.peerDependencies)
            peerDependencies[peerDep] = +libPackageJson.peerDependencies[peerDep].match(/(\d+).\d+.\d+/)[1];
        const installedDependencies = {};
        for (const dep in projectPackageJson.dependencies) {
            const match = projectPackageJson.dependencies[dep].match(/(\d+)\.\d+\.\d+/);
            if (match)
                installedDependencies[dep] = +match[1];
        }
        for (const dep in projectPackageJson.devDependencies) {
            const match = projectPackageJson.devDependencies[dep].match(/(\d+)\.\d+\.\d+/);
            if (match)
                installedDependencies[dep] = +match[1];
        }
        const dependencies = Object.assign(Object.assign({}, peerDependencies), staticDependencies);
        const packagesToUpdate = Object.keys(dependencies).filter(name => !!installedDependencies[name] && installedDependencies[name] < dependencies[name]);
        const updateRuns = [{}];
        for (const packageToUpdate of packagesToUpdate) {
            const currentVersion = installedDependencies[packageToUpdate];
            const targetVersion = dependencies[packageToUpdate];
            for (let version = currentVersion + 1; version <= targetVersion; version++) {
                const i = version - currentVersion - 1;
                if (!updateRuns[i])
                    updateRuns[i] = {};
                updateRuns[i][packageToUpdate] = version;
            }
        }
        for (const updateRun of updateRuns) {
            const updates = Object.entries(updateRun).map(([name, version]) => `${name}@${version}`);
            const command = `ng update --allow-dirty --force ${updates.join(' ')}`;
            console.log(command);
            (0, child_process_1.execSync)(command, { stdio: 'inherit' });
        }
        return tree;
    };
}
function replaceAllOccurrencesOf(before, after) {
    return (tree) => {
        tree.visit(filePath => {
            var _a;
            if (!(filePath.endsWith('.ts') || filePath.endsWith('.html')))
                return;
            if (filePath.includes('node_modules'))
                return;
            const content = (_a = tree.read(filePath)) === null || _a === void 0 ? void 0 : _a.toString();
            if (!content)
                return;
            const updatedContent = content.split(before).join(after);
            if (updatedContent !== content)
                tree.overwrite(filePath, updatedContent);
        });
        return tree;
    };
}
function ngUpdate() {
    return (0, schematics_1.chain)([
        updateAllDependencies('node_modules/@sowatech/shared/package.json'),
        replaceAllOccurrencesOf('focusPreviouseRow', 'focusPreviousRow'),
    ]);
}
//# sourceMappingURL=index.js.map