import { EventEmitter, KeyValueChangeRecord, KeyValueDiffer, KeyValueDiffers } from '@angular/core';
import { SelectColor, SelectItem, SelectItemGroup } from '@sowatech/shared/@types';
import { DatasourceComponent } from '@sowatech/shared/ds-datasource';
import { LoggerService } from '@sowatech/shared/logger';
import { Subscription } from 'rxjs';
import { DialogDynamicList, DialogField, DialogFieldButton, DialogFieldCategory, DialogInputSize } from './swt-generic-edit-dialog.types';
import * as i0 from "@angular/core";
export declare abstract class GenericEditDialogBaseComponent<T> {
    protected logger: LoggerService;
    private differs;
    constructor(logger: LoggerService, differs: KeyValueDiffers);
    private sharedConfig;
    inputSizeDefault: DialogInputSize;
    categoriesAsTabs: boolean;
    onHidden: EventEmitter<void>;
    onCancel: EventEmitter<void>;
    onSubmit: EventEmitter<T>;
    onBeforeSubmit: EventEmitter<T>;
    onChangeDetected: EventEmitter<void>;
    protected differ: KeyValueDiffer<any, any>;
    protected subscriptions: Array<Subscription>;
    protected dtoItem: T;
    editItem: any;
    mode: any;
    errorText: string;
    dynamicLists?: DialogDynamicList[];
    submitResult: 'CANCEL' | 'OK' | string;
    protected onInit(): void;
    protected doCheck(): void;
    protected onDestroy(): void;
    hide(): void;
    private _inputSizeClass;
    get inputSizeClass(): string;
    set inputSizeClass(value: 'input-sm' | 'input-lg' | string);
    private _inputSize;
    get inputSize(): DialogInputSize;
    set inputSize(newSize: DialogInputSize);
    private getInputSizeClassForInputSize;
    private readonly dirty;
    readonly isDirty: import("@angular/core").Signal<boolean>;
    resetDirty(): void;
    setDirty(): void;
    abstract isShown(): boolean;
    protected initData(dto?: T, mode?: any, //user-defined 'mode' without any logic in dialog. can e.g. be used to store meta-info like "INSERT|EDIT|DUPLICATE" in multi-role dialogs
    dynamicLists?: DialogDynamicList[]): void;
    protected resetData(): void;
    cancelDialog(): void;
    /**
     * Abschluss der Bearbeitung:
     * Konvertiert die Form-Eingabewerte in den korrekten Typ soweit erforderlich (z.B. string nach number).
     * Kopiert die Form-Eingabewerte in das Datenobjekt zurück.
     * Löst Submit Events aus
     *
     * @param submitResult
     */
    protected submitDialog(submitResult?: 'OK' | string): void;
    get isSubmitDisabled(): boolean;
    showErrors(errors: string[]): void;
    handleKeyboardEvent(event: KeyboardEvent): void;
    enterKeyAsTabKey: boolean;
    configureDialogFields(fieldsOrCategoriesOfFields: DialogField<T>[] | DialogFieldCategory<T>[]): void;
    get getAllDialogFields(): DialogField<T>[];
    protected getDialogField(fieldname: string): DialogField<T>;
    categories: DialogFieldCategory[];
    get visibleCategories(): DialogFieldCategory[];
    protected copyToEditItem(dto: T): void;
    private convertToIsoDate;
    protected numberToStringEditItem(field: DialogField<T>): void;
    protected stringToNumberEditItem(field: DialogField<T>): any;
    protected getValueOfDtoItem(fieldname: string): any;
    protected initNewEditItem(): void;
    protected prepareItem(): void;
    private convertEditItemValuesToCorrectTypes;
    protected stringToNullOrBool(value: any): boolean;
    private writeAllEditItemFieldToDtoItemFields;
    private writeEditItemFieldToDtoItemField;
    private fieldIsEmpty;
    private prepareDialogFields;
    private getControlType;
    private passwordConfirmInvalid;
    hasLookups(fieldname: string | DialogField<T>): boolean;
    getGroupableLookups(field: string | DialogField<T>): SelectItemGroup[];
    getLookups(fieldname: string | DialogField<T>): Array<SelectItem | SelectColor>;
    private lookupTypeCheck;
    private mapGroupedLookups;
    private isGroupedSelectItem;
    doOnChange(keyValueChange: KeyValueChangeRecord<string, any>): void;
    getSelectItem(fieldname: string): SelectItem;
    setCatActive(activeCat: DialogFieldCategory): void;
    private setFirstCatActive;
    private getDynamicLookupItems;
    getDynamicDatasource(field: DialogField<T>): DatasourceComponent;
    private getDynamicList;
    onButtonClicked(btn: DialogFieldButton, editItem: any): void;
    doOnDropdownGridShown(fieldname: string): void;
    private prepareGrid;
    private datasourceSubscriptions;
    bindGridSelectionToEditItem(): void;
    private unSubscribeDatasources;
    private hasDatePicker;
    private useBrowserDateInput;
    static ɵfac: i0.ɵɵFactoryDeclaration<GenericEditDialogBaseComponent<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<GenericEditDialogBaseComponent<any>, never, never, { "inputSizeDefault": { "alias": "inputSizeDefault"; "required": false; }; "categoriesAsTabs": { "alias": "categoriesAsTabs"; "required": false; }; }, { "onHidden": "onHidden"; "onCancel": "onCancel"; "onSubmit": "onSubmit"; "onBeforeSubmit": "onBeforeSubmit"; "onChangeDetected": "onChangeDetected"; }, never, never, true, never>;
}
