import { AfterViewInit, DoCheck, KeyValueDiffers, OnDestroy, OnInit, QueryList } from '@angular/core';
import { LoggerService } from '@sowatech/shared/logger';
import { SharedConfigService } from '@sowatech/shared/shared-config';
import { ModalDirective } from 'ngx-bootstrap/modal';
import { GenericEditDialogBaseComponent } from './swt-generic-edit-dialog-base.component';
import { GenericEditDialogService } from './swt-generic-edit-dialog.service';
import { DialogDynamicList, DialogFieldButton, DialogSize } from './swt-generic-edit-dialog.types';
import { SwtGenericEditDialogComponentBase } from './templates/swt-generic-edit-dialog.templates';
import * as i0 from "@angular/core";
export declare class GenericEditDialogComponent<T> extends GenericEditDialogBaseComponent<T> implements DoCheck, OnDestroy, OnInit, AfterViewInit {
    private genericEditDialogService;
    constructor(logger: LoggerService, genericEditDialogService: GenericEditDialogService, differs: KeyValueDiffers, sharedConfig: SharedConfigService);
    template: QueryList<SwtGenericEditDialogComponentBase>;
    get dialog(): ModalDirective;
    private get dialogInitDirective();
    modalTitle: string;
    titleSingular: string;
    dialogId: string;
    hideOkButton: boolean;
    hideCancelButton: boolean;
    disableAnimation: boolean;
    swtDropdownContainerContainer: string;
    /** set this true, if this dialog component should be used as the "global generic dialog" */
    set serviceDialog(value: boolean);
    /** used internal */
    isShown(): boolean;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    /** fix weil modal-open nicht herausgenommen wird wenn ein 2ter Dialog geoeffnet wird */
    private closeModalFix;
    ngDoCheck(): void;
    ngOnDestroy(): void;
    /**
     * Fill Data and Show Dialog
     *
     * @param dto
     * @param mode user-defined 'mode' without any logic in dialog. can e.g. be used to store meta-info like "INSERT|EDIT|DUPLICATE" in multi-role dialogs
     * @param dynamicLists dynamic lookups (in contrary to static) which are loaded before dialog.show. they are refernced by a lookupKey in the configuration (lookups of type string)
     */
    show(dto?: T, mode?: any, dynamicLists?: DialogDynamicList[]): void;
    /**
     * Re-Open the Dialog with errors shown
     *
     * @param errors
     */
    showErrors(errors: string[]): void;
    submitDialog(submitResult?: 'OK' | string): void;
    hide(): void;
    cancelDialog(): void;
    get customFormButtonsBefore(): Array<DialogFieldButton>;
    get customFormButtonsAfter(): Array<DialogFieldButton>;
    private getCustomButtons;
    private _size;
    sizeClass: string;
    get size(): DialogSize;
    set size(newSize: DialogSize);
    private getSizeClass;
    focus(fieldname: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<GenericEditDialogComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<GenericEditDialogComponent<any>, "swt-generic-edit-dialog", never, { "titleSingular": { "alias": "titleSingular"; "required": false; }; "dialogId": { "alias": "id"; "required": false; }; "serviceDialog": { "alias": "serviceDialog"; "required": false; }; }, {}, never, never, false, never>;
}
