import { SelectItem } from '@sowatech/shared/@types';
import { AggregateFunctionConfig, AggregateFunctionFieldConfig, FilterOperator } from '@sowatech/shared/ds-datasource';
import { ColumnType, PaginationInfoVariant, TextAlignType } from '@sowatech/shared/shared-config';
export type HeaderTitleGroups = Record<string, IHeaderTitleGroup>;
export type GridLookup = Array<SelectItem> | Array<string>;
export type GridSpanVariant = 'label' | 'icon' | 'progress' | 'stackedProgress';
export type GridColumnType = ColumnType | 'buttons' | 'empty' | 'lookup';
/**
 * das zugewiesene Feld kann nur ein Feldname von T sein, wobei der zugewiesene Typ für dieses Feld V ist
 */
type KeyWithType<T, V> = {
    [K in keyof T]-?: T[K] extends V ? K : never;
}[keyof T];
/**
 * das zugewiesene Feld kann nur ein Feldname von T mit string value sein
 */
type FieldnameWithStringValue<T> = KeyWithType<T, string>;
type FieldnameWithBooleanValue<T> = KeyWithType<T, boolean>;
type FieldnameWithRecordValue<T> = KeyWithType<T, Record<string, unknown>>;
type ItemId = any;
export declare class GridColumn<ListItem = any> implements AggregateFunctionFieldConfig<ListItem> {
    text?: string;
    title?: string;
    fieldname?: Extract<keyof ListItem, string>;
    headerTitleGroup?: string;
    hideFieldValue?: boolean;
    type?: GridColumnType;
    lookups?: GridLookup;
    trueValueText?: string;
    falseValueText?: string;
    unit?: string;
    digitInfo?: string;
    dateFormat?: string;
    buttons?: Array<GridColumnButton<ListItem>>;
    buttonsAsDropdown?: string;
    buttonsAsDropdownClass?: string;
    spans?: Array<GridColumnSpan<ListItem>>;
    titleSpans?: Array<GridTitleSpan<ListItem>>;
    minWidth?: string;
    width?: string;
    textAlign?: TextAlignType;
    bodyClass?: string;
    bodyClassFieldname?: FieldnameWithStringValue<ListItem>;
    headerClass?: string;
    allowFilter?: boolean;
    allowSort?: boolean;
    filterOperator?: FilterOperator;
    /**
     * Filtervariante bei Lookups
     * @default 'single'
     */
    filterSelectOption?: 'single' | 'multi';
    edit?: boolean;
    /** Aggregatfunktionen über Items (siehe includedAggregateData). Ergebnis im Tooltip oder Footer. Klappt nur mit Zahlen */
    aggregateFunctions?: AggregateFunctionGridConfig[];
    /** Wenn true: Spalte ist hidden und muss über den visibility-Dialog explizit eingeblendet werden */
    hiddenByDefault?: boolean;
    /**
     * welche Daten sollen für aggregateFunctions verwendet werden?
     *
     * @default 'all'
     */
    includedAggregateData?: 'all' | 'selected';
    groupBy?: boolean;
}
export declare class GridColumnButton<ListItem = any> {
    ident?: string;
    text?: string;
    tooltip?: string;
    buttonClass?: string;
    iconClass?: string;
    disabledFieldname?: FieldnameWithBooleanValue<ListItem>;
    buttonClassFieldname?: FieldnameWithStringValue<ListItem>;
    iconClassFieldname?: FieldnameWithStringValue<ListItem>;
    /**
     * Beispiel:
     * `spans: [{ text: 'Löschen', ident: 'DELETE', onClick: id => this.delete(id) }]`
     */
    onClick?: (itemId: ItemId | null) => void;
}
export declare class GridTitleSpan<ListItem = any> {
    class?: string;
    text?: string;
    title?: string;
    positionBefore?: boolean;
    color?: string;
    color2?: string;
    backgroundColor?: string;
    isIcon?: boolean;
    variant?: GridSpanVariant;
    routerLink?: string;
    /** Zusätzliche QueryParams für den RouterLink*/
    queryParams?: Record<string, unknown>;
    /** soll bei variant = 'progress' der Wert in % angezeigt werden? default: true */
    showProgressPercent?: boolean;
    stackedProgressBars?: IStackedProgressBar<ListItem>[];
    ident?: string;
    onClick?: () => void;
}
export declare class GridColumnSpan<ListItem = any> {
    class?: string;
    classFieldname?: FieldnameWithStringValue<ListItem>;
    text?: string;
    textFieldname?: Extract<keyof ListItem, string>;
    title?: string;
    titleFieldname?: Extract<keyof ListItem, string>;
    positionBefore?: boolean;
    color?: string;
    colorFieldname?: FieldnameWithStringValue<ListItem>;
    color2?: string;
    color2Fieldname?: FieldnameWithStringValue<ListItem>;
    backgroundColor?: string;
    backgroundColorFieldname?: FieldnameWithStringValue<ListItem>;
    isIcon?: boolean;
    variant?: GridSpanVariant;
    routerLink?: string;
    /** Feldname mit Routerlink (als string); if!=null wird in <a> tag mit Routerlink gerendert */
    routerLinkFieldname?: FieldnameWithStringValue<ListItem>;
    /** Zusätzliche QueryParams für den RouterLink*/
    queryParams?: Record<string, unknown>;
    /** Feldname mit zusätzlichen QueryParams für den RouterLink*/
    queryParamsFieldname?: FieldnameWithRecordValue<ListItem>;
    /** soll bei variant = 'progress' der Wert in % angezeigt werden? default: true */
    showProgressPercent?: boolean;
    stackedProgressBars?: IStackedProgressBar<ListItem>[];
    ident?: string;
    /**
     * Beispiel:
     * `buttons: [{ text: 'Löschen', ident: 'DELETE', onClick: id => this.delete(id) }]`
     */
    onClick?: (itemId: ItemId | null) => void;
}
export declare class GridConfiguration<ListItem = any> {
    columns: Array<GridColumn<ListItem>>;
    idfield?: Extract<keyof ListItem, string>;
    small?: boolean;
    gridStoreKey?: string;
    gridClass?: string;
    allowFilter?: boolean;
    allowSort?: boolean;
    allowPaging?: boolean;
    pageSizes?: number[];
    paginationInfoVariant?: PaginationInfoVariant;
    allowPrintDownload?: boolean;
    printTitle?: string;
    rowClassFieldName?: keyof ListItem;
    rowDetailClassFieldName?: keyof ListItem;
    allowSelectPageSize?: boolean;
    allowMultiSelect?: boolean;
    disableFieldName?: Extract<keyof ListItem, string>;
    tableHover?: boolean;
    showSelectCheckBoxes?: boolean;
    showEmptyGrid?: boolean;
    emptyGridText?: string;
    dragulaBag?: string;
    filterFieldsVisible?: boolean;
    hideColSelectBtn?: boolean;
    headerTitleGroups?: HeaderTitleGroups;
}
export type AggregateFunctionGridConfig = AggregateFunctionConfig & {
    /** @default true */
    showInTooltip?: boolean;
    /** @default false */
    showInFooterRow?: boolean;
};
export interface IHeaderTitleGroup {
    text: string;
    title?: string;
}
export interface IStackedProgressBar<ListItem = any> {
    value?: string;
    valueFieldname?: Extract<keyof ListItem, string>;
    class?: string;
    classFieldName?: string;
}
export {};
