import { CurrencyPipe } from '@angular/common';
import { AfterViewInit, ElementRef, EventEmitter, OnDestroy, OnInit } from '@angular/core';
import { CSVConfig, DatasourceComponent } from '@sowatech/shared/ds-datasource';
import { LoggerService } from '@sowatech/shared/logger';
import { ScrollEvent } from '@sowatech/shared/scheduler';
import { IconAlignType, PaginationInfoVariant, ShowDetailMethod, SwtGridDefaultConfig } from '@sowatech/shared/shared-config';
import { LoadingIndicatorComponent } from '@sowatech/shared/swt-controls';
import { DragulaService } from '@sowatech/shared/swt-dragula';
import { I18nService } from '@sowatech/shared/utilities';
import { BsModalService } from 'ngx-bootstrap/modal';
import { NgScrollbar } from 'ngx-scrollbar';
import { ColSelectDialogComponent } from '../col/col-select-dialog.component';
import { ColVisibilityService } from '../col/col-visibility.service';
import { GridColumn, GridColumnButton, GridColumnSpan, GridColumnType, GridConfiguration, GridTitleSpan, HeaderTitleGroups, IHeaderTitleGroup } from './swt-grid-configuration';
import { GridColumnButtonEvent, GridDropEvent, GridDropRemoveEvent, Html5DragDropEvent, RowClickEvent, SpanClickEvent } from './swt-grid-events';
import * as i0 from "@angular/core";
type OnlyStringKeys = Record<string, any>;
type Id = any;
export declare class GridComponent<ListItem extends OnlyStringKeys = any> implements OnInit, OnDestroy, AfterViewInit {
    private logger;
    private dragulaService;
    locale: string;
    private config;
    private colVisibilityService;
    private currencyPipe;
    private modalService;
    private i18n;
    constructor(logger: LoggerService, dragulaService: DragulaService, locale: string, config: SwtGridDefaultConfig, colVisibilityService: ColVisibilityService, currencyPipe: CurrencyPipe, modalService: BsModalService, i18n: I18nService);
    private bsModalRef?;
    private readonly destroyRef;
    private printService;
    readonly selectAllRowsLabel: string;
    readonly selectRowLabel: string;
    private datePipe;
    private decimalPipe;
    private subscriptions;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    private onColVisibilityChanged;
    onKeydownHandler(event: KeyboardEvent): void;
    onEnterPressed(): void;
    /**
     * @deprecated clickOnFocusedRow() benutzen
     */
    clickOnFocuedRow(): void;
    clickOnFocusedRow(): void;
    onKeyUp(): void;
    onKeyDown(): void;
    get datasourceHasExternalRefresh(): boolean;
    gridId: string;
    gridIdPrefix: string;
    idfield: string;
    set setGridId(value: string);
    cyTotalRefreshCounter: number;
    cyCurrentRefreshCounter: number;
    set setListDatasource(value: DatasourceComponent);
    stickyHeader: boolean;
    name: string;
    small: boolean;
    allowKeyboardShortCuts: boolean;
    minHeight: string;
    /**
     * Max-Height of table excluding pagination.
    */
    maxHeightTable: string;
    /**
    * Obsolete. Max-Height of entire component including pagination, filter info etc. Use maxHeightTable instead.
    */
    maxHeight: string;
    rowHeight: number;
    filterRowHeight: number;
    headerRowHeight: number;
    headerTitleGroups: HeaderTitleGroups;
    gridStoreKey: string;
    hideColSelectBtn: boolean;
    gridClass: string;
    allowCSVDownload: boolean;
    csvFileName: string;
    csvConfig: CSVConfig;
    allowFilter: boolean;
    allowSort: boolean;
    allowPaging: boolean;
    showSelectedIdsNotFoundWarning: boolean;
    showRowDetail: boolean;
    showDetailMethod: ShowDetailMethod;
    paginationInfoVariant: PaginationInfoVariant;
    allowPrintDownload: boolean;
    printTitle: string;
    rowClassFieldName?: keyof ListItem;
    rowDetailClassFieldName?: keyof ListItem;
    allowSelectPageSize: boolean;
    set _pageSizes(values: number[]);
    pageSizes: number[];
    allowMultiSelect: boolean;
    /** Bool-Fieldname des Models der angibt ob Select für Zeile disabled wird*/
    disableSelectFieldName: Extract<keyof ListItem, string>;
    showEmptyGrid: boolean;
    emptyGridText: string;
    filterFieldsVisible: boolean;
    sortItemAlign: IconAlignType;
    html5Draggable: string;
    onHtml5DragStart: EventEmitter<Html5DragDropEvent>;
    dragulaBag: import("@angular/core").InputSignal<string>;
    dragulaShowIcon: import("@angular/core").InputSignal<boolean>;
    dragulaOnlyIconDrag: import("@angular/core").InputSignal<boolean>;
    private setDragulaOptions;
    private getDragulaOptions;
    private dragulaSubscriptions;
    private setDragulaSubscriptions;
    showSelectCheckBoxes: boolean;
    tableHover: boolean;
    set setConfig(value: GridConfiguration<ListItem>);
    onButtonClicked: EventEmitter<GridColumnButtonEvent>;
    onRowClicked: EventEmitter<RowClickEvent>;
    onDrop: EventEmitter<GridDropEvent>;
    onDragulaRemove: EventEmitter<GridDropRemoveEvent>;
    /** nur für showDetailMethod = 'dropdown' */
    detailOpened: EventEmitter<any>;
    loadingIndicator: LoadingIndicatorComponent;
    filterItems: ElementRef<HTMLElement>;
    table: ElementRef;
    swtGridDiv: ElementRef;
    headerTitleGroupColumns?: HeaderTitleGroupCol[];
    showFooter: boolean;
    firstItemsOfGroup: Id[];
    focusGrid(): void;
    listDatasource: DatasourceComponent<ListItem>;
    set columns(allColumns: GridColumn<ListItem>[]);
    setFocusedFilter(fieldName: string): void;
    visibleColumns: GridColumn<ListItem>[];
    private setVisibleColumns;
    get numOfVisibleColumns(): number;
    private get extraColumnCount();
    get rowCursorClass(): string;
    groupByColumns: GridColumn<ListItem>[];
    get groupByColumn(): GridColumn<ListItem>;
    get grouped(): boolean;
    private prepareHeaderGroupColumns;
    private setGroupBy;
    private prepareColumns;
    configureGrid(config: GridConfiguration<ListItem>): void;
    getData(): object[];
    downloadCSV(): void;
    private getCSVColumn;
    displayText(listItem: any, column: GridColumn<ListItem>): string;
    getLookupTextColumn(listItem: any, column: GridColumn<ListItem>): string;
    allowSortColumn(column: GridColumn<ListItem>): boolean;
    allowFilterColumn(column: GridColumn<ListItem>): boolean;
    getFilterOperator(column: GridColumn<ListItem>): string;
    private autoDetectIdFieldname;
    private getListItemId;
    buttonClicked(event: MouseEvent, ident: string, listItem: any): void;
    spanClicked(event: SpanClickEvent): void;
    rowClick(event: MouseEvent, listItem: any): void;
    private onBeforeDatasourceRefresh;
    private onAfterDatasourceRefresh;
    private onFocus;
    toggleGridDetail(listItemId: Id): void;
    setRowDetailId(listItemId: Id): void;
    html5DragStart(event: DragEvent, listItem: ListItem): void;
    isSelected(listItem: ListItem): boolean;
    isFocused(listItem: ListItem): boolean;
    /** Die ID des geöffneten Grid Details */
    detailId?: Id;
    closeDetail(): void;
    closeDetailByDropDown(event?: Event): void;
    isRowDetailIdOpen(listItemId: Id): boolean;
    isRowDetailOpen(listItem: ListItem): boolean;
    openDetail(event: Event, listItem: ListItem): void;
    visibilityKey(gridColumn: GridColumn): string;
    colSelectDialog: ColSelectDialogComponent;
    showColSelectDialog(): void;
    columnClass(column: GridColumn<ListItem>, listItem: ListItem): string;
    getDefaultColumnTextAlignment(type?: GridColumnType): any;
    spansBefore(spans: GridColumnSpan[] | GridTitleSpan[]): Array<GridColumnSpan<ListItem>>;
    spansAfter(spans: GridColumnSpan[] | GridTitleSpan[]): Array<GridColumnSpan<ListItem>>;
    getButtonClass(listItem: ListItem, btn: GridColumnButton<ListItem>): string;
    getButtonIconClass(listItem: ListItem, btn: GridColumnButton<ListItem>): string;
    private onRowDrop;
    private onRowRemove;
    fieldValueModelChange(event: any, gridColumn: GridColumn<ListItem>, listItem: ListItem): void;
    getSelectOptionValue(lookup: unknown): unknown;
    private getColumnsByColVisibility;
    private formatAggregate;
    getAggregateFooterText(col: GridColumn<ListItem>): string;
    getAggregateTitleText(col: GridColumn<ListItem>): string;
    getEditColLabel(col: GridColumn<ListItem>): string;
    private updateShowFooter;
    private setDefaultConfigurations;
    printGrid(): void;
    private getNode;
    readonly scrollbar: import("@angular/core").Signal<NgScrollbar>;
    private scrollEventBlocked;
    scrollToPosition(posX: number, posY: number): void;
    scrolledToPosition: EventEmitter<ScrollEvent>;
    scroll(event: any): void;
    private calcFirstItemsOfGroups;
    isFirstItemOfGroup(item: ListItem): boolean;
    columnTemplateParam: {
        listItem: ListItem;
        column: GridColumn<ListItem>;
    };
    getInputType(type: GridColumnType): "number" | "text" | "date" | "url" | "email" | "tel" | "buttons" | "empty" | "lookup" | "datetime-local" | "checkbox";
    static ɵfac: i0.ɵɵFactoryDeclaration<GridComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<GridComponent<any>, "swt-grid", never, { "idfield": { "alias": "idfield"; "required": false; }; "setGridId": { "alias": "id"; "required": false; }; "setListDatasource": { "alias": "datasource"; "required": false; }; "stickyHeader": { "alias": "stickyHeader"; "required": false; }; "name": { "alias": "name"; "required": false; }; "small": { "alias": "small"; "required": false; }; "allowKeyboardShortCuts": { "alias": "allowKeyboardShortCuts"; "required": false; }; "minHeight": { "alias": "minHeight"; "required": false; }; "maxHeightTable": { "alias": "maxHeightTable"; "required": false; }; "maxHeight": { "alias": "maxHeight"; "required": false; }; "rowHeight": { "alias": "rowHeight"; "required": false; }; "filterRowHeight": { "alias": "filterRowHeight"; "required": false; }; "headerRowHeight": { "alias": "headerRowHeight"; "required": false; }; "headerTitleGroups": { "alias": "headerTitleGroups"; "required": false; }; "gridStoreKey": { "alias": "store-key"; "required": false; }; "hideColSelectBtn": { "alias": "hideColSelectBtn"; "required": false; }; "gridClass": { "alias": "gridClass"; "required": false; }; "allowCSVDownload": { "alias": "allowCSVDownload"; "required": false; }; "csvFileName": { "alias": "csvFileName"; "required": false; }; "csvConfig": { "alias": "csvConfig"; "required": false; }; "allowFilter": { "alias": "allowFilter"; "required": false; }; "allowSort": { "alias": "allowSort"; "required": false; }; "allowPaging": { "alias": "allowPaging"; "required": false; }; "showSelectedIdsNotFoundWarning": { "alias": "showSelectedIdsNotFoundWarning"; "required": false; }; "showRowDetail": { "alias": "showRowDetail"; "required": false; }; "showDetailMethod": { "alias": "showDetailMethod"; "required": false; }; "paginationInfoVariant": { "alias": "paginationInfoVariant"; "required": false; }; "allowPrintDownload": { "alias": "allowPrintDownload"; "required": false; }; "printTitle": { "alias": "printTitle"; "required": false; }; "rowClassFieldName": { "alias": "rowClassFieldName"; "required": false; }; "rowDetailClassFieldName": { "alias": "rowDetailClassFieldName"; "required": false; }; "allowSelectPageSize": { "alias": "allowSelectPageSize"; "required": false; }; "_pageSizes": { "alias": "pageSizes"; "required": false; }; "allowMultiSelect": { "alias": "allowMultiSelect"; "required": false; }; "disableSelectFieldName": { "alias": "disableSelectFieldName"; "required": false; }; "showEmptyGrid": { "alias": "showEmptyGrid"; "required": false; }; "emptyGridText": { "alias": "emptyGridText"; "required": false; }; "filterFieldsVisible": { "alias": "filterFieldsVisible"; "required": false; }; "sortItemAlign": { "alias": "sortItemAlign"; "required": false; }; "html5Draggable": { "alias": "html5Draggable"; "required": false; }; "dragulaBag": { "alias": "dragulaBag"; "required": false; "isSignal": true; }; "dragulaShowIcon": { "alias": "dragulaShowIcon"; "required": false; "isSignal": true; }; "dragulaOnlyIconDrag": { "alias": "dragulaOnlyIconDrag"; "required": false; "isSignal": true; }; "showSelectCheckBoxes": { "alias": "showSelectCheckBoxes"; "required": false; }; "tableHover": { "alias": "table-hover"; "required": false; }; "setConfig": { "alias": "config"; "required": false; }; }, { "onHtml5DragStart": "onHtml5DragStart"; "onButtonClicked": "onButtonClicked"; "onRowClicked": "onRowClicked"; "onDrop": "onDrop"; "onDragulaRemove": "onDragulaRemove"; "detailOpened": "detailOpened"; "scrolledToPosition": "scrolledToPosition"; }, never, ["*"], false, never>;
}
declare class HeaderTitleGroupCol implements IHeaderTitleGroup {
    key: string | null;
    span: number;
    constructor(key: string | null, span?: number, data?: IHeaderTitleGroup);
    text: string;
    title: string;
    get isEmpty(): boolean;
    static get empty(): HeaderTitleGroupCol;
}
export {};
